<?php
session_start(); // Session başlat

require 'db.php'; // Veritabanı bağlantısı

// CSRF Token Oluşturma Fonksiyonu
function generateToken() {
    return bin2hex(random_bytes(32)); // 32 byte'lık rastgele bir değer oluştur
}

// Token'i oluştur ve sakla
if (!isset($_SESSION['token'])) {
    $_SESSION['token'] = generateToken();
}

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // CSRF token kontrolü
    if (!isset($_POST['token']) || $_POST['token'] !== $_SESSION['token']) {
        die("Arka planda SESSIONS oluşturuldu. Lütfen bir önceki sayfaya giderek tekrar yorum yap. Otomatik olarak doğrulanacak. İleride bu sistem değişecektir. İlgin ve alakan için teşekkür ederiz.");
    }

    $movieId = $_POST['movie_id'];
    $userId = $_SESSION['user_id']; // Oturumdan kullanıcı ID'sini alın
    $content = $_POST['content'];

    try {
        // Yorumu veritabanına ekleyin
        $stmt = $pdo->prepare("INSERT INTO comments (movie_id, user_id, content) VALUES (:movie_id, :user_id, :content)");
        $stmt->bindParam(':movie_id', $movieId);
        $stmt->bindParam(':user_id', $userId);
        $stmt->bindParam(':content', $content);
        $stmt->execute();

        // Yorumun ID'sini alın
        $commentId = $pdo->lastInsertId();

        // Etiketleri tespit etme ve veritabanına ekleme
        preg_match_all('/#(\w+)/', $content, $matches);
        $tags = $matches[1];

        foreach ($tags as $tag) {
            // Etiketleri veritabanına ekleme
            $tagQuery = "INSERT INTO tags (tag, user_id, movie_id, comment_id) VALUES (:tag, :user_id, :movie_id, :comment_id)";
            $tagStmt = $pdo->prepare($tagQuery);
            $tagStmt->bindParam(':tag', $tag);
            $tagStmt->bindParam(':user_id', $userId);
            $tagStmt->bindParam(':movie_id', $movieId);
            $tagStmt->bindParam(':comment_id', $commentId);
            $tagStmt->execute();
        }

        // Post/Redirect/Get prensibi ile yönlendirme
        header('Location: movie?id=' . $movieId);
        exit();
    } catch (PDOException $e) {
        // PDO istisnasını yönetin (örneğin, bütünlük kısıtlama ihlali)
        $_SESSION['comment_error'] = "Yorumunuz eklenirken bir hata oluştu: " . $e->getMessage();
        header('Location: movie?id=' . $movieId);
        exit();
    }
} else {
    // Form gönderilmediyse veya GET isteği geldiyse, hata verin veya başka bir şey yapın
    die("Arka planda SESSIONS oluşturuldu. Lütfen bir önceki sayfaya giderek tekrar yorum yapın. Otomatik olarak doğrulanacak ve bir daha sizi rahatsız etmeyeceğiz.");
}
?>
