<?php
session_start();

// Database connection and other necessary files
require 'db.php'; // Database connection

// Check if the form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if user is logged in
    if (!isset($_SESSION['user_id'])) {
        http_response_code(403); // Unauthorized
        exit("You are not logged in.");
    }

    // Check if token is valid (for CSRF protection)
    if (!isset($_POST['token']) || $_POST['token'] !== $_SESSION['token']) {
        http_response_code(403); // Forbidden
        exit("Invalid CSRF token.");
    }

    // Sanitize and validate input
    $tvId = $_POST['tv_id'];
    $content = htmlspecialchars($_POST['content'], ENT_QUOTES, 'UTF-8'); // XSS protection
    $userId = $_SESSION['user_id'];

    // Insert comment into database
    $stmt = $pdo->prepare("
        INSERT INTO comments (tv_id, user_id, content, timestamp)
        VALUES (:tv_id, :user_id, :content, NOW())
    ");
    $stmt->execute([
        'tv_id' => $tvId,
        'user_id' => $userId,
        'content' => $content
    ]);

    // Redirect to prevent form resubmission on refresh
    header("Location: tv.php?id=$tvId");
    exit();
} else {
    http_response_code(405); // Method Not Allowed
    exit("Method not allowed.");
}
?>
