<?php
session_start();
require 'db.php'; // Veritabanı bağlantısı

// Kullanıcının giriş yapmış olup olmadığını kontrol et
$userLoggedIn = isset($_SESSION['user_id']);

// Kullanıcı giriş yapmışsa, kullanıcı ID'sini al
$userId = $_SESSION['user_id'] ?? null;

$title = "Rozetlerim";

include 'navbar.php'; // Başlık ve NAV

$api_key = '63fd1ed0aa746bf66c0513b79c7b2b8f';

// API'den kategorileri almak için URL
$api_url = "https://api.themoviedb.org/3/genre/movie/list?api_key=$api_key&language=tr-TR";

// CURL ile API isteği yapalım
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $api_url);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
$response = curl_exec($ch);
$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
curl_close($ch);

$categories = [];
if ($response && $http_code == 200) {
    $data = json_decode($response, true);
    $categories = $data['genres'];
}

// Fonksiyon: Kategori ismine göre Font Awesome ikonu döndürür
function getFontAwesomeIcon($categoryName)
{
    switch ($categoryName) {
        case 'Aksiyon':
            return 'fighter-jet';
        case 'Macera':
            return 'compass';
        case 'Animasyon':
            return 'robot';
        case 'Komedi':
            return 'laugh';
        case 'Suç':
            return 'exclamation-triangle'; // Örnek ikon, değiştirilebilir
        case 'Belgesel':
            return 'file-alt';
        case 'Dram':
            return 'theater-masks';
        case 'Aile':
            return 'child';
        case 'Fantastik':
            return 'dragon';
        case 'Tarih':
            return 'landmark';
        case 'Korku':
            return 'ghost';
        case 'Müzik':
            return 'music';
        case 'Gizem':
            return 'question';
        case 'Romantik':
            return 'heart';
        case 'Bilim-Kurgu':
            return 'rocket';
        case 'TV film':
            return 'tv';
        case 'Gerilim':
            return 'bolt';
        case 'Savaş':
            return 'bomb';
        case 'Vahşi Batı':
            return 'horse';
        default:
            return 'film'; // Varsayılan ikon
    }
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Foxy - Film Kategorileri</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="description" content="Foxy'in film kategorilerine göz at.">
    <meta name="keywords" content="film, dizi, foxy, foxyplatform, film kategorileri, fimler, kategoriler, foxy instagram, 9fud, ebusoft, 9fud.com, movie 9fud">
    <meta property="og:image" content="/cdn/logo.png">
    <meta name="author" content="Foxy | 9FUD.COM">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://cdn.jsdelivr.net/npm/animate.css@4.1.1/animate.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        .movie-item:hover .overlay {
            opacity: 1;
            visibility: visible;
        }

        .overlay {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
            opacity: 0;
            visibility: hidden;
            display: flex;
            justify-content: center;
            align-items: center;
            transition: opacity 0.3s ease;
        }

        .overlay-text {
            color: white;
            font-size: 18px;
            font-weight: bold;
            text-align: center;
            padding: 10px;
        }

        .movie-poster {
            transition: transform 0.3s ease;
        }

        .movie-poster:hover {
            transform: scale(1.1);
        }
    </style>
</head>

<body class="bg-gray-100">
    <div class="container mx-auto p-4 pb-32">
        <div class="flex flex-col items-center mb-4">
            <h1 class="text-3xl font-bold"><i class="fa-solid fa-clapperboard"></i> Film Kategorileri</h1>
            <span class="text-zinc-500 mt-1 text-sm font-semibold text-center">Aşağıdaki kategorilere tıklayarak ilgili kategoriye ait filmlere göz atabilirsin.</span>
        </div>
        <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-2">
            <?php foreach ($categories as $category) : ?>
                <div class="relative p-4 bg-black text-white rounded-lg shadow-md transition duration-300 transform hover:scale-95 movie-item">
                    <a href="#" onclick="showMovies(<?php echo htmlspecialchars($category['id']); ?>, 1); return false;" class="block text-lg font-semibold transition duration-300 hover:text-blue-600 flex items-center">
                        <span class="mr-2"><i class="fas fa-<?php echo getFontAwesomeIcon($category['name']); ?>"></i></span> <!-- Font Awesome icon -->
                        <?php echo htmlspecialchars($category['name']); ?>
                    </a>
                </div>
            <?php endforeach; ?>
        </div>

        <!-- Movie list section (to display movies dynamically) -->
        <div id="movieList" class="mt-8">
            <!-- This section will dynamically populate with movies -->
        </div>
    </div>

    <!-- JavaScript function for showing movies -->
    <script>
        function showMovies(categoryId, page) {
            var moviesDiv = document.getElementById('movieList');
            moviesDiv.innerHTML = '<h2 class="text-2xl font-semibold mb-2"><i class="fa-solid fa-spinner fa-spin"></i> Yükleniyor...</h2>';

            // API'den kategoriye ait filmleri almak için URL
            var moviesUrl = "https://api.themoviedb.org/3/discover/movie?api_key=<?php echo $api_key; ?>&language=tr-TR&include_adult=false&include_video=false&page=" + page + "&with_genres=" + categoryId;

            // AJAX ile API isteği yapalım
            var xhr = new XMLHttpRequest();
            xhr.open("GET", moviesUrl, true);
            xhr.onload = function() {
                if (xhr.status === 200) {
                    var response = JSON.parse(xhr.responseText);
                    var movies = response.results;
                    var html = '<div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-5 gap-4">';
                    movies.forEach(function(movie, index) {
                        var posterUrl = movie.poster_path ? 'https://image.tmdb.org/t/p/w500' + movie.poster_path : 'https://via.placeholder.com/500x750?text=Poster+Not+Available';
                        var delay = index * 100; // Delay for animation

                        // Tarih formatını ayarlayalım (örnek: 2024-07-09)
                        var releaseDate = movie.release_date ? new Date(movie.release_date) : '';
                        var year = releaseDate ? releaseDate.getFullYear() : '';

                        html += '<div class="relative rounded-lg overflow-hidden animate__animated animate__fadeInUp" style="animation-delay: ' + delay + 'ms;">';
                        html += '<a href="movie.php?id=' + movie.id + '" class="block">';
                        html += '<img draggable="false" src="' + posterUrl + '" alt="' + movie.title + '" class="rounded-lg ">';
                        html += '<div class="absolute top-0 left-0 w-full h-full bg-black opacity-0 hover:opacity-75 transition-opacity duration-300">';
                        html += '<div class="absolute inset-0 flex flex-col items-center justify-center">';
                        html += '<p class="text-lg font-semibold text-white text-center">' + movie.title + '</p>';
                        html += '<p class="text-sm text-gray-300 mt-1">' + year + '</p>'; // Sadece yıl ekleme
                        html += '</div></div>';
                        html += '</a></div>';
                    });
                    html += '</div>';
                    moviesDiv.innerHTML = html;

                    // Sayfalama butonunu ekleyelim
                    var totalPages = response.total_pages;
                    if (totalPages > 1) {
                        var paginationHtml = '<div class="mt-4 flex items-center justify-between">';
                        if (page > 1) {
                            paginationHtml += '<button class="bg-blue-500 hover:bg-blue-600 duration-300 font-semibold text-white px-4 py-2 rounded-md mr-2" onclick="showMovies(' + categoryId + ', ' + (page - 1) + ');"><i class="fas fa-arrow-left mr-2"></i>Önceki Sayfa</button>';
                        }
                        if (page < totalPages) {
                            paginationHtml += '<button class="bg-blue-500 hover:bg-blue-600 duration-300 font-semibold text-white px-4 py-2 rounded-md" onclick="showMovies(' + categoryId + ', ' + (page + 1) + ');">Sonraki Sayfa<i class="fas fa-arrow-right ml-2"></i></button>';
                        }
                        paginationHtml += '</div>';
                        moviesDiv.innerHTML += paginationHtml;
                    }

                } else {
                    moviesDiv.innerHTML = '<p class="text-red-500">Filmler yüklenirken bir hata oluştu.</p>';
                }
            };
            xhr.onerror = function() {
                moviesDiv.innerHTML = '<p class="text-red-500">Filmler yüklenirken bir hata oluştu.</p>';
            };
            xhr.send();
        }
    </script>

    <footer class="mt-8 bg-black/90 text-white p-4 fixed bottom-0 w-full right-0 opacity-90">
        <div class="container mx-auto flex justify-between items-center">
            <div>
                <div class="flex flex-row items-center">
                    <img draggable="false" src="./cdn/logo.png" alt="Foxy" class="w-12">
                    <h3 class="text-lg font-bold">Foxy</h3>
                </div>
                <p class="mt-2">Tüm hakları saklıdır. | <span class="font-semibold">&copy; 2024 <a class="hover:text-red-600 duration-150" href="https://9fud.com">9FUD.COM</a></span></p>
            </div>
            <div>
                <ul class="flex space-x-3">
                    <li>
                        <a href="https://instagram.com/FoxyPlatform" target="_blank" rel="noopener noreferrer" class="duration-150 text-gray-300 hover:text-pink-500" data-tippy-content="Bizi İnstagram'dan takip et!">
                            <i class="fab fa-instagram fa-lg"></i>
                        </a>
                    </li>
                    <li>
                        <a href="https://twitter.com/FoxyPlatform" target="_blank" rel="noopener noreferrer" class="duration-150 text-gray-300 hover:text-blue-400" data-tippy-content="Bizi X'ten takip et!">
                            <i class="fab fa-x-twitter fa-lg"></i>
                        </a>
                    </li>
                </ul>
            </div>
        </div>
    </footer>
</body>

</html>