<?php
session_start();
require 'db.php'; // Veritabanı bağlantısı

// Kullanıcının giriş yapmış olup olmadığını kontrol et
$userLoggedIn = isset($_SESSION['user_id']);

// Kullanıcı giriş yapmışsa, kullanıcı ID'sini al
$userId = $_SESSION['user_id'] ?? null;

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $userId = $_SESSION['user_id'];
    $title = $_POST['title'];
    $description = $_POST['description'];
    $uniqueLink = bin2hex(random_bytes(5)); // Benzersiz bağlantı oluşturma, 10 yerine 5 bayt kullanıldı

    $query = $pdo->prepare('INSERT INTO lists (user_id, title, description, unique_link) VALUES (?, ?, ?, ?)');
    if ($query->execute([$userId, $title, $description, $uniqueLink])) {
        $_SESSION['list_message'] = 'Yeni liste başarıyla oluşturuldu!';
        // Yeni oluşturulan listenin sayfasına yönlendir
        header('Location: list.php?id=' . $pdo->lastInsertId());
        exit();
    } else {
        $_SESSION['list_message'] = 'Liste oluşturulurken bir hata oluştu.';
    }
} else {
    // Giriş yapmış kullanıcı kontrolü
    if (!isset($_SESSION['user_id'])) {
        // Kullanıcı giriş yapmamışsa uyarı ver ve yönlendir
        $_SESSION['list_message'] = 'Giriş yapmamışsınız. Liste oluşturabilmek için giriş yapın.';
        header('Location: login.php');
        exit();
    }
?>



<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Yeni Liste Oluştur</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        /* Stil sayfası yerine Tailwind CSS sınıfları tercih edildi */
    </style>
</head>
<body class="bg-gray-100">
    <div class="bg-white mt-[25vh] mx-auto p-8 rounded-lg shadow-lg w-full max-w-md">
        <h2 class="text-2xl font-bold text-center mb-6"><i class="fa-solid fa-list"></i> Yeni Liste Oluştur</h2>

        <form method="POST" action="create_list.php" onsubmit="return validateForm()">
            <div class="mb-4">
                <label for="title" class="block text-sm font-medium mb-2"> Başlık:</label>
                <input type="text" id="title" name="title" required maxlength="64" class="w-full px-4 py-2 bg-gray-200 text-gray-800 border border-gray-300 rounded-lg focus:outline-none focus:border-blue-500" oninput="updateCharCount(this)">
                <div id="titleError" class="text-xs text-red-500 mt-1"></div>
                <div id="titleCharCount" class="text-sm text-gray-500 mt-2">0 / 64 karakter</div>
            </div>
            <div class="mb-6">
                <label for="description" class="block text-sm font-medium mb-2">Açıklama:</label>
                <textarea id="description" name="description" maxlength="500" class="w-full px-4 py-2 bg-gray-200 text-gray-800 border border-gray-300 rounded-lg focus:outline-none focus:border-blue-500" oninput="updateCharCount(this)"></textarea>
                <div id="charCount" class="text-sm text-gray-500 mt-2">0 / 500 karakter</div>
            </div>

            <div class="flex flex-col space-y-2 text-center">
                <button type="submit" class="w-full bg-blue-500 duration-150 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded-lg flex items-center justify-center">
                    <i class="fas fa-plus mr-1"></i> Listeyi Oluştur
                </button>
                <span class="text-xs text-zinc-400 font-semibold">Oluşturduğun listeni herkes görebilecek. Dilersen arkadaşlarınla da paylaşabileceksin.</span>
            </div>

        </form>
    </div>

    <script>
        function updateCharCount(input) {
            const maxLength = input.maxLength;
            const currentLength = input.value.length;
            const charCountElement = input.id === 'description' ? document.getElementById('charCount') : document.getElementById('titleCharCount');
            charCountElement.textContent = currentLength + ' / ' + maxLength + ' karakter';
            
            if (currentLength >= maxLength) {
                input.value = input.value.substring(0, maxLength);
                charCountElement.style.color = 'red';
            } else {
                charCountElement.style.color = '';
            }
        }

        function validateForm() {
            const titleInput = document.getElementById('title');
            const titleValue = titleInput.value.trim();
            const titleError = document.getElementById('titleError');
            const maxTitleLength = 64;

            if (titleValue.length === 0) {
                titleError.textContent = 'Başlık boş olamaz.';
                titleInput.focus();
                return false;
            } else if (titleValue.length > maxTitleLength) {
                titleError.textContent = 'Başlık en fazla ' + maxTitleLength + ' karakter olabilir.';
                titleInput.focus();
                return false;
            } else {
                titleError.textContent = '';
                return true;
            }
        }
    </script>
</body>
</html>

<?php
}
?>
