<?php
session_start();
require 'db.php';
include 'navbar.php';

// Kullanıcı oturumunun doğruluğunu kontrol et
$user_id = $_SESSION['user_id'] ?? null;

// Kullanıcının admin olup olmadığını kontrol et
function isAdmin($pdo, $user_id)
{
    $stmt = $pdo->prepare("SELECT admin FROM users WHERE id = ?");
    $stmt->execute([$user_id]);
    $user = $stmt->fetch();
    return $user && $user['admin'] == 1; // Admin ise 1
}

// Not ekleme işlemi
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if ($user_id && isAdmin($pdo, $user_id)) { // Admin kontrolü
        $title = $_POST['title'];
        $version = $_POST['version'];
        $note = $_POST['note'];
        $date = (new DateTime())->format('Y-m-d H:i:s'); // Veritabanı için doğru format

        // Görsel dosyasını işleme
        $imagePath = null;
        if (isset($_FILES['image']) && $_FILES['image']['error'] == UPLOAD_ERR_OK) {
            $imageName = basename($_FILES['image']['name']);
            $targetDir = 'uploads/';
            $targetFile = $targetDir . $imageName;

            // Görseli yükle
            if (move_uploaded_file($_FILES['image']['tmp_name'], $targetFile)) {
                $imagePath = $targetFile;
            }
        }

        // Geliştirici notunu veritabanına ekleme kodu
        $stmt = $pdo->prepare("INSERT INTO developer_notes (user_id, title, version, note, image, created_at) VALUES (?, ?, ?, ?, ?, ?)");
        $stmt->execute([$user_id, $title, $version, $note, $imagePath, $date]);
    } else {
        // Yetkisiz kullanıcı uyarısı
        $error = "Not ekleme yetkiniz yok.";
    }
}

// Geliştirici notlarını ve kullanıcı bilgilerini veritabanından çekme kodu
$stmt = $pdo->query("
    SELECT dn.*, u.username, u.profile_picture
    FROM developer_notes dn
    JOIN users u ON dn.user_id = u.id
    ORDER BY dn.created_at DESC
");
$notes = $stmt->fetchAll();

// Tarih formatını ayarlamak için Türkçe locale ayarını yap
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');
?>
<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Foxy - Geliştirici Notları</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="description" content="Foxy'in en son geliştirici notlarına göz at.">
    <meta name="keywords" content="film, dizi, foxy, foxyplatform, film kategorileri, fimler, kategoriler, foxy instagram, 9fud, ebusoft, 9fud.com, movie 9fud, geliştirici, developers, developer, geliştirici notları, gelistirici, gelistirici notlari, gelistirici notları, notlar">
    <meta property="og:image" content="/cdn/logo.png">
    <meta name="author" content="Foxy | 9FUD.COM">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <script src="https://cdn.tailwindcss.com"></script>
</head>

<body class="bg-gray-100">
    <div class="container mx-auto p-2">
        <h1 class="text-2xl font-bold mb-4 mt-4"><i class="fa-solid fa-note-sticky"></i> Geliştirici Notları</h1>

        <!-- Not ekleme formu (Sadece admin kullanıcı görebilir) -->
        <?php if ($user_id && isAdmin($pdo, $user_id)) : ?>
            <form action="" method="post" enctype="multipart/form-data" class="mb-8">
                <div class="bg-white p-6 rounded-lg shadow-md border border-gray-200 hover:border-gray-300 transition duration-300 ease-in-out">
                    <h2 class="text-xl font-semibold mb-4">Yeni Geliştirici Notu Ekle</h2>
                    <div class="mb-4">
                        <label for="title" class="block text-sm font-medium text-gray-700">Başlık:</label>
                        <input id="title" name="title" type="text" class="mt-1 block w-full border border-gray-300 rounded-md shadow-sm p-2 focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm transition duration-300 ease-in-out" required />
                    </div>
                    <div class="mb-4">
                        <label for="version" class="block text-sm font-medium text-gray-700">Sürüm:</label>
                        <input id="version" name="version" type="text" class="mt-1 block w-full border border-gray-300 rounded-md shadow-sm p-2 focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm transition duration-300 ease-in-out" required />
                    </div>
                    <div class="mb-4">
                        <label for="note" class="block text-sm font-medium text-gray-700">Geliştirici Notu:</label>
                        <textarea id="note" name="note" rows="6" class="mt-1 block w-full border border-gray-300 rounded-md shadow-sm p-2 focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm transition duration-300 ease-in-out" required></textarea>
                    </div>
                    <div class="mb-4">
                        <label for="image" class="block text-sm font-medium text-gray-700">Görsel (isteğe bağlı):</label>
                        <input id="image" name="image" type="file" accept="image/*" class="mt-1 block w-full border border-gray-300 rounded-md shadow-sm p-2 focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm transition duration-300 ease-in-out" />
                    </div>
                    <button type="submit" class="bg-blue-600 text-white px-6 py-3 rounded-md shadow-md hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 transition duration-300 ease-in-out">Notu Ekle</button>
                </div>
            </form>
        <?php else : ?>
            <?php if (isset($error)) : ?>
                <div class="bg-red-100 text-red-700 p-4 rounded-md mb-4"><?= htmlspecialchars($error) ?></div>
            <?php endif; ?>
        <?php endif; ?>

        <!-- Geliştirici notlarını göster -->
        <div class="grid grid-cols-1 md:grid-cols-2 gap-2">
            <?php foreach ($notes as $note) : ?>
                <?php
                // Tarih formatını ayarla
                $createdAt = strftime('%d %B %Y - %H:%M', strtotime($note['created_at']));
                ?>
                <div class="bg-black mx-auto text-zinc-300 p-8 rounded-lg shadow-md mb-2">
                    <div class="flex items-center gap-4 mb-2">
                        <img src="<?= htmlspecialchars($note['profile_picture']) ?>" alt="<?= htmlspecialchars($note['username']) ?>" width="48" height="48" class="rounded-full" />
                        <div>
                            <div class="flex mb-1 flex-row space-x-2 items-center">
                                <div class="text-lg font-semibold"><?= htmlspecialchars($note['username']) ?></div>
                                <span class="text-zinc-100 bg-blue-600 px-2 text-sm p-0 rounded font-semibold cursor-pointer duration-150 hover:opacity-75" data-tippy-content="Geliştirici"><i class="fa-solid fa-code"></i></span>
                                <span class="text-zinc-100 bg-red-600 px-2 text-sm p-0 rounded font-semibold cursor-pointer duration-150 hover:opacity-75" data-tippy-content="Proje Yöneticisi"><i class="fa-solid fa-diagram-project"></i></span>
                            </div>
                            <div class="text-sm text-gray-500"><?= htmlspecialchars($createdAt) ?></div>
                        </div>
                    </div>
                    <div class="flex flex-row space-x-2 items-center mb-1 mt-6">
                        <h2 class="text-xl font-bold text-zinc-300"><?= htmlspecialchars($note['title']) ?></h2>
                        <div class="text-sm text-black bg-white font-semibold px-3 rounded inline-flex"><?= htmlspecialchars($note['version']) ?></div>
                    </div>
                    <?php if (!empty($note['image'])) : ?>
                        <div class="mt-4 mb-4">
                            <img src="<?= htmlspecialchars($note['image']) ?>" alt="Görsel" class="w-full min-h-[300px] max-h-[300px] md:min-h-[300px] md:max-h-[300px] rounded-md shadow-sm" />
                        </div>
                    <?php endif; ?>
                    <div class="text-zinc-400"><?= htmlspecialchars($note['note']) ?></div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            placement: 'top',
            animation: 'shift-away'
        });
    </script>
</body>

</html>