<?php
session_start();
require 'db.php'; // Veritabanı bağlantısı

if (isset($_SESSION['is_mobile']) && $_SESSION['is_mobile'] === true) {
    header("Location: index.php");
    exit;
}

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

// Türkçe ayarları yap
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

if (isset($_GET['comment_id'])) {
    $commentId = $_GET['comment_id'];

    // Yorum bilgilerini al
    $stmt = $pdo->prepare("SELECT * FROM tv_comments WHERE id = :comment_id");
    $stmt->execute(['comment_id' => $commentId]);
    $comment = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$comment) {
        die("Böyle bir yorum bulunamadı.");
    }

    // Kullanıcıya ait yorum olup olmadığını kontrol etmek için gerektiğinde ek kontrol yapılabilir.
    if ($_SESSION['user_id'] != $comment['user_id']) {
        die("Bu yorumu düzenleme izniniz yok.");
    }

    // Düzenleme geçmişini al
    $stmt = $pdo->prepare("SELECT * FROM tv_comment_history WHERE comment_id = :comment_id ORDER BY timestamp DESC");
    $stmt->execute(['comment_id' => $commentId]);
    $history = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Yorumu güncelle
        $newContent = $_POST['content'];

        // Eski yorumu geçmişe ekle
        $stmt = $pdo->prepare("INSERT INTO tv_comment_history (comment_id, content) VALUES (:comment_id, :content)");
        $stmt->execute(['comment_id' => $commentId, 'content' => $comment['content']]);

        // Yorumu güncelle
        $stmt = $pdo->prepare("UPDATE tv_comments SET content = :content, edited = 1 WHERE id = :comment_id");
        $stmt->execute(['content' => $newContent, 'comment_id' => $commentId]);

        // Düzenleme geçmişini JSON formatında güncelle
        $history[] = [
            'timestamp' => date('Y-m-d H:i:s'),
            'content' => $newContent
        ];
        $editHistory = json_encode($history);

        // tv_comments tablosundaki edit_history sütununu güncelle
        $stmt = $pdo->prepare("UPDATE tv_comments SET edit_history = :edit_history WHERE id = :comment_id");
        $stmt->execute(['edit_history' => $editHistory, 'comment_id' => $commentId]);

        // Yorum güncellendikten sonra yönlendir
        header("Location: tv.php?id=" . $comment['tv_id']);
        exit();
    }
} else {
    die("Yorum ID'si belirtilmemiş.");
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy - Yorum Düzenle</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
</head>

<body class="bg-gray-100">
    <div class="container mx-auto p-4">
        <a href="<?php echo $_SERVER['HTTP_REFERER']; ?>" class="hover:p-2 hover:bg-transparent text-blue-500 mb-8 block bg-blue-500/10 p-4 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Geri dön</a>

        <div class="flex flex-row items-center space-x-2 mb-4">
            <h1 class="text-2xl text-gray-600 font-bold"><i class="fa-solid fa-pen-to-square"></i> Yorumu Düzenle</h1>
            <button id="openModal" class="bg-gray-200 text-gray-500 font-bold text-xs px-4 py-2 rounded-lg shadow-md hover:bg-gray-300 transition duration-300"><i class="fa-solid fa-clock-rotate-left"></i> Düzenleme Geçmişim</button>
        </div>

        <form action="" method="post" class="relative">
            <textarea name="content" rows="4" class="w-full p-4 border rounded-lg shadow-md"><?php echo htmlspecialchars($comment['content']); ?></textarea>
            <div class="p-4 py-6">
                <button type="submit" class="bg-blue-500 bottom-0 text-white absolute right-0 px-4 py-2 rounded-lg shadow-md hover:bg-blue-600 transition duration-300"><i class="fa-solid fa-check"></i> Kaydet</button>
            </div>
        </form>

        <!-- Düzenleme Geçmişi Modalı -->
        <div id="historyModal" class="fixed inset-0 z-50 hidden overflow-y-auto bg-black backdrop-blur-sm duration-150 bg-opacity-50 flex items-center justify-center">
            <div class="bg-white p-5 relative max-w-[800px] mx-auto rounded-lg shadow-md">
                <h2 class="text-2xl font-bold mb-4"><i class="fa-solid fa-clock-rotate-left"></i> Düzenleme Geçmişi</h2>
                <?php if (empty($history)) : ?>
                    <p class="text-gray-500 p-8"><i class="fa-solid fa-head-side-cough-slash"></i> Düzenleme geçmişi yok.</p>
                <?php else : ?>
                    <?php foreach ($history as $entry) : ?>
                        <div class="border-b pb-2 mb-2">
                            <p class="text-sm text-gray-500"><?php echo strftime('%e %B %Y - %H:%M', strtotime($entry['timestamp'])); ?></p>
                            <p class="mt-2"><?php echo htmlspecialchars($entry['content']); ?></p>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
                <button id="closeModal" class="bg-gray-200 text-gray-500 font-bold text-xs px-4 py-2 rounded-lg shadow-md hover:bg-gray-300 transition duration-300 absolute bottom-5 right-5"><i class="fa-solid fa-times"></i> Kapat</button>
            </div>
        </div>

        <script>
            const openModal = document.getElementById('openModal');
            const closeModal = document.getElementById('closeModal');
            const historyModal = document.getElementById('historyModal');

            openModal.addEventListener('click', () => {
                historyModal.classList.remove('hidden');
            });

            closeModal.addEventListener('click', () => {
                historyModal.classList.add('hidden');
            });
        </script>
    </div>
</body>

</html>
