<?php
// edit_list.php dosyası

require 'db.php'; // Veritabanı bağlantısı
session_start();

// Kullanıcının giriş yapmış olup olmadığını kontrol et
$userLoggedIn = isset($_SESSION['user_id']);

// Kullanıcı giriş yapmışsa, kullanıcı ID'sini al
$userId = $_SESSION['user_id'] ?? null;

include 'navbar.php'; // Başlık ve NAV

// Kullanıcı giriş yapmış mı kontrol edelim
if (!isset($_SESSION['user_id'])) {
    header('Location: login'); // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    exit;
}

// Liste ID'sini alalım
$listId = $_GET['id'] ?? null;

// Liste ID'si yoksa veya boşsa hata sayfasına yönlendir
if (!$listId) {
    header('Location: 404.php'); // Hata sayfasına yönlendir
    exit;
}

// Kullanıcının kendi listesini mi düzenlemeye çalışıyoruz kontrol edelim
$userId = $_SESSION['user_id'];
$stmt = $pdo->prepare("SELECT * FROM lists WHERE id = :list_id AND user_id = :user_id");
$stmt->execute([':list_id' => $listId, ':user_id' => $userId]);
$list = $stmt->fetch(PDO::FETCH_ASSOC);

// Listeyi bulamazsak veya kullanıcıya ait değilse hata sayfasına yönlendir
if (!$list) {
    header('Location: 404.php'); // Hata sayfasına yönlendir
    exit;
}

// Form gönderildiğinde
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = $_POST['title'] ?? '';
    $description = $_POST['description'] ?? '';

    // Form doğrulama işlemleri
    // Örneğin: Başlık ve açıklama boş olmamalı gibi kontroller yapılabilir

    // Liste güncelleme işlemi
    $stmt = $pdo->prepare("UPDATE lists SET title = :title, description = :description WHERE id = :list_id");
    $stmt->execute([':title' => $title, ':description' => $description, ':list_id' => $listId]);

    // Başarıyla güncellendiğine dair mesaj veya yönlendirme yapılabilir
    header('Location: lists.php'); // Listelerim sayfasına yönlendir
    exit;
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Liste Düzenle - Foxy</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
</head>

<body class="bg-gray-100">

    <div class="container mx-auto mt-8">
        <h1 class="text-2xl font-bold mb-4">Liste Düzenle</h1>

        <form action="" method="POST" class="max-w-lg bg-white p-6 rounded-lg shadow-md">
            <div class="mb-4">
                <label for="title" class="block text-sm font-semibold text-gray-700">Başlık</label>
                <input type="text" id="title" name="title" value="<?php echo htmlspecialchars($list['title']); ?>" class="mt-1 px-3 py-2 block w-full border border-gray-300 rounded-md shadow-sm focus:outline-none focus:border-indigo-500 focus:ring focus:ring-indigo-500 focus:ring-opacity-50" required>
            </div>
            <div class="mb-4">
                <label for="description" class="block text-sm font-semibold text-gray-700">Açıklama</label>
                <textarea id="description" name="description" rows="4" class="mt-1 px-3 py-2 block w-full border border-gray-300 rounded-md shadow-sm focus:outline-none focus:border-indigo-500 focus:ring focus:ring-indigo-500 focus:ring-opacity-50"><?php echo htmlspecialchars($list['description']); ?></textarea>
            </div>
            <div class="flex justify-end">
                <button type="submit" class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">Kaydet</button>
            </div>
        </form>
    </div>
</body>

</html>
