<?php
session_start();
require 'db.php'; // Veritabanı bağlantısı

if (isset($_SESSION['is_mobile']) && $_SESSION['is_mobile'] === true) {
    header("Location: index.php");
    exit;
}

// Oturum açmış kullanıcıyı al
$userId = $_SESSION['user_id'] ?? null;

if (!$userId) {
    // Kullanıcı oturum açmamışsa, giriş sayfasına yönlendir
    header('Location: login.php');
    exit();
}

// Kullanıcı bilgilerini çek
$stmt = $pdo->prepare("SELECT username, email, profile_picture FROM users WHERE id = :user_id");
$stmt->execute([':user_id' => $userId]);
$user = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$user) {
    // Kullanıcı bulunamazsa, çıkış yap ve giriş sayfasına yönlendir
    header('Location: logout.php');
    exit();
}

// Profil bilgilerini güncelleme
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = $_POST['username'] ?? '';
    $email = $_POST['email'] ?? '';

    // Kullanıcı adı ve e-posta adresi boş değilse, güncelle
    if (!empty($username) && !empty($email)) {
        $stmt = $pdo->prepare("UPDATE users SET username = :username, email = :email WHERE id = :user_id");
        $stmt->execute([
            ':username' => $username,
            ':email' => $email,
            ':user_id' => $userId
        ]);

        // Başarıyla güncellendiğinde profil sayfasına yönlendir
        header('Location: profile.php');
        exit();
    } else {
        // Eksik bilgi varsa hata mesajı gösterilebilir
        $error = "Kullanıcı adı ve e-posta adresi zorunludur.";
    }
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Profil Düzenle</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
</head>

<body class="bg-gray-100">
    <nav class="flex justify-between items-center py-4 bg-gray-800 text-white">
        <div class="text-2xl font-bold mx-4"><a href="/">Foxy</a></div>
        <div class="flex items-center mx-4">
            <a href="profile.php" class="px-3 py-1 rounded hover:bg-gray-600"><i class="fa-solid fa-user"></i> Profil</a>
            <a href="logout.php" class="px-3 py-1 ml-2 rounded bg-red-500 hover:bg-red-600">Çıkış Yap</a>
        </div>
    </nav>

    <div class="container w-[530px] mx-auto p-4 mt-8 relative">
        <h2 class="text-2xl font-bold mb-4"><i class="fa-solid fa-user-pen"></i> Profil Düzenle</h2>

        <?php if (isset($error)) : ?>
            <p class="text-red-500"><?php echo $error; ?></p>
        <?php endif; ?>

        <form action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']); ?>" method="POST" class="space-y-4">
            <div class="items-start flex flex-col">
                <span class="font-semibold"><i class="fa-solid fa-user"></i> Kullanıcı Adı</span>
                <span class="p-2 rounded bg-white w-full cursor-not-allowed rounded"><?php echo htmlspecialchars($user['username']); ?></span>
            </div>
            <span class="text-xs mt-2 mb-2 text-zinc-500"><i class="fa-solid fa-circle-info"></i> <strong>Foxy</strong> üzerinden henüz kullanıcı adı değiştirmek mümkün değil.</span>
            <div>
                <label for="email" class="block font-semibold"><i class="fa-solid fa-envelope"></i> E-posta Adresi</label>
                <input type="email" id="email" name="email" value="<?php echo htmlspecialchars($user['email']); ?>" class="w-full p-2 border rounded-md shadow-sm">
            </div>
            <div class="ml-auto absolute right-4">
                <button type="submit" class="bg-green-500 text-white px-4 py-2 rounded-md shadow-md hover:bg-green-600 transition duration-300"><i class="fa-solid fa-check"></i> Kaydet</button>
            </div>
        </form>
    </div>
</body>

</html>