<?php
session_start();
require 'tmdb.php'; // TMDb API işlemleri için
require 'db.php';
require 'navbar.php'; // Navbar dosyasını dahil edin
require 'duyuru.php';

$popularMovies = getPopularMovies();
$popularTvSeries = getPopularTvSeries();

// Arama sonuçlarını işle
$searchResults = [];
if (isset($_GET['search_movie']) && !empty($_GET['search_movie'])) {
    $searchTermMovie = $_GET['search_movie'];
    $searchResults['movies'] = searchMovies($searchTermMovie);
}

if (isset($_GET['search_tv']) && !empty($_GET['search_tv'])) {
    $searchTermTV = $_GET['search_tv'];
    $searchResults['tv'] = searchTVSeries($searchTermTV);
}

// Fonksiyon: Film veya dizi ziyaretini kaydet
function recordVisit($pdo, $userId, $contentType, $contentId)
{
    try {
        // Kontrol etme: Kullanıcı ve içerik zaten kaydedilmiş mi?
        $stmt = $pdo->prepare("SELECT id FROM {$contentType}_visits WHERE user_id = :user_id AND {$contentType}_id = :content_id");
        $stmt->execute(['user_id' => $userId, 'content_id' => $contentId]);
        $existingVisit = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$existingVisit) {
            // Yeni ziyaret kaydı ekle
            $stmt = $pdo->prepare("INSERT INTO {$contentType}_visits (user_id, {$contentType}_id, visit_date) VALUES (:user_id, :content_id, NOW())");
            $stmt->execute(['user_id' => $userId, 'content_id' => $contentId]);

            if ($stmt->rowCount() > 0) {
                echo "Ziyaret başarıyla kaydedildi.";
            } else {
                echo "Ziyaret kaydedilemedi.";
            }
        } else {
            echo "Bu içerik zaten ziyaret edilmiş.";
        }
    } catch (PDOException $e) {
        // Log PDOException
        error_log('PDOException: ' . $e->getMessage());
        echo "Ziyaret kaydedilemedi. Bir hata oluştu.";
    }
}

// İçerik tıklama kontrolü
if (isset($_GET['id'])) {
    $contentId = $_GET['id'];
    $contentType = '';

    // API'den içerik türünü ve detaylarını al
    $contentDetails = getMovieDetails($contentId);
    if (!$contentDetails) {
        $contentDetails = getTVShowDetails($contentId);
        $contentType = 'tv_series';
    } else {
        $contentType = 'movies';
    }

    // Ziyareti kaydet
    if (!empty($contentDetails)) {
        try {
            // Önce var mı diye kontrol edelim
            $stmt = $pdo->prepare("SELECT id FROM {$contentType} WHERE id = ?");
            $stmt->execute([$contentId]);
            $existingContent = $stmt->fetch();

            if (!$existingContent) {
                // Eğer yoksa ekleyelim
                $stmt = $pdo->prepare("INSERT INTO {$contentType} (id, title, description, release_date, poster_path) VALUES (?, ?, ?, ?, ?)");
                $stmt->execute([$contentId, $contentDetails['title'], $contentDetails['overview'], $contentDetails['release_date'], $contentDetails['poster_path']]);
            }

            // Ziyareti kaydet
            recordVisit($pdo, $_SESSION['user_id'], $contentType, $contentId);
        } catch (PDOException $e) {
            // Log PDOException
            error_log('PDOException: ' . $e->getMessage());
            echo "İçerik eklenemedi. Bir hata oluştu.";
        }
    }
}

$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f'; // TMDb API anahtarınızı buraya koyun

// Kullanıcının en son eklediği 20 favori filmi al
$userFavorites = [];
if (isset($_SESSION['user_id'])) {
    $stmt = $pdo->prepare("SELECT movie_id FROM user_favorites WHERE user_id = ? ORDER BY created_at DESC LIMIT 20");
    $stmt->execute([$_SESSION['user_id']]);
    $userFavorites = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Kullanıcının favori filmlerine göre önerileri al
$recommendedMovies = [];
foreach ($userFavorites as $favoriteMovieId) {
    $similarMovies = getSimilarMovies($favoriteMovieId, $apiKey);
    if (isset($similarMovies['results'])) {
        foreach ($similarMovies['results'] as $movie) {
            // Öneri listesinde aynı filmi tekrar eklememeye ve sadece daha yüksek puanlı filmleri seçmeye dikkat edelim
            if (!in_array($movie['id'], array_column($recommendedMovies, 'id'), true) && $movie['vote_average'] >= 6.0 && $movie['vote_count'] >= 100) {
                $recommendedMovies[] = $movie;
            }
        }
    }
}

// Önerilen filmleri benzerlik puanına göre sıralayalım (yüksekten düşüğe)
usort($recommendedMovies, function ($a, $b) {
    return $b['vote_average'] <=> $a['vote_average'];
});

// En fazla 20 filmle sınırlayalım
$recommendedMovies = array_slice($recommendedMovies, 0, 24);



$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
$nowPlayingUrl = 'https://api.themoviedb.org/3/movie/now_playing?api_key=' . $apiKey . '&language=tr-TR&page=1';

$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $nowPlayingUrl);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
$response = curl_exec($ch);
curl_close($ch);

$nowPlayingMovies = json_decode($response, true)['results'];

// İlk 6 filmi almak
$nowPlayingMovies = array_slice($nowPlayingMovies, 0, 6);


$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
$topRatedUrl = 'https://api.themoviedb.org/3/movie/top_rated?api_key=' . $apiKey . '&language=tr-TR&page=1';

$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $topRatedUrl);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
$response = curl_exec($ch);
curl_close($ch);

$topRatedMovies = json_decode($response, true)['results'];

// İlk 6 filmi almak
$topRatedMovies = array_slice($topRatedMovies, 0, 6);

// TMDb API anahtarınızı buraya ekleyin
$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
$language = 'tr-TR'; // Türkçe dil
$region = 'TR'; // Türkiye bölgesi

// API URL'sini oluşturun
$apiUrl = "https://api.themoviedb.org/3/discover/tv?api_key=$apiKey&language=$language&region=$region&sort_by=popularity.desc&with_original_language=en";

// API isteğini yapın
$response = file_get_contents($apiUrl);

$popularTvSeries = json_decode($response, true)['results'];

// Türkçe orijinal dizi olanları filtrele
$filteredTvSeries = array_filter($popularTvSeries, function ($tvSeries) {
    return $tvSeries['original_language'] === 'tr';
});


// TMDb API anahtarınızı buraya ekleyin
$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
$language = 'tr-TR'; // Türkçe dil
$region = 'TR'; // Türkiye bölgesi

// Film ve dizi API URL'lerini oluşturun
$movieApiUrl = "https://api.themoviedb.org/3/trending/movie/day?api_key=$apiKey&language=$language&region=$region";
$tvApiUrl = "https://api.themoviedb.org/3/trending/tv/day?api_key=$apiKey&language=$language&region=$region";

// API isteğini yapın
$movieResponse = file_get_contents($movieApiUrl);
$tvResponse = file_get_contents($tvApiUrl);

// Sonuçları diziye çevirin
$trendingMovies = json_decode($movieResponse, true)['results'] ?? [];
$trendingTvSeries = json_decode($tvResponse, true)['results'] ?? [];

// Filmleri ve dizileri tek bir diziye birleştir
$trendingContent = array_merge(
    array_map(function ($movie) {
        return array_merge($movie, ['type' => 'film']);
    }, $trendingMovies),
    array_map(function ($tvSeries) {
        return array_merge($tvSeries, ['type' => 'dizi']);
    }, $trendingTvSeries)
);

// İçeriği rastgele karıştırın
shuffle($trendingContent);
?>
<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy - İzle ve Yorumla</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="description" content="Foxy ile yorumlar yap ve filmleri puanla.">
    <meta name="keywords" content="film, dizi, foxy, foxyplatform, foxy instagram, 9fud, wsoft, 9fud.com, movie 9fud">
    <meta property="og:image" content="/cdn/logo.png">
    <meta name="author" content="Foxy | 9FUD.COM">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <style>
        .overlay {
            position: absolute;
            inset: 0;
            background-color: rgba(0, 0, 0, 0.75);
            opacity: 0;
            transition: opacity 0.3s ease-in-out;
            display: flex;
            justify-content: center;
            align-items: center;
        }

        .group:hover .overlay {
            opacity: 1;
        }

        #loading-bar {
            width: 100%;
            height: 3px;
            background-color: #1a202c;
            position: fixed;
            top: 0;
            left: 0;
            z-index: 9999;
        }

        #loading-bar .progress {
            height: 100%;
            width: 0;
            background: linear-gradient(123deg, #08d6a1, #2db1e9, #038dc7);
            background-size: 600% 600%;

            -webkit-animation: AnimationName 9s ease infinite;
            -moz-animation: AnimationName 9s ease infinite;
            -o-animation: AnimationName 9s ease infinite;
            animation: AnimationName 9s ease infinite;
            transition: width 0.3s ease;
        }

        @-webkit-keyframes AnimationName {
            0% {
                background-position: 0% 50%
            }

            50% {
                background-position: 100% 50%
            }

            100% {
                background-position: 0% 50%
            }
        }

        @-moz-keyframes AnimationName {
            0% {
                background-position: 0% 50%
            }

            50% {
                background-position: 100% 50%
            }

            100% {
                background-position: 0% 50%
            }
        }

        @-o-keyframes AnimationName {
            0% {
                background-position: 0% 50%
            }

            50% {
                background-position: 100% 50%
            }

            100% {
                background-position: 0% 50%
            }
        }

        @keyframes AnimationName {
            0% {
                background-position: 0% 50%
            }

            50% {
                background-position: 100% 50%
            }

            100% {
                background-position: 0% 50%
            }

        }
    </style>
</head>

<body class="bg-gray-100">

    <!-- Loading bar -->
    <div id="loading-bar">
        <div class="progress"></div>
    </div>

    <div class="container mx-auto">

        <div class="flex flex-row space-x-2">
            <!-- Film için arama kutusu -->
            <div class="flex flex-col justify-center mt-8 w-full p-2 md:p-0">
                <h1 class="font-extrabold text-zinc-600 text-2xl mb-2"><i class="fa-solid fa-clapperboard"></i> Film Ara</h1>
                <div>
                    <form action="" method="GET" class="flex w-full">
                        <input type="text" name="search_movie" placeholder="Film ara..." class="p-3 w-full border border-gray-600/20 hover:border-blue-500 duration-150 rounded-l-lg focus:outline-none focus:ring-0" value="<?php echo isset($_GET['search_movie']) ? htmlspecialchars($_GET['search_movie']) : ''; ?>">
                        <button type="submit" class="duration-150 bg-blue-500 text-white px-4 py-3 rounded-r-full hover:bg-blue-600 items-center flex flex-row"><i class="fa-solid fa-magnifying-glass"></i></button>
                    </form>
                </div>
            </div>

            <!-- Dizi için arama kutusu -->
            <div class="flex flex-col justify-center mt-8 w-full p-2 md:p-0">
                <h1 class="font-extrabold text-zinc-600 text-2xl mb-2"><i class="fa-solid fa-tv"></i> Dizi Ara</h1>
                <div>
                    <form action="" method="GET" class="flex w-full">
                        <input type="text" name="search_tv" placeholder="Dizi ara..." class="p-3 w-full border border-gray-600/20 hover:border-blue-500 duration-150 rounded-l-lg focus:outline-none focus:ring-0" value="<?php echo isset($_GET['search_tv']) ? htmlspecialchars($_GET['search_tv']) : ''; ?>">
                        <button type="submit" class="duration-150 bg-blue-500 text-white px-4 py-3 rounded-r-full hover:bg-blue-600 items-center flex flex-row"><i class="fa-solid fa-magnifying-glass"></i></button>
                    </form>
                </div>
            </div>
        </div>

        <div class="p-3 md:p-0">
            <a href="/random" class="mx-auto space-x-2 w-full hover:opacity-75 duration-150 items-center text-zinc-100 text-center justify-center font-semibold inline-flex p-4 bg-gradient-to-r from-cyan-500 to-blue-600 mt-3 rounded-3xl" data-tippy-content="Tıkla ve rastgele içerikleri gör!">
                <i class="fa-solid fa-shuffle"></i>
                <span>RASTGELE İÇERİKLER!</span>
            </a>
        </div>

        <!-- Film için arama sonuçları -->
        <?php if (!empty($searchResults['movies'])) : ?>
            <h2 class="text-2xl font-bold mb-4 mt-8">Film için arama sonuçları</h2>
            <div id="movieResults" class="grid p-2 md:p-0 grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-5 xl:grid-cols-6 gap-3 md:gap-8">
                <?php foreach ($searchResults['movies'] as $result) : ?>
                    <div class="group relative bg-white rounded overflow-hidden shadow-md">
                        <a href="movie?id=<?php echo $result['id']; ?>">
                            <img class="w-full h-auto group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $result['poster_path']; ?>" onerror="this.src='./cdn/not-image.png';" alt="<?php echo $result['title']; ?>">
                            <div class="overlay">
                                <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                    <span><?php echo $result['title']; ?></span>
                                    <span class="font-normal text-sm"><?php echo date('Y', strtotime($result['release_date'])); ?></span>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>

        <!-- Dizi için arama sonuçları -->
        <?php if (!empty($searchResults['tv'])) : ?>
            <h2 class="text-2xl font-bold mb-4 mt-8">Dizi için arama sonuçları</h2>
            <div id="tvResults" class="grid p-2 md:p-0 grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-5 xl:grid-cols-6 gap-3 md:gap-8">
                <?php foreach ($searchResults['tv'] as $result) : ?>
                    <div class="group relative bg-white rounded overflow-hidden shadow-md">
                        <a href="tv?id=<?php echo $result['id']; ?>">
                            <img class="w-full h-auto group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $result['poster_path']; ?>" onerror="this.src='./cdn/not-image.png';" alt="<?php echo $result['name']; ?>">
                            <div class="overlay">
                                <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                    <span><?php echo $result['name']; ?></span>
                                    <span class="font-normal text-sm"><?php echo date('Y', strtotime($result['first_air_date'])); ?></span>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>

        <style>
            /* Kartların genel stili */
            .card {
                position: relative;
                background-color: white;
                border-radius: 1.5rem;
                overflow: hidden;
                box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
                transition: transform 0.5s, filter 0.5s, box-shadow 0.5s;
            }

            /* Kartın üzerine gelindiğinde zoom efekti */
            .card:hover {
                transform: scale(1.05);
                z-index: 10;
            }

            /* Diğer kartların blurlu olması için kullanılan sınıf */
            .card-container {
                position: relative;
            }

            .card-container:hover .card {
                filter: blur(4px);
            }

            .card-container:hover .card:hover {
                filter: none;
            }
        </style>

        <?php
        // TMDb API Anahtarı
        $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';

        // `nowPlayingMovies` dizisi ile döngü
        if (!empty($nowPlayingMovies)) :
        ?>
            <!-- Şu Anda Sinemada Olan Filmler -->
            <div class="container mx-auto mt-16 px-4">
                <div class="text-center bg-blue-500 p-5 rounded-lg mb-10">
                    <h1 class="text-4xl font-extrabold text-zinc-100 tracking-tight"><i class="fa-solid fa-clapperboard"></i> Şu Anda Sinemada</h1>
                    <p class="text-zinc-100/90 mt-2">Gösterimdeki en popüler filmler</p>
                </div>

                <div class="card-container grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 xl:grid-cols-6 gap-5">
                    <?php foreach ($nowPlayingMovies as $index => $movie) : ?>
                        <?php
                        // Filmin TMDb ID'si
                        $movieId = $movie['id'];

                        // API isteği için URL
                        $url = "https://api.themoviedb.org/3/movie/$movieId?api_key=$apiKey&language=tr-TR";

                        // cURL ile API'den veriyi çek
                        $ch = curl_init();
                        curl_setopt($ch, CURLOPT_URL, $url);
                        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                        $response = curl_exec($ch);
                        curl_close($ch);

                        if ($response === false) {
                            $rating = 'N/A';
                        } else {
                            $data = json_decode($response, true);
                            $rating = isset($data['vote_average']) ? number_format($data['vote_average'], 1) : 'N/A';
                        }

                        // Yayın tarihini Türkçe formatta al
                        $releaseDate = date('M Y', strtotime($movie['release_date']));
                        $months = [
                            '01' => 'Oca',
                            '02' => 'Şub',
                            '03' => 'Mar',
                            '04' => 'Nis',
                            '05' => 'May',
                            '06' => 'Haz',
                            '07' => 'Tem',
                            '08' => 'Ağu',
                            '09' => 'Eyl',
                            '10' => 'Eki',
                            '11' => 'Kas',
                            '12' => 'Ara'
                        ];
                        $month = date('m', strtotime($movie['release_date']));
                        $releaseDate = str_replace(date('M', strtotime($movie['release_date'])), $months[$month], $releaseDate);
                        ?>
                        <div class="card group relative rounded-3xl overflow-hidden shadow-lg hover:shadow-2xl transition-shadow duration-500 transform hover:-translate-y-4 hover:scale-105 transition-transform duration-500">
                            <a href="movie?id=<?php echo $movie['id']; ?>" class="block">
                                <img class="w-full h-80 object-cover transition-transform duration-150 group-hover:scale-110" src="https://image.tmdb.org/t/p/w500<?php echo $movie['poster_path']; ?>" alt="<?php echo $movie['title']; ?>">
                                <div class="absolute inset-0 bg-gradient-to-t from-black via-transparent to-transparent opacity-75 group-hover:opacity-90 transition-opacity duration-500"></div>
                                <div class="absolute bottom-4 left-4 right-4 text-white">
                                    <h2 class="text-2xl font-bold"><?php echo $movie['title']; ?></h2>
                                    <p class="text-gray-300 text-sm mt-1"><?php echo $releaseDate; ?></p>
                                </div>
                                <div class="absolute bottom-4 right-0 bg-blue-500 text-white text-xs font-semibold px-3 py-1 rounded-l-full flex items-center space-x-1">
                                    <i class="fa-solid fa-star"></i>
                                    <span><?php echo $rating; ?></span>/10
                                </div>
                            </a>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

        <?php
        else :
        ?>
            <p class="text-center text-gray-600">Şu anda sinemada olan filmler bulunamadı.</p>
        <?php endif; ?>

        <!-- Günün Trendleri -->
        <div class="text-center mt-20 rounded-full bg-gradient-to-r from-yellow-200 to-orange-100 px-5 flex-col mt-8 mx-auto items-center flex justify-center">
            <div class="flex flex-row space-x-2 items-center">
                <img src="./cdn/trending.png" class="w-14" alt="">
                <h1 class="text-4xl text-zinc-700 font-extrabold">Günün Trendleri</h1>
            </div>
            <div>
                <p class="text-zinc-500 font-semibold mt-1 text-sm">Bugün popüler olan film ve dizilerden 12'si.</p>
            </div>
            <div id="trendingContent" class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 px-2 lg:grid-cols-5 xl:grid-cols-6 gap-4 mt-8">
                <?php if (!empty($trendingContent)) : ?>
                    <?php foreach (array_slice($trendingContent, 0, 12) as $index => $content) : ?>
                        <div class="group relative rounded-lg transition duration-150 overflow-hidden" id="content-<?php echo $index; ?>">
                            <a href="<?php echo $content['type'] === 'film' ? 'movie?id=' . $content['id'] : 'tv?id=' . $content['id']; ?>">
                                <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $content['poster_path']; ?>" alt="<?php echo $content['type'] === 'film' ? $content['title'] : $content['name']; ?>">
                                <div class="overlay">
                                    <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                        <span><?php echo $content['type'] === 'film' ? $content['title'] : $content['name']; ?></span>
                                        <span class="font-normal text-sm"><?php echo $content['type'] === 'film' ? date('Y', strtotime($content['release_date'])) : date('Y', strtotime($content['first_air_date'])); ?></span>
                                    </div>
                                </div>
                                <div class="absolute top-2 left-2 bg-black bg-opacity-50 text-white text-xs px-2 py-1 rounded">
                                    <?php echo strtoupper($content['type']); ?>
                                </div>
                            </a>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <p class="text-center text-gray-600">Günün trend olan film ve dizileri bulunamadı.</p>
                <?php endif; ?>
            </div>
        </div>

        <!-- En fazla oylanan filmler -->
        <div class="text-center rounded-full bg-gradient-to-r from-pink-100 to-cyan-100 px-5 flex-col mt-8 mx-auto items-center flex justify-center">
            <div class="flex flex-row space-x-2 items-center">
                <img src="./cdn/top-rating.png" class="w-14" alt="">
                <h1 class="text-4xl text-zinc-700 font-extrabold">En Fazla Oylanan (TMDB)</h1>
            </div>
            <div>
                <p class="text-zinc-500 font-semibold mt-1 text-sm">TMDB'e göre en fazla oylanan 6 film</p>
            </div>
            <div id="topRatedMovies" class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 px-2 lg:grid-cols-5 xl:grid-cols-6 gap-4 mt-8">
                <?php if (!empty($topRatedMovies)) : ?>
                    <?php foreach ($topRatedMovies as $index => $movie) : ?>
                        <div class="group relative rounded overflow-hidden" id="movie-<?php echo $index; ?>">
                            <a href="movie?id=<?php echo $movie['id']; ?>">
                                <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $movie['poster_path']; ?>" alt="<?php echo $movie['title']; ?>">
                                <div class="overlay">
                                    <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                        <span> <?php echo $movie['title']; ?></span>
                                        <span class="font-normal text-sm"><?php echo date('Y', strtotime($movie['release_date'])); ?></span>
                                    </div>
                                </div>
                            </a>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <p class="text-center text-gray-600">En fazla oylanan filmler bulunamadı.</p>
                <?php endif; ?>
            </div>
        </div>

        <div class="text-center rounded-full bg-gradient-to-r from-pink-100 to-cyan-100 px-5 flex-col mt-8 mx-auto items-center flex justify-center">
            <div class="flex flex-row space-x-2 items-center">
                <img src="./cdn/movie.png" class="w-14" alt="">
                <h1 class="text-4xl text-zinc-700 font-extrabold">Önerilen Filmler</h1>
            </div>
            <div>
                <p class="text-zinc-500 font-semibold mt-1 text-sm">Favorilerine eklediğin son filmlere göre analiz yapıp sana 24 film önerisiyle geldik!</p>
            </div>
            <?php if (!empty($recommendedMovies)) : ?>

                <div id="recommendedMovies" class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 px-2 lg:grid-cols-5 xl:grid-cols-6 gap-4 mt-8">
                    <?php foreach ($recommendedMovies as $movie) : ?>
                        <div class="group relative rounded overflow-hidden">
                            <a href="movie?id=<?php echo $movie['id']; ?>">
                                <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $movie['poster_path']; ?>" alt="<?php echo $movie['title']; ?>">
                                <div class="overlay">
                                    <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                        <span><?php echo $movie['title']; ?></span>
                                        <span class="font-normal text-sm"><?php echo date('Y', strtotime($movie['release_date'])); ?></span>
                                    </div>
                                </div>
                            </a>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php else : ?>
                <div class="text-center text-sm text-zinc-400 mt-8 mb-8 bg-white/50 p-4 rounded">
                    <?php if (!isset($_SESSION['user_id'])) : ?>
                        <i class="fa-solid fa-user-slash"></i> Giriş yapmadın. Öneri listesi için <a class="text-blue-500 font-bold hover:underline hover:opacity-75 duration-150" href="/login">Giriş yap</a> veya <a class="text-blue-500 font-bold hover:underline hover:opacity-75 duration-150" href="/register">Kayıt ol</a></span>
                    <?php else : ?>
                        <i class="fa-solid fa-road-barrier"></i> Öneri bulunamadı. Daha fazla film favori olarak ekleyerek öneri listesini güncelleyebilirsin.
                    <?php endif; ?>
                </div>
            <?php endif; ?>

        </div>



        <!-- Başlık -->
        <div class="text-center rounded-full bg-gradient-to-r from-pink-100 to-cyan-100 px-5 flex-col mt-24 mx-auto items-center flex justify-center">
            <div class="flex flex-row space-x-2 items-center">
                <img src="./cdn/film.png" class="w-14" alt="">
                <h1 class="text-4xl text-zinc-700 font-extrabold">Popüler Filmler</h1>
            </div>
            <div>
                <p class="text-zinc-500 font-semibold mt-1 text-sm">Foxy ile en çok izlenen filmleri keşfet! Yorum yap ve puanla.</p>
            </div>
        </div>

        <!-- Popüler Filmler -->
        <div id="popularMovies" class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 px-2 lg:grid-cols-5 xl:grid-cols-6 gap-4 mt-8">
            <?php if (!empty($popularMovies)) : ?>
                <?php foreach ($popularMovies as $index => $movie) : ?>
                    <div class="group relative rounded overflow-hidden" id="movie-<?php echo $index; ?>">
                        <a href="movie?id=<?php echo $movie['id']; ?>">
                            <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $movie['poster_path']; ?>" alt="<?php echo $movie['title']; ?>">
                            <div class="overlay">
                                <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                    <span> <?php echo $movie['title']; ?></span>
                                    <span class="font-normal text-sm"><?php echo date('Y', strtotime($movie['release_date'])); ?></span>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endforeach; ?>
                <div id="loadingIndicator" class="text-center mt-8 hidden">
                    <p class="text-gray-600">Yükleniyor...</p>
                </div>
            <?php else : ?>
                <p class="text-center text-gray-600">Popüler filmler yüklenemedi.</p>
            <?php endif; ?>
        </div>

        <div class="py-14">
            <!-- Başlık -->
            <div class="text-center rounded-full bg-gradient-to-r from-pink-100 to-cyan-100 px-5 flex-col mx-auto items-center flex justify-center">
                <div class="flex flex-row space-x-2 items-center">
                    <img src="./cdn/tv.png" class="w-14" alt="">
                    <h1 class="text-4xl text-zinc-700 font-extrabold">Popüler Diziler</h1>
                </div>
                <div>
                    <p class="text-zinc-500 font-semibold mt-1 text-sm">Foxy ile en çok izlenen dizileri keşfet! Yorum yap ve puanla.</p>
                </div>
            </div>
        </div>

        <!-- Popüler Diziler -->
        <div id="popularTvSeries" class="grid grid-cols-1 sm:grid-cols-2 px-2 md:grid-cols-3 lg:grid-cols-5 xl:grid-cols-6 gap-4">
            <?php if (!empty($popularTvSeries)) : ?>
                <?php foreach ($popularTvSeries as $index => $tvSeries) : ?>
                    <div class="group relative rounded overflow-hidden" id="tv-<?php echo $index; ?>">
                        <a href="tv?id=<?php echo $tvSeries['id']; ?>">
                            <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $tvSeries['poster_path']; ?>" alt="<?php echo $tvSeries['name']; ?>">
                            <div class="overlay">
                                <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                    <span> <?php echo $tvSeries['name']; ?></span>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endforeach; ?>
            <?php else : ?>
                <p class="text-center text-gray-600">Popüler diziler yüklenemedi.</p>
            <?php endif; ?>
        </div>

    </div>

    <!-- Loading bar için JavaScript -->
    <script>
        // Sayfa yükleme durumunu göstermek için
        document.addEventListener("DOMContentLoaded", function() {
            const progressBar = document.querySelector('#loading-bar .progress');
            progressBar.style.width = '100%';
            setTimeout(() => {
                progressBar.style.width = '0%';
            }, 1000);
        });
    </script>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const popularMoviesContainer = document.getElementById('popularMovies');
            const popularTvSeriesContainer = document.getElementById('popularTvSeries');
            let moviePage = 1;
            let tvSeriesPage = 1;
            let movieLoading = false;
            let tvSeriesLoading = false;

            // IntersectionObserver kullanarak filmleri ve dizileri ayrı ayrı yükleme
            const movieObserver = new IntersectionObserver(entries => {
                entries.forEach(entry => {
                    if (entry.isIntersecting && !movieLoading) {
                        movieLoading = true;
                        fetchMovies();
                    }
                });
            }, {
                threshold: 0
            });

            const tvSeriesObserver = new IntersectionObserver(entries => {
                entries.forEach(entry => {
                    if (entry.isIntersecting && !tvSeriesLoading) {
                        tvSeriesLoading = true;
                        fetchTvSeries();
                    }
                });
            }, {
                threshold: 0
            });

            movieObserver.observe(popularMoviesContainer.lastElementChild);
            tvSeriesObserver.observe(popularTvSeriesContainer.lastElementChild);

            // AJAX ile filmleri yükleme
            function fetchMovies() {
                const loadingIndicator = document.getElementById('loadingIndicator');
                loadingIndicator.classList.remove('hidden');

                fetch(`fetch_popular_movies.php?page=${moviePage}`)
                    .then(response => response.json())
                    .then(data => {
                        loadingIndicator.classList.add('hidden');

                        if (data.length > 0) {
                            data.forEach(movie => {
                                const movieHtml = `
                                    <div class="group relative bg-white rounded overflow-hidden shadow-md">
                                        <a href="movie?id=${movie.id}">
                                            <img class="w-full h-auto group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500${movie.poster_path}" alt="${movie.title}">
                                            <div class="overlay">
                                                <div class="text-white text-lg font-bold text-center">
                                                    ${movie.title}
                                                </div>
                                            </div>
                                        </a>
                                    </div>
                                `;
                                popularMoviesContainer.insertAdjacentHTML('beforeend', movieHtml);
                            });
                            moviePage++;
                            movieLoading = false;
                        } else {
                            movieObserver.unobserve(popularMoviesContainer.lastElementChild);
                        }
                    })
                    .catch(error => {
                        console.error('Error fetching movies:', error);
                        loadingIndicator.classList.add('hidden');
                    });
            }

            // AJAX ile dizileri yükleme
            function fetchTvSeries() {
                const loadingIndicator = document.getElementById('loadingIndicator');
                loadingIndicator.classList.remove('hidden');

                fetch(`fetch_popular_tv_series.php?page=${tvSeriesPage}`)
                    .then(response => response.json())
                    .then(data => {
                        loadingIndicator.classList.add('hidden');

                        if (data.length > 0) {
                            data.forEach(tvSeries => {
                                const tvSeriesHtml = `
                                    <div class="group relative bg-white rounded overflow-hidden shadow-md">
                                        <a href="tv?id=${tvSeries.id}">
                                            <img class="w-full h-auto group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500${tvSeries.poster_path}" alt="${tvSeries.name}">
                                            <div class="overlay">
                                                <div class="text-white text-lg font-bold text-center">
                                                    ${tvSeries.name}
                                                </div>
                                            </div>
                                        </a>
                                    </div>
                                `;
                                popularTvSeriesContainer.insertAdjacentHTML('beforeend', tvSeriesHtml);
                            });
                            tvSeriesPage++;
                            tvSeriesLoading = false;
                        } else {
                            tvSeriesObserver.unobserve(popularTvSeriesContainer.lastElementChild);
                        }
                    })
                    .catch(error => {
                        console.error('Error fetching TV series:', error);
                        loadingIndicator.classList.add('hidden');
                    });
            }
        });
    </script>


    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            placement: 'top',
            animation: 'shift-away'
        });
    </script>

    <?php include 'footer.php'; ?>

</body>

</html>