<?php
session_start();
require 'db.php';
require 'navbar.php';

$userLoggedIn = isset($_SESSION['user_id']);
$userId = $_SESSION['user_id'] ?? null;

$listId = $_GET['id'];

setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

$query = $pdo->prepare('SELECT lists.*, users.username FROM lists LEFT JOIN users ON lists.user_id = users.id WHERE lists.id = ?');
$query->execute([$listId]);
$list = $query->fetch(PDO::FETCH_ASSOC);

if (!$list) {
    echo '<div class="mx-auto flex justify-center mt-[43vh] text-gray-500">Aradığın liste bulunamadı. Silinmiş olabilir. Veya daha önce hiç böyle bir liste olmadı. Şizöfreni atakları geçiriyor olduğundan şüpheliyim. Bir doktora görün.</div>';
    exit;
}

$createdAt = strftime('%d %B %Y - %H:%M', strtotime($list['created_at']));

$userIp = $_SERVER['REMOTE_ADDR'];

$query = $pdo->prepare('SELECT * FROM list_views WHERE list_id = ? AND ip_address = ?');
$query->execute([$listId, $userIp]);
$visit = $query->fetch(PDO::FETCH_ASSOC);

if (!$visit) {
    $query = $pdo->prepare('INSERT INTO list_views (list_id, ip_address) VALUES (?, ?)');
    $query->execute([$listId, $userIp]);

    $query = $pdo->prepare('UPDATE lists SET views = views + 1 WHERE id = ?');
    $query->execute([$listId]);
}

$query = $pdo->prepare('SELECT * FROM list_items WHERE list_id = ?');
$query->execute([$listId]);
$listItems = $query->fetchAll(PDO::FETCH_ASSOC);

$movieDetails = [];
foreach ($listItems as $item) {
    $movieId = $item['movie_id'];
    $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
    $apiUrl = "https://api.themoviedb.org/3/movie/$movieId?api_key=$apiKey&language=tr-TR";
    $response = file_get_contents($apiUrl);
    $movieDetails[] = json_decode($response, true);
}

// Film sayısını al
$movieCount = count($movieDetails);
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="title" content="<?php echo htmlspecialchars($list['title']); ?> - Listesine göz at | Foxy">
    <meta name="description" content="<?php echo htmlspecialchars($list['username']); ?> adlı kullanıcının <?php echo htmlspecialchars($list['title']); ?> listesine bir göz at. Foxy ile sen de listelerini oluştur ve paylaş!">
    <meta name="keywords" content="foxy, liste, film listeleri, film listesi, film, listeler, listelemeler, film listeleme, film listelemesi">
    <meta name="robots" content="index, follow">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <script>
        function deleteMovie(movieId) {
            if (confirm('Bu filmi listenizden silmek istediğinizden emin misiniz?')) {
                var xhr = new XMLHttpRequest();
                xhr.open('POST', 'delete_movie.php', true);
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                xhr.onload = function() {
                    if (xhr.status === 200) {
                        // Başarılı silme işlemi
                        alert('Film başarıyla silindi.');
                        // Sayfayı yenile
                        location.reload();
                    } else {
                        alert('Silme işlemi sırasında bir hata oluştu.');
                    }
                };
                xhr.send('movie_id=' + movieId);
            }
        }

        function deleteList(listId) {
            if (confirm('Bu listeyi silmek istediğinizden emin misiniz? Bu işlem geri alınamaz!')) {
                var xhr = new XMLHttpRequest();
                xhr.open('POST', 'delete_list.php', true);
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                xhr.onload = function() {
                    if (xhr.status === 200) {
                        // Başarılı silme işlemi
                        alert('Liste başarıyla silindi.');
                        // Sayfayı yönlendir
                        window.location.href = '/'; // Ana sayfaya yönlendirme
                    } else {
                        alert('Silme işlemi sırasında bir hata oluştu.');
                    }
                };
                xhr.send('list_id=' + listId);
            }
        }
    </script>

</head>

<body class="bg-gray-100 text-black">
    <div class="container mx-auto p-4">

        <div class="">
            <h1 class="text-4xl font-bold"><?php echo htmlspecialchars($list['title']); ?></h1>
            <p class="mb-4 font-semibold"><?php echo nl2br(htmlspecialchars($list['description'])); ?></p>
        </div>

        <div class="mt-1 flex items-center flex-row space-x-2">
            <p class="text-xs cursor-pointer bg-black p-2 rounded text-white px-3 duration-150" data-tippy-content="Oluşturulma Tarihi"><i class="fa-solid fa-calendar-days mr-2"></i> <strong><?php echo $createdAt; ?></strong></p>
            <p class="text-xs cursor-pointer bg-black p-2 rounded text-white px-3 duration-150" data-tippy-content="Toplam Film Sayısı"><i class="fa-solid fa-film mr-2"></i><strong><?php echo $movieCount; ?></strong> Film </p>
            <p class="text-xs cursor-pointer bg-black p-2 rounded text-white px-3 duration-150" data-tippy-content="Görüntülenme Sayısı"><i class="fa-solid fa-eye mr-1"></i> <strong><?php echo $list['views']; ?></strong> Görüntülenme</p>
        </div>

        <?php if ($userLoggedIn && $userId === $list['user_id']) : ?>
            <div class="mt-4">
                <button onclick="deleteList(<?php echo $list['id']; ?>)" class="bg-red-500 duration-150 hover:bg-red-600 px-4 py-1 rounded text-white font-semibold"><i class="fa-solid fa-trash"></i> Listeyi Sil</button>
            </div>
        <?php endif; ?>

        <div class="mt-8">
            <!-- Profil Fotoğrafı ve Kullanıcı Adı -->
            <div class="flex bg-white p-3 rounded justify-start flex justify-between space-x-2 items-center mb-4 text-sm">

                <div class="flex flex-row space-x-2 items-center">
                    <?php
                    // Kullanıcıya ait profil fotoğrafını çekmek için user_id kullanarak bir sorgu yapın
                    $query = $pdo->prepare('SELECT username, profile_picture FROM users WHERE id = ?');
                    $query->execute([$list['user_id']]);
                    $user = $query->fetch(PDO::FETCH_ASSOC);

                    if ($user && !empty($user['profile_picture'])) {
                        echo '<img src="' . htmlspecialchars($user['profile_picture']) . '" alt="Profil Fotoğrafı" class="w-8 h-8 rounded-full">';
                    }
                    ?>
                    <p class="text-lg">
                        <strong>
                            <a href="profile.php?user_id=<?php echo $list['user_id']; ?>" class="text-blue-500 hover:underline">
                                <?php echo htmlspecialchars($user['username']); ?>
                            </a>
                        </strong>
                    </p>
                </div>

                <a href="profile.php?user_id=<?php echo $list['user_id']; ?>" class="hover:opacity-85 duration-150 text-xl font-bold text-blue-500 hover:underline" data-tippy-content="Liste sahibinin profiline göz at.">
                    Profile Git <i class="fa-solid fa-angles-right"></i>
                </a>
            </div>

            <!-- Film Listesi Sayfası -->
            <?php if (empty($movieDetails)) : ?>
                <p class="text-zinc-400 text-sm border border-zinc-600/20 p-4 rounded">Listende herhangi bir film yok. Film eklemek için <a class="hover:text-blue-300 duration-150 underline text-blue-500 font-semibold" href="/">anasayfadaki</a> arama çubuğunu kullanabilir veya <a class="hover:text-blue-300 duration-150 underline text-blue-500 font-semibold" href="/categories">kategoriler sayfasından</a> kategorilerine göre filmleri inceleyebilirsin.</p>
            <?php else : ?>
                <div class="grid gap-4 grid-cols-1 sm:grid-cols-1 md:grid-cols-1 lg:grid-cols-1" data-tippy-content="Filmin ismine tıklayarak detay sayfasına gidebilirsin">
                    <?php foreach ($movieDetails as $movie) : ?>
                        <div class="relative flex flex-row group bg-white rounded-lg shadow-md overflow-hidden mb-4">
                            <img src="<?php echo isset($movie['poster_path']) ? htmlspecialchars('https://image.tmdb.org/t/p/original' . $movie['poster_path']) : 'https://via.placeholder.com/300x450?text=Poster Yok'; ?>" alt="<?php echo htmlspecialchars($movie['title']); ?>" class="md:w-[200px] h-auto rounded mr-4">

                            <div>
                                <div class="flex-1 p-4">
                                    <h2 class="text-2xl font-extrabold mb-2">
                                        <a href="movie.php?id=<?php echo $movie['id']; ?>" class="hover:text-blue-500 duration-150">
                                            <?php echo htmlspecialchars($movie['title']); ?>
                                        </a>
                                    </h2>
                                    <p class="text-sm mb-4 font-semibold text-zinc-500"><?php echo htmlspecialchars($movie['overview']); ?></p>
                                </div>
                                <div class="flex absolute space-x-2 right-5 bottom-6 justify-between items-center">
                                    <a href="movie.php?id=<?php echo $movie['id']; ?>" class="bg-blue-500 hover:bg-blue-600 px-4 rounded text-zinc-100 font-semibold duration-150"><i class="fa-solid fa-clapperboard"></i> Detay</a>
                                    <?php if ($userLoggedIn && $userId === $list['user_id']) : ?>
                                        <button onclick="deleteMovie(<?php echo $movie['id']; ?>)" class="bg-red-500 hover:bg-red-600 px-4 rounded text-zinc-100 font-semibold duration-150"><i class="fa-solid fa-trash"></i> Sil</button>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>

    </div>

    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            placement: 'top',
            animation: 'shift-away'
        });
    </script>
</body>

</html>