<?php
// lists.php dosyası

require 'db.php'; // Veritabanı bağlantısı
session_start();

include 'navbar.php'; // Navbar dosyasını session kontrolünden sonra dahil ediyoruz


// Kullanıcı giriş yapmış mı kontrol edelim
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php'); // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    exit;
}

// Kullanıcının listelerini çek
$userId = $_SESSION['user_id'];
$stmt = $pdo->prepare("SELECT id, title FROM lists WHERE user_id = :user_id");
$stmt->execute([':user_id' => $userId]);
$lists = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Listelerim - Foxy</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://cdn.tailwindcss.com"></script>
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        .movie-thumbnails {
            display: flex;
            flex-direction: column;
            gap: 5px;
        }

        .movie-thumbnail {
            width: 100px;
            height: auto;
            border-radius: 5px;
            overflow: hidden;
        }
    </style>
</head>

<body class="bg-gray-100">

    <div class="container mx-auto mt-8 p-4">
        <h1 class="text-2xl font-bold mb-4">Listelerim</h1>

        <?php if (empty($lists)) : ?>
            <p class=" text-gray-500">Henüz bir liste oluşturmadınız.</p>
        <?php else : ?>
            <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                <?php foreach ($lists as $list) : ?>
                    <div class="relative bg-white p-4 rounded-lg shadow-md overflow-hidden transition duration-300 transform hover:scale-105">
                        <?php if (!empty($lastThreeMovies)) : ?>
                            <div class="flex items-center space-x-4">
                                <div class="movie-thumbnails">
                                    <?php foreach ($lastThreeMovies as $movie) : ?>
                                        <?php if (isset($movie['image_url'])) : ?>
                                            <img src="<?php echo htmlspecialchars($movie['image_url']); ?>" alt="<?php echo htmlspecialchars($movie['title']); ?>" class="movie-thumbnail">
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </div>
                                <div class="flex-1">
                                    <h2 class="text-lg font-semibold"><?php echo htmlspecialchars($list['title']); ?></h2>
                                </div>
                            </div>
                        <?php else : ?>
                            <h2 class="text-lg font-semibold"><?php echo htmlspecialchars($list['title']); ?></h2>
                        <?php endif; ?>

                        <a href="edit_list.php?id=<?php echo htmlspecialchars($list['id']); ?>" class="text-blue-500 hover:underline absolute top-2 right-2 z-10">Düzenle</a>
                        <!-- Listeyi düzenleme bağlantısı -->

                        <a href="list.php?id=<?php echo htmlspecialchars($list['id']); ?>" class="absolute inset-0 z-0"></a>
                        <!-- Kartın herhangi bir yerine tıklanabilir bağlantı -->
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </div>



</body>

</html>