<?php
session_start();

// Veritabanı bağlantısı ve diğer gerekli dosyaları dahil etme
require 'db.php'; // Veritabanı bağlantısı
require 'tmdb.php'; // TMDb API işlevleri

// Fonksiyon: Kullanıcı rozetleri
function getUserBadges($userId, $pdo)
{
    $stmt = $pdo->prepare("SELECT * FROM badges WHERE user_id = :user_id");
    $stmt->execute(['user_id' => $userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fonksiyon: "x zaman önce" formatında tarih gösterimi
function time_ago($datetime) {
    date_default_timezone_set('Europe/Istanbul'); // Zaman dilimini ayarla
    $now = new DateTime();
    $ago = new DateTime($datetime);
    $diff = $now->getTimestamp() - $ago->getTimestamp();

    $seconds = $diff;
    $minutes = round($seconds / 60); // value 60 is seconds
    $hours = round($seconds / 3600); // value 3600 is 60 minutes * 60 seconds
    $days = round($seconds / 86400); // value 86400 is 24 * 60 minutes * 60 seconds
    $weeks = round($seconds / 604800); // value 604800 is 7 * 24 * 60 minutes * 60 seconds

    if ($seconds <= 60) {
        return "Az önce";
    } else if ($minutes <= 60) {
        return $minutes . " dakika önce";
    } else if ($hours <= 24) {
        return $hours . " saat önce";
    } else if ($days <= 7) {
        return $days . " gün önce";
    } else if ($weeks <= 4.3) { // 4.3 == 30 / 7
        return $weeks . " hafta önce";
    } else {
        return date('d M Y', strtotime($datetime));
    }
}

// Fonksiyon: Etiket sayısını almak
function getTagCount($tag, $pdo)
{
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM tags WHERE tag = :tag");
    $stmt->execute(['tag' => $tag]);
    return $stmt->fetchColumn();
}

// Sayfa numarası ve yüklenecek yorum sayısını al
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1;
$commentsPerPage = 20; // Her sayfada gösterilecek yorum sayısı

// Başlangıç noktasını hesapla
$start = ($page - 1) * $commentsPerPage;

$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

// Türkçe ayarları yap
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

// Yorumları ve kullanıcı başına toplam yorum sayısını getirme
$stmt = $pdo->prepare("
    SELECT 
        comments.id, 
        users.id AS user_id, 
        users.username, 
        users.profile_picture, 
        users.verified,
        admin,
        comments.content, 
        comments.timestamp,
        comments.edited,
        (SELECT COUNT(*) FROM comments WHERE user_id = users.id) AS comment_count 
    FROM comments
    JOIN users ON comments.user_id = users.id
    WHERE comments.movie_id = :movie_id
    ORDER BY comments.timestamp DESC
    LIMIT :start, :commentsPerPage
");

$stmt->bindValue(':movie_id', $_GET['id'], PDO::PARAM_INT);
$stmt->bindValue(':start', $start, PDO::PARAM_INT);
$stmt->bindValue(':commentsPerPage', $commentsPerPage, PDO::PARAM_INT);
$stmt->execute();
$comments = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Yorumları HTML olarak çıktı ver
foreach ($comments as $comment) {
    // Kullanıcı rozetlerini al
    $userBadges = getUserBadges($comment['user_id'], $pdo);

    // Yorum içeriğinde etiketlerin arka planını mavi yapma ve link ekleme
    $commentContent = htmlspecialchars($comment['content']);
    $commentContent = preg_replace_callback(
        '/#(\w+)/',
        function ($matches) use ($pdo) {
            $tag = $matches[1];
            $tagCount = getTagCount($tag, $pdo);
            return '<a href="tags.php?tag=' . htmlspecialchars($tag) . '" class="bg-blue-100 rounded font-semibold hover:text-blue-500 duration-150 hover:underline text-blue-400" data-tippy-content="<strong>' . htmlspecialchars($tagCount) . '</strong> adet <strong>' . htmlspecialchars($tag) . '</strong> başlığı var">' . htmlspecialchars($matches[0]) . '</a>';
        },
        $commentContent
    );

?>
    <div class="bg-white relative shadow-md rounded-lg p-4 mb-4">
        <div class="flex items-center mb-2">
            <img src="<?= htmlspecialchars($comment['profile_picture']); ?>" alt="<?= htmlspecialchars($comment['username']); ?>" class="w-10 h-10 rounded-full mr-2">
            <div>
                <div class="flex items-center">
                    <a href="profile.php?user_id=<?= $comment['user_id']; ?>" class="font-bold"><?= htmlspecialchars($comment['username']); ?></a>
                    <p class="text-blue-400 font-semibold bg-blue-200 rounded px-2 border border-blue-500/10 text-sm ml-1">
                        <i class="fa-solid fa-comment"></i> <?= $comment['comment_count']; ?> yorum
                    </p>
                    <?php if ($comment['verified'] == 1) : ?>
                        <img src="./cdn/verified.svg" alt="Doğrulanmış Kullanıcı" class="w-5 h-5 ml-2 cursor-pointer" data-tippy-content="Doğrulanmış Kullanıcı" data-tippy-placement="top">
                    <?php endif; ?>
                    <?php if ($comment['admin'] == 1) : ?>
                        <img src="./cdn/admin.png" alt="Admin" class="w-5 h-5 ml-2 cursor-pointer" data-tippy-content="Admin" data-tippy-placement="top">
                    <?php endif; ?>
                    <?php foreach ($userBadges as $badge) : ?>
                        <img src="<?= htmlspecialchars($badge['badge_icon']); ?>" alt="<?= htmlspecialchars($badge['badge_name']); ?>" data-tippy-content="<?= htmlspecialchars($badge['badge_description']); ?>" class="w-5 h-5 ml-2 cursor-pointer" data-tippy-placement="top">
                    <?php endforeach; ?>
                </div>

                <p class="text-gray-500 text-sm" id="comment-timestamp">
                    <?= time_ago($comment['timestamp']); ?>
                </p>

            </div>
        </div>
        <p class="text-start text-zinc-500 mt-2 items-center mx-auto"><?= nl2br($commentContent); ?></p>
        <?php if (isset($_SESSION['user_id']) && $_SESSION['user_id'] === $comment['user_id']) : ?>
            <div class="mt-2 absolute bottom-3 right-3">
                <a data-tippy-content="Yorumu düzenle" href="edit_comment.php?comment_id=<?= $comment['id']; ?>" class="text-blue-500 hover:opacity-75 duration-150 bg-blue-100 rounded border border-blue-500/20 px-3 font-semibold text-sm"><i class="fa-solid fa-pen-to-square"></i> Düzenle</a>
                <a data-tippy-content="Yorumu sil (Geri alınamaz)" href="movie.php?id=<?= $_GET['id']; ?>&action=delete&comment_id=<?= $comment['id']; ?>" class="text-red-500 hover:opacity-75 duration-150 bg-red-100 rounded border border-red-500/20 px-3 font-semibold text-sm" onclick="return confirm('Yorumu silmek istediğinizden emin misiniz?')"><i class="fa-regular fa-trash-can"></i> Sil</a>
            </div>
        <?php endif; ?>
        <?php if ($comment['edited'] == 1) : ?>
            <p class="text-xs text-gray-400 mt-2">Bu yorum düzenlendi.</p>
        <?php endif; ?>

    </div>

<?php } ?>
