<?php
require 'db.php';
session_start();

// Şifremi unuttum işlemi
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['reset_email'])) {
    $reset_email = $_POST['reset_email'];

    // Kullanıcıyı bul
    $stmt = $pdo->prepare("SELECT * FROM users WHERE email = :email");
    $stmt->bindParam(':email', $reset_email);
    $stmt->execute();
    $user = $stmt->fetch();

    if ($user) {
        // Şifre sıfırlama kodu oluştur
        $reset_token = bin2hex(random_bytes(32));

        // Veritabanına sıfırlama kodunu kaydet
        $stmt = $pdo->prepare("UPDATE users SET reset_token = :reset_token, reset_token_expires_at = DATE_ADD(NOW(), INTERVAL 1 HOUR) WHERE id = :user_id");
        $stmt->execute([
            ':reset_token' => $reset_token,
            ':user_id' => $user['id']
        ]);

        // Şifre sıfırlama e-postası gönder
        $reset_link = "http://foxy.9fud.com/reset_password.php?token=" . $reset_token;
        $to = $reset_email;
        $subject = 'Şifre Sıfırlama';
        $message = "Şifrenizi sıfırlamak için aşağıdaki bağlantıya tıklayın:\n\n" . $reset_link;
        $headers = 'From: your_email@example.com' . "\r\n" .
            'Reply-To: your_email@example.com' . "\r\n" .
            'X-Mailer: PHP/' . phpversion();

        if (mail($to, $subject, $message, $headers)) {
            $reset_success = 'Şifre sıfırlama bağlantısı e-posta adresinize gönderildi.';
        } else {
            $reset_error = 'Şifre sıfırlama e-postası gönderilirken bir hata oluştu. Lütfen daha sonra tekrar deneyin.';
        }
    } else {
        $reset_error = 'Bu e-posta adresine sahip bir kullanıcı bulunamadı.';
    }
}

// Giriş işlemi
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['email'], $_POST['password'])) {
    $email = $_POST['email'];
    $password = $_POST['password'];

    $stmt = $pdo->prepare("SELECT * FROM users WHERE email = :email");
    $stmt->bindParam(':email', $email);
    $stmt->execute();
    $user = $stmt->fetch();

    if ($user && password_verify($password, $user['password'])) {
        // Kullanıcı bilgilerini al
        $user_id = $user['id'];
        $username = $user['username'];
        $profile_picture = $user['profile_picture']; // Varsa profili resmi, yoksa varsayılan resmi göstermek için

        // Kullanıcı bilgilerini çerezlere kaydet
        $cookie_expire = time() + (360 * 24 * 60 * 60); // 360 gün boyunca geçerli
        setcookie('user_id', $user_id, $cookie_expire, '/');
        setcookie('username', $username, $cookie_expire, '/');
        setcookie('profile_picture', $profile_picture, $cookie_expire, '/');

        // Oturum başlat
        $_SESSION['user_id'] = $user_id;

        // Ana sayfaya yönlendir
        header('Location: index.php');
        exit();
    } else {
        $error = 'Geçersiz email veya şifre';
    }
}

?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Giriş Yap</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    <style>
        body {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            overflow: hidden;
            /* Gereksiz kaydırmayı önlemek için */
        }

        .login-container {
            display: flex;
            width: 80%;
            max-width: 1200px;
            background-color: #fff;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            /* İçeriği sarmalamak için */
        }

        .login-right {
            flex: 1;
            padding: 40px;
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
        }

        .login-container h1 {
            font-size: 2.5rem;
            margin-bottom: 20px;
            color: #333;
            text-align: center;
        }

        .login-container form {
            width: 100%;
            max-width: 300px;
            display: flex;
            flex-direction: column;
        }

        .login-container label {
            font-size: 1.1rem;
            margin-bottom: 5px;
            color: #555;
            text-align: left;
        }

        .login-container input[type="email"],
        .login-container input[type="password"] {
            padding: 10px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            transition: border-color 0.2s;
            font-size: 1rem;
        }

        .login-container input[type="email"]:hover,
        .login-container input[type="password"]:hover {
            border-color: #eb150e;
            transition: border-color 0.2s;

        }

        .login-container button {
            background-color: #3490dc;
            color: white;
            padding: 10px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 1.1rem;
            transition: background-color 0.3s ease;
        }

        .login-container button:hover {
            background-color: #2779bd;
        }

        .error-message {
            color: red;
            margin-top: 10px;
            text-align: center;
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            background-color: rgba(255, 255, 255, 0.9);
            padding: 10px 0;
            z-index: 10;
        }

        .login-left {
            flex: 1;
            display: flex;
            justify-content: center;
            align-items: center;
            background-image: url('./cdn/deadpool_wp.gif');
            background-size: cover;
            background-position: center;
        }

        /* Mobil cihazlarda gizle */
        @media (max-width: 768px) {
            .login-left {
                display: none !important;
            }
        }

        /* Masaüstü ve daha büyük ekranlarda göster */
        @media (min-width: 768px) {
            .login-left {
                display: flex !important;
            }
        }

        .login-right {
            flex: 1;
            padding: 40px;
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
        }
    </style>
</head>

<body>
    <div class="login-container min-h-screen min-w-full relative">

        <a href="/" class="flex anasayfa justify-center hover:opacity-85 hover:text-white duration-150 items-center p-8 bg-red-700 text-zinc-200" style="background-image: url(./cdn/line.png);">
            <div class="animate__animated animate__fadeInLeft flex flex-col space-y-2 items-center">
                <i class="fa-solid fa-house-crack fa-2xl mb-8"></i>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">N</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">S</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">Y</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">F</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
            </div>
        </a>

        <div class="absolute "></div>
        <div class="relative login-left animate__animated animate__fadeIn">
            <span class="animate__animated animate__fadeInLeft absolute right-4 bottom-4 text-zinc-400 font-semibold hover:underline hover:text-zinc-100 duration-300"><a target="_blank" href="https://www.deviantart.com/ymeisnot/art/Deadpool-Wallpaper-GIF-359219653">Art by <strong>Ymeisnot</strong></a></span>
        </div>
        <div class="login-right relative animate__animated animate__fadeIn">
            <h1 class="text-3xl md:text-4xl lg:text-5xl mb-6 text-center text-gray-800 font-semibold"><i class="fa-solid fa-user-tie"></i> Giriş Yap</h1>
            <form action="login" method="post" class="w-full max-w-sm mx-auto">
                <?php if (!empty($error)) : ?>
                    <div class="error-message text-red-400 font-semibold mt-8 bg-red-100 border border-red-500/10 shadow-md rounded py-2 px-4 absolute top-0 left-1/2 transform -translate-x-1/2 -translate-y-1/2">
                        <i class="fa-solid fa-circle-exclamation"></i> <?php echo $error; ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($reset_success)) : ?>
                    <div class="success-message text-green-400 font-semibold mt-8 bg-green-100 border border-green-500/10 shadow-md rounded py-2 px-4 absolute top-0 left-1/2 transform -translate-x-1/2 -translate-y-1/2">
                        <?php echo $reset_success; ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($reset_error)) : ?>
                    <div class="error-message text-red-400 font-semibold mt-8 bg-red-100 border border-red-500/10 shadow-md rounded py-2 px-4 absolute top-0 left-1/2 transform -translate-x-1/2 -translate-y-1/2">
                        <i class="fa-solid fa-circle-exclamation"></i> <?php echo $reset_error; ?>
                    </div>
                <?php endif; ?>
                <div class="mb-4">
                    <label for="email" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-envelope"></i> Email</label>
                    <input type="email" id="email" name="email" class="w-full p-2 border-2 rounded focus:outline-none focus:border-red-500 hover:border-red-500" required>
                </div>
                <div class="mb-4">
                    <label for="password" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-lock"></i> Şifre</label>
                    <input type="password" id="password" name="password" class="w-full p-2 border-2 rounded focus:outline-none focus:border-red-500" required>
                </div>
                <div class="flex justify-between mb-4 duration-150">
                    <button type="submit" class="w-full bg-gradient-to-r from-red-600 to-red-700 text-white py-2 px-4 rounded hover:shadow-lg flex justify-between items-center focus:outline-none">
                        <span class="mx-2">Giriş Yap</span>
                        <i class="fa-solid fa-arrow-right-to-bracket mx-2"></i>
                    </button>
                </div>
                <p class="text-center text-gray-600">Hesabın yok mu? <a href="register" class="text-red-600 hover:underline font-semibold transition duration-300">Kayıt Ol</a></p>
                <p class="text-center text-gray-600 mt-2"><a href="forgot_password" class="text-red-600 hover:underline font-semibold transition duration-300">Şifremi Unuttum</a></p>
            </form>
        </div>
    </div>

</body>

</html>