<?php
session_start();
require 'PHPMailer/src/PHPMailer.php';
require 'PHPMailer/src/SMTP.php';
require 'PHPMailer/src/Exception.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\SMTP;
use PHPMailer\PHPMailer\Exception;

if (isset($_SESSION['user_id'])) {
}
$userLoggedIn = isset($_SESSION['user_id']);

// Define $userId if user is logged in
$userId = null;
if ($userLoggedIn) {
    $userId = $_SESSION['user_id'];
}

// Veritabanı bağlantısı ve diğer gerekli dosyaları dahil etme
require 'db.php'; // Veritabanı bağlantısı
require 'tmdb.php'; // TMDb API işlevleri

// Fonksiyon: TMDb'den film videolarını getir
function fetchMovieVideos($movieId)
{
    $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f'; // TMDb API anahtarı
    $url = "https://api.themoviedb.org/3/movie/$movieId/videos?api_key=$apiKey&language=tr-TR";

    // API'ye GET isteği gönderme
    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    curl_close($ch);

    // Yanıtı JSON olarak çözme
    $videos = json_decode($response, true);

    // Sadece fragmanları filtreleme
    $trailers = array_filter($videos['results'], function ($video) {
        return $video['type'] === 'Trailer';
    });

    return $trailers;
}

function addNotification($userId, $message)
{
    global $pdo;
    $stmt = $pdo->prepare("
        INSERT INTO notifications (user_id, message)
        VALUES (:user_id, :message)
    ");
    $stmt->execute(['user_id' => $userId, 'message' => $message]);
}

// Fonksiyon: Kullanıcı rozetleri
function getUserBadges($userId)
{
    global $pdo;
    $stmt = $pdo->prepare("SELECT * FROM badges WHERE user_id = :user_id");
    $stmt->execute(['user_id' => $userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

function addUserBadge($userId, $badgeName, $badgeDescription, $badgeIcon, $commentCount)
{
    global $pdo;
    $stmt = $pdo->prepare("
        INSERT INTO badges (user_id, badge_name, badge_description, badge_icon, comment_count)
        VALUES (:user_id, :badge_name, :badge_description, :badge_icon, :comment_count)
    ");
    $stmt->execute([
        'user_id' => $userId,
        'badge_name' => $badgeName,
        'badge_description' => $badgeDescription,
        'badge_icon' => $badgeIcon,
        'comment_count' => $commentCount
    ]);

    // Bildirim gönder
    $badgeName = htmlspecialchars($badgeName, ENT_QUOTES, 'UTF-8'); // XSS koruması için
    $message = "Tebrikler! <strong>$badgeName</strong> rozetini kazandınız.";
    addNotification($userId, $message);
}

// Kullanıcı giriş yapmış mı kontrol etme
$userLoggedIn = isset($_SESSION['user_id']);

// Film ID'si verildi mi kontrol etme
if (isset($_GET['id'])) {
    $movieId = $_GET['id'];
    $movie = getMovieDetails($movieId); // Film detaylarını getirme işlevi

    // Yorumları ve kullanıcı başına toplam yorum sayısını getirme
    $stmt = $pdo->prepare("
SELECT 
    comments.id, 
    users.id AS user_id, 
    users.username, 
    users.profile_picture, 
    users.verified,
    users.admin,
    comments.content, 
    comments.timestamp,
    comments.edited,
    (SELECT COUNT(*) FROM comments WHERE user_id = users.id) AS comment_count 
FROM comments
JOIN users ON comments.user_id = users.id
WHERE comments.movie_id = :movie_id
ORDER BY comments.timestamp DESC
LIMIT 20
");

    $stmt->execute(['movie_id' => $movieId]);
    $comments = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Toplam yorum sayısını hesaplama
    $stmt = $pdo->prepare("SELECT COUNT(*) as total_comments FROM comments WHERE movie_id = :movie_id");
    $stmt->execute(['movie_id' => $movieId]);
    $totalComments = $stmt->fetch(PDO::FETCH_ASSOC)['total_comments'];

    // Ortalama puanı getirme
    $stmt = $pdo->prepare("SELECT AVG(rating) as average_rating FROM ratings WHERE movie_id = :movie_id");
    $stmt->execute(['movie_id' => $movieId]);
    $averageRating = $stmt->fetch(PDO::FETCH_ASSOC)['average_rating'] ?: 0.0;

    // Film videolarını getirme
    $videos = fetchMovieVideos($movieId);
    $videoKey = !empty($videos) ? $videos[0]['key'] : null; // Mevcut ise ilk fragmanın anahtarını al

} else {
    echo "Film ID'si belirtilmemiş.";
    exit();
}

// Yorum Silme İşlemi
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['comment_id'])) {
    $commentId = $_GET['comment_id'];
    // Yorumun kullanıcıya ait olduğunu doğrulamak için ek kontroller eklenebilir.
    $stmt = $pdo->prepare("DELETE FROM comments WHERE id = :comment_id");
    $stmt->execute(['comment_id' => $commentId]);

    // Yorumu sildikten sonra sayfayı yenileme
    header("Location: movie?id=$movieId");
    exit();
}

// Kullanıcı belirli bir yorum sayısına ulaştı mı, rozet verme
if ($userLoggedIn) {
    $userId = $_SESSION['user_id'];
    $stmt = $pdo->prepare("SELECT COUNT(*) as comment_count FROM comments WHERE user_id = :user_id");
    $stmt->execute(['user_id' => $userId]);
    $commentCount = $stmt->fetch(PDO::FETCH_ASSOC)['comment_count'];

    // Yorum sayısına göre rozet kontrolü ve verme
    if ($commentCount >= 10) {
        // Kullanıcının rozetin zaten verilip verilmediğini kontrol et
        $existingBadge = getUserBadges($userId);

        // 10 Yorum Rozeti
        $badgeName10 = '10 Yorum';
        $badgeDescription10 = '10. yorumuna ulaştı';
        $badgeIcon10 = 'cdn/badge-10.png'; // Rozet ikonu URL'si

        // 50 Yorum Rozeti
        $badgeName50 = '50 Yorum';
        $badgeDescription50 = 'Vay be! 50 yorum yaptı.';
        $badgeIcon50 = 'cdn/badge-50.png'; // Rozet ikonu URL'si

        // 150 Yorum Rozeti
        $badgeName150 = '150 Yorum';
        $badgeDescription150 = 'Efsanevi! 150 yorum yaptı.';
        $badgeIcon150 = 'cdn/badge-150.png'; // Rozet ikonu URL'si

        // 500 Yorum Rozeti
        $badgeName500 = '500 Yorum';
        $badgeDescription500 = 'İnanılmaz! 500 yorum yapmayı başardı.';
        $badgeIcon500 = 'cdn/badge-500.png'; // Rozet ikonu URL'si

        // 1000 Yorum Rozeti
        $badgeName1000 = '1000 Yorum';
        $badgeDescription1000 = 'DURDURULAMAZ! 1.000 yorumunu ekledi!';
        $badgeIcon1000 = 'cdn/badge-1000.png'; // Rozet ikonu URL'si

        // 2000 Yorum Rozeti
        $badgeName2000 = '2000 Yorum';
        $badgeDescription2000 = 'BU ADAM BİR YAŞAYAN EFSANE! 2.000 YORUMU VAAR!!';
        $badgeIcon2000 = 'cdn/badge-2000.png'; // Rozet ikonu URL'si

        // Kullanıcının rozeti zaten alıp almadığını kontrol etme
        $hasBadge10 = false;
        $hasBadge50 = false;
        $hasBadge150 = false;
        $hasBadge500 = false;
        $hasBadge1000 = false;
        $hasBadge2000 = false;

        foreach ($existingBadge as $badge) {
            if ($badge['badge_name'] === $badgeName10) {
                $hasBadge10 = true;
            }
            if ($badge['badge_name'] === $badgeName50) {
                $hasBadge50 = true;
            }
            if ($badge['badge_name'] === $badgeName150) {
                $hasBadge150 = true;
            }
            if ($badge['badge_name'] === $badgeName500) {
                $hasBadge500 = true;
            }
            if ($badge['badge_name'] === $badgeName1000) {
                $hasBadge1000 = true;
            }
            if ($badge['badge_name'] === $badgeName2000) {
                $hasBadge2000 = true;
            }
        }

        // Kullanıcıda 10 Yorum Rozeti yoksa ekle
        if (!$hasBadge10) {
            addUserBadge($userId, $badgeName10, $badgeDescription10, $badgeIcon10, $commentCount);
        }

        // Kullanıcıda 50 Yorum Rozeti yoksa ekle
        if (!$hasBadge50 && $commentCount >= 50) {
            addUserBadge($userId, $badgeName50, $badgeDescription50, $badgeIcon50, $commentCount);
        }

        // Kullanıcıda 150 Yorum Rozeti yoksa ekle
        if (!$hasBadge150 && $commentCount >= 150) {
            addUserBadge($userId, $badgeName150, $badgeDescription150, $badgeIcon150, $commentCount);
        }

        // Kullanıcıda 500 Yorum Rozeti yoksa ekle
        if (!$hasBadge500 && $commentCount >= 500) {
            addUserBadge($userId, $badgeName500, $badgeDescription500, $badgeIcon500, $commentCount);
        }

        // Kullanıcıda 1000 Yorum Rozeti yoksa ekle
        if (!$hasBadge1000 && $commentCount >= 1000) {
            addUserBadge($userId, $badgeName1000, $badgeDescription1000, $badgeIcon1000, $commentCount);
        }

        // Kullanıcıda 2000 Yorum Rozeti yoksa ekle
        if (!$hasBadge2000 && $commentCount >= 2000) {
            addUserBadge($userId, $badgeName2000, $badgeDescription2000, $badgeIcon2000, $commentCount);
        }
    }
}

// Kullanıcı puanı verdi mi kontrol etme ve puanı ekleyin veya güncelleyin
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['rating']) && isset($_SESSION['user_id'])) {
    $rating = $_POST['rating'];
    $userId = $_SESSION['user_id'];

    // Film ID'si ve kullanıcı ID'si ile birlikte puanı ekleyin veya güncelleyin
    $stmt = $pdo->prepare("
        INSERT INTO ratings (movie_id, user_id, rating)
        VALUES (:movie_id, :user_id, :rating)
        ON DUPLICATE KEY UPDATE rating = :rating
    ");
    $stmt->execute([
        'movie_id' => $movieId,
        'user_id' => $userId,
        'rating' => $rating
    ]);

    // Bildirim gönderme (isteğe bağlı)
    $message = "Film için puan verdiniz: $rating/5";
    addNotification($userId, $message);

    // Yönlendirme veya mesaj gösterme (isteğe bağlı)
    header("Location: movie?id=$movieId");
    exit();
}

// Kullanıcı daha önce puan verdi mi kontrol etme
$hasRated = false;
if ($userLoggedIn) {
    $userId = $_SESSION['user_id'];
    $stmt = $pdo->prepare("SELECT * FROM ratings WHERE movie_id = :movie_id AND user_id = :user_id");
    $stmt->execute(['movie_id' => $movieId, 'user_id' => $userId]);
    $hasRated = $stmt->rowCount() > 0;
}

// Örnek veri tabanı sorgusu
$query = "SELECT rating FROM user_ratings WHERE user_id = ? AND movie_id = ?";
$stmt = $pdo->prepare($query);
$stmt->execute([$userId, $movieId]);
$userRating = $stmt->fetchColumn();


// Film ID'sini kontrol etme ve kategorileri çekme
if (isset($_GET['id']) && !empty($_GET['id'])) {
    $movieId = $_GET['id'];

    // TMDb API'den film kategorilerini çekme
    $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f'; // TMDb API anahtarınızı buraya ekleyin
    $language = 'tr-TR'; // Türkçe dil tercihi
    $endpoint = 'movie/' . $movieId;
    $url = "https://api.themoviedb.org/3/$endpoint?api_key=$apiKey&language=$language";

    // API'ye GET isteği gönderme ve yanıtı alın
    $response = file_get_contents($url);
    $movieDetails = json_decode($response, true);

    // Yanıttan kategorileri alın
    $genres = $movieDetails['genres'] ?? [];

    // Kategori isimlerini virgülle ayırarak göstermek için dizeye dönüştürme
    $genreList = implode(', ', array_column($genres, 'name'));
} else {
    echo "Film ID'si belirtilmemiş.";
    exit();
}

// CREDİTS DETAYLAR VB.
// Film ID'sini alalım ve kontrol edelim
// Çeviri fonksiyonu
function translate_role($role)
{
    $translations = [
        'voice' => 'seslendirme',
        'narrator' => 'anlatıcı',
        'director' => 'yönetmen',
        'producer' => 'yapımcı',
        'uncredited' => 'rol bilinmiyor',
        // Diğer karakter türlerini burada ekleyebilirsiniz
    ];

    return $translations[strtolower($role)] ?? $role;
}

// Film ID'sini alalım ve kontrol edelim
$movie_id = isset($_GET['id']) ? $_GET['id'] : '';

if (!empty($movie_id)) {
    // API key
    $api_key = '63fd1ed0aa746bf66c0513b79c7b2b8f';

    // API'den film bilgilerini almak için URL oluşturalım
    $api_url = "https://api.themoviedb.org/3/movie/$movie_id?api_key=$api_key&language=tr-TR";

    // CURL ile API isteği yapalım
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $api_url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($response && $http_code == 200) {
        $movie_data = json_decode($response, true);

        // Oyuncu bilgilerini almak için URL oluşturalım
        $credits_url = "https://api.themoviedb.org/3/movie/$movie_id/credits?api_key=$api_key&language=tr-TR";

        // CURL ile oyuncu bilgilerini alalım
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $credits_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $credits_response = curl_exec($ch);
        $credits_http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($credits_response && $credits_http_code == 200) {
            $credits_data = json_decode($credits_response, true);
            $cast = $credits_data['cast'];
        } else {
            $cast = [];
        }
    } else {
        $movie_data = null;
    }
} else {
    $movie_data = null;
    $cast = [];
}


// Beğeni sayısını alın
$query = $pdo->prepare("SELECT COUNT(*) FROM likes WHERE movie_id = ?");
$query->execute([$movie_id]);
$like_count = $query->fetchColumn();

$user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
$like = null;

if ($user_id) {
    // Kullanıcının bu filmi beğenip beğenmediğini kontrol edin
    $query = $pdo->prepare("SELECT * FROM likes WHERE user_id = ? AND movie_id = ?");
    $query->execute([$user_id, $movie_id]);
    $like = $query->fetch();
}

// Beğenen kullanıcıları alın
$query = $pdo->prepare("SELECT users.id, users.username, users.profile_picture FROM likes JOIN users ON likes.user_id = users.id WHERE likes.movie_id = ?");
$query->execute([$movie_id]);
$likers = $query->fetchAll();


// API'ye istek yapın ve veriyi alın
$response = file_get_contents($api_url);

// Veriyi diziye dönüştürün
$data = json_decode($response, true);

// Bütçe bilgisini alın ve virgülle formatlayın veya "Bilgi Yok" olarak ayarlayın
if (isset($data['budget'])) {
    $budget = $data['budget'] > 0 ? number_format($data['budget'], 0, ',', '.') : 'Bilgi Yok';
} else {
    $budget = 'Bilgi Yok';
}

// Süre bilgisini alın veya "Bilgi Yok" olarak ayarlayın
$runtime = isset($data['runtime']) ? $data['runtime'] : 'Bilgi Yok';

$visitor_ip = $_SERVER['REMOTE_ADDR'];
$page_id = isset($_GET['id']) ? $_GET['id'] : '';

try {
    $stmt_check_ip_page = $pdo->prepare("SELECT * FROM page_visitors WHERE page_id = ? AND ip_address = ?");
    $stmt_check_ip_page->execute([$page_id, $visitor_ip]);

    if ($stmt_check_ip_page->rowCount() == 0) {
        $stmt_insert_ip_page = $pdo->prepare("INSERT INTO page_visitors (page_id, ip_address) VALUES (?, ?)");
        $stmt_insert_ip_page->execute([$page_id, $visitor_ip]);
    }

    $stmt_visitor_count = $pdo->prepare("SELECT COUNT(DISTINCT ip_address) AS total_visitors FROM page_visitors WHERE page_id = ?");
    $stmt_visitor_count->execute([$page_id]);

    if ($stmt_visitor_count->rowCount() > 0) {
        $row = $stmt_visitor_count->fetch();
        $total_visitors = $row['total_visitors'];
    }
} catch (PDOException $e) {
    echo "Hata: " . $e->getMessage();
}


// Filmi favorilere ekleme fonksiyonu
function addToFavorites($pdo, $userId, $movieId)
{
    try {
        // Kullanıcı ve film zaten favorilerde mi kontrol et
        $stmt = $pdo->prepare("SELECT id FROM user_favorites WHERE user_id = :user_id AND movie_id = :movie_id");
        $stmt->execute(['user_id' => $userId, 'movie_id' => $movieId]);
        $existingFavorite = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$existingFavorite) {
            // Favorilere ekle
            $stmt = $pdo->prepare("INSERT INTO user_favorites (user_id, movie_id) VALUES (:user_id, :movie_id)");
            $stmt->execute(['user_id' => $userId, 'movie_id' => $movieId]);

            if ($stmt->rowCount() > 0) {
                $_SESSION['favorite_message'] = "Film başarıyla favorilere eklendi.";
            } else {
                $_SESSION['favorite_message'] = "Film favorilere eklenemedi.";
            }
        } else {
            $_SESSION['favorite_message'] = "Bu film zaten favorilerde.";
        }
    } catch (PDOException $e) {
        // Hata kaydı
        error_log('PDOException: ' . $e->getMessage());
        $_SESSION['favorite_message'] = "Favorilere eklenemedi. Bir hata oluştu.";
    }
}

// Favorilere ekleme işlemi
if (isset($_POST['add_to_favorites']) && isset($_POST['movie_id'])) {
    $movieId = $_POST['movie_id'];
    $userId = $_SESSION['user_id'];

    if ($userId) {
        addToFavorites($pdo, $userId, $movieId);
    } else {
        $_SESSION['favorite_message'] = "Favorilere eklemek için giriş yapmalısınız.";
    }
}

// Favorilerden kaldırma işlemi
if (isset($_POST['remove_from_favorites']) && isset($_POST['movie_id'])) {
    $movieId = $_POST['movie_id'];
    $userId = $_SESSION['user_id'];

    if ($userId) {
        removeFromFavorites($pdo, $userId, $movieId);
    } else {
        $_SESSION['favorite_message'] = "Favorilerden kaldırmak için giriş yapmalısınız.";
    }
}

// removeFromFavorites fonksiyonunu tanımla
function removeFromFavorites($pdo, $userId, $movieId)
{
    // Favoriden kaldırma işlemini gerçekleştir
    $stmt = $pdo->prepare("DELETE FROM user_favorites WHERE user_id = ? AND movie_id = ?");
    $stmt->execute([$userId, $movieId]);

    if ($stmt->rowCount() > 0) {
        $_SESSION['favorite_message'] = "Film favorilerden kaldırıldı.";
    } else {
        $_SESSION['favorite_message'] = "Film favorilerde bulunamadı veya kaldırılamadı.";
    }
}

// TMDB API ayarları
$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
$movieId = $movie['id'];
$apiUrl = "https://api.themoviedb.org/3/movie/$movieId/credits?api_key=$apiKey";

// API'den veri çekme
if (!empty($apiKey) && !empty($movieId)) {
    $response = file_get_contents($apiUrl);
    $data = json_decode($response, true);

    // Yapımcıları saklamak için boş bir dizi oluşturalım
    $producers = [];

    // API'den dönen veriyi işleme
    if (isset($data['crew'])) {
        foreach ($data['crew'] as $crew) {
            if ($crew['job'] === 'Producer') {
                $producers[] = $crew['name'];
            }
        }
    }
}

// API'den platform bilgilerini alacak fonksiyon
function getMoviePlatforms($movieId)
{
    // API çağrısı yaparak platform bilgilerini al
    // Bu örnekte TMDb API'sini kullandım, kendi API'nize göre düzenleyin
    $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
    $url = "https://api.themoviedb.org/3/movie/$movieId/watch/providers?api_key=$apiKey";
    $response = file_get_contents($url);
    $data = json_decode($response, true);

    // Türkiye için platform bilgilerini alın (TR bölgesine göre)
    if (isset($data['results']['TR'])) {
        return $data['results']['TR']['flatrate'] ?? [];
    }
    return [];
}


$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';

// URL'den film ID'sini almak
$movieId = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($movieId > 0) {
    $similarMoviesUrl = 'https://api.themoviedb.org/3/movie/' . $movieId . '/recommendations?api_key=' . $apiKey . '&language=tr-TR&page=1';

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $similarMoviesUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = curl_exec($ch);
    curl_close($ch);

    $similarMovies = json_decode($response, true)['results'];

    // İlk 6 filmi almak
    $similarMovies = array_slice($similarMovies, 0, 6);
} else {
    $similarMovies = [];
}


function sendNewMovieEmail($movie)
{
    // Veritabanı bağlantısı
    $conn = mysqli_connect('localhost', 'fud_ebu', '@gj9r;CnbnxH', 'fud_ebu');
    // $conn = mysqli_connect('localhost', 'root', '', 'movie_platform');
    mysqli_set_charset($conn, 'utf8mb4');

    // Tercihleri olan kullanıcıları çekme
    $sql = "SELECT user_id, email FROM email_preferences WHERE notify_new_movie = 1";
    $result = mysqli_query($conn, $sql);
    $emails = mysqli_fetch_all($result, MYSQLI_ASSOC);

    // SMTP bağlantı ayarları
    $mail = new PHPMailer(true);

    try {
        // SMTP ayarları
        $mail->isSMTP();
        $mail->Host = 'mail.9fud.com'; // SMTP sunucusu
        $mail->SMTPAuth = true;
        $mail->Username = 'noreply@9fud.com'; // SMTP kullanıcı adı
        $mail->Password = 'TMQnSTHoqzxm2_'; // SMTP şifre
        $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
        $mail->Port = 587; // TLS portu
        $mail->SMTPOptions = array(
            'ssl' => array(
                'verify_peer' => false,
                'verify_peer_name' => false,
                'allow_self_signed' => true
            )
        );

        $mail->setFrom('noreply@9fud.com', 'Foxy');

        foreach ($emails as $email) {
            $to = $email['email'];
            $mail->addAddress($to);

            $mail->isHTML(true);
            $mail->CharSet = 'UTF-8';
            $mail->Subject = "Foxy'a Yeni Film Eklendi: " . htmlspecialchars($movie['title']);

            // HTML içeriğinin güvenliğini sağlamak için özel karakterleri kaçırın
            $overview = htmlspecialchars($movie['overview']);
            $vote_average = htmlspecialchars($movie['vote_average']);
            $poster_path = htmlspecialchars($movie['poster_path']);
            $release_date = htmlspecialchars($movie['release_date']);

            // Yılı al
            $date = new DateTime($release_date);
            $year = $date->format('Y'); // Yıl formatı

            $unsubscribe_link = "https://foxy.9fud.com/unsubscribe.php?email=" . urlencode($to);
            $movie_page_link = "https://foxy.9fud.com/movie.php?id=" . htmlspecialchars($movie['id']);

            $mail->Body = "
            <html>
            <head>
            <title>Foxy'a Yeni Film Eklendi</title>
            <style>
                .button {
                    display: inline-block;
                    padding: 10px 20px;
                    font-size: 16px;
                    font-weight: bold;
                    color: #fff;
                    background-color: #007bff;
                    text-decoration: none;
                    border-radius: 5px;
                }
                .button:hover {
                    background-color: #0056b3;
                }
                .unsub {

                }
            </style>
            </head>
            <body>
            <h1>" . htmlspecialchars($movie['title']) . "  (" . $year . ")</h1>
            <img src='https://image.tmdb.org/t/p/w500" . $poster_path . "' alt='" . htmlspecialchars($movie['title']) . "'>
            <p><a href='" . $movie_page_link . "' class='button'>Filme git</a></p>
            <p>" . $overview . "</p>
            <p>Ortalama Puan (TMDB): " . $vote_average . "</p>
            <p clas='unsub'>Artık film bildirimi almak istemiyorsan <a href='" . $unsubscribe_link . "'>buraya tıkla</a> Ek olarak Profil > E-Posta Tercihleri butonundan e-posta tercihlerini yönetebilirsin.</p>
            </body>
            </html>
            ";

            $mail->send();
            $mail->clearAddresses(); // Her e-posta için adresi temizle
        }
    } catch (Exception $e) {
        echo 'E-posta gönderilirken bir hata oluştu: ', $mail->ErrorInfo;
    }

    // Bağlantıyı kapat
    mysqli_close($conn);
}

$movie_id = $_GET['id'];
$user_id = $_SESSION['user_id'];

// TMDb API anahtarınızı buraya ekleyin
$api_key = '63fd1ed0aa746bf66c0513b79c7b2b8f';

// Kullanıcının filmi izleyip izlemediğini kontrol et
$query = "SELECT watched FROM user_movies WHERE user_id = :user_id AND movie_id = :movie_id";
$stmt = $pdo->prepare($query);
$stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
$stmt->bindParam(':movie_id', $movie_id, PDO::PARAM_INT);
$stmt->execute();
$result = $stmt->fetch();
$watched = $result && $result['watched'] == 1;

// TMDb API'den film bilgilerini al
$api_url = "https://api.themoviedb.org/3/movie/$movie_id?api_key=$api_key&language=en-US";
$response = file_get_contents($api_url);
$movie_data = json_decode($response, true);

// API yanıtından backdrop_path'i al
$backdrop_path = isset($movie_data['backdrop_path']) ? $movie_data['backdrop_path'] : '';

// API'den alınan tam path ile birlikte backdrop path oluştur
$full_backdrop_path = $backdrop_path ? "https://image.tmdb.org/t/p/w500" . $backdrop_path : '';

// Giriş yapmış kullanıcı kontrolü
$is_logged_in = isset($_SESSION['user_id']); // 'user_id' oturum değişkeninin mevcut olup olmadığını kontrol eder

$user_id = $_SESSION['user_id'];

// Takip edilen kullanıcıların yorumlarını üstte göstermek için sorgu
$stmt = $pdo->prepare("
    SELECT comments.*, users.username, users.profile_picture 
    FROM comments 
    JOIN users ON comments.user_id = users.id 
    LEFT JOIN followers ON comments.user_id = followers.following_id AND followers.follower_id = ? 
    WHERE comments.movie_id = ? 
    ORDER BY followers.follower_id DESC, comments.created_at DESC
");
$stmt->execute([$user_id, $movie_id]);
$comments = $stmt->fetchAll();

$existingLists = $existingLists ?? [];
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy - <?php echo htmlspecialchars($movie['title']); ?></title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="description" content="<?php echo htmlspecialchars($movie['overview']); ?>">
    <meta name="keywords" content="film, <?php echo htmlspecialchars($movie['title']); ?>">
    <meta property="og:image" content="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($movie['poster_path']); ?>">
    <meta name="author" content="Foxy | 9FUD.COM">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            const options = {
                root: null,
                rootMargin: '0px',
                threshold: 0.1
            };

            const observer = new IntersectionObserver((entries, observer) => {
                entries.forEach(entry => {
                    if (entry.isIntersecting) {
                        entry.target.classList.add('opacity-100', 'translate-y-0');
                        observer.unobserve(entry.target);
                    }
                });
            }, options);

            document.querySelectorAll('.actor-card').forEach(card => {
                observer.observe(card);
            });
        });
    </script>
    <style>
        /* Stilizasyon için gerekli CSS */
        #loading-bar {
            width: 100%;
            height: 3px;
            background-color: #1a202c;
            position: fixed;
            top: 0;
            left: 0;
            z-index: 9999;
        }

        #loading-bar .progress {
            height: 100%;
            width: 0;
            background: linear-gradient(123deg, #08d6a1, #2db1e9, #038dc7);
            background-size: 600% 600%;

            -webkit-animation: AnimationName 9s ease infinite;
            -moz-animation: AnimationName 9s ease infinite;
            -o-animation: AnimationName 9s ease infinite;
            animation: AnimationName 9s ease infinite;
            transition: width 0.3s ease;
        }

        .overlay {
            position: absolute;
            top: 0;
            bottom: 0;
            left: 0;
            right: 0;
            height: 100%;
            width: 100%;
            opacity: 0;
            transition: opacity 0.5s ease;
            pointer-events: none;
            background-color: rgba(0, 0, 0, 0.5);
        }

        .group:hover .overlay {
            opacity: 1;
        }
    </style>
</head>

<body class="bg-gray-100">

    <!-- Navbar -->
    <?php include 'navbar.php'; ?>

    <div class="w-full z-20 text-center">
        <div class="mx-auto items-center hover:opacity-95 duration-150 bg-gradient-to-r from-indigo-600 to-indigo-700 text-zinc-300">
            <a href="https://discord.gg/Chh7gM5kY7" class="block p-3">
                <i class="fa-brands fa-discord fa-lg"></i> <strong>Discord</strong> sunucumuz açıldı! Buraya tıklayarak hemen sen de katıl.
            </a>
        </div>

        <div id="specialMessage" class="hidden font-semibold bg-black text-zinc-200 p-3 shadow-lg text-center">
            Editör, bu filme bok gibi dedi.
        </div>

        <script>
            // URL'deki id parametresini al
            const movieId = new URLSearchParams(window.location.search).get('id');

            // Eğer film ID'si 889737 ise, gizli `div`'i göster
            if (movieId === '889737') {
                document.getElementById('specialMessage').classList.remove('hidden');
            }
        </script>

    </div>


    <!-- Loading bar -->
    <div id="loading-bar">
        <div class="progress"></div>
    </div>

    <!-- Bildirim için div (favoriler) -->
    <div id="favorite-message" class="fixed top-0 right-0 left-0 w-full bg-blue-600 text-white px-4 py-3 z-500 rounded shadow-lg opacity-0 transition-opacity duration-300">
        <p id="favorite-message-text"></p>
    </div>

    <div class="container mb-24 md:mb-24 mx-auto p-2">
        <div class="container mx-auto mt-4">

            <!-- Geri Dönüş Bağlantısı -->
            <a href="/" class="hover:p-2 text-blue-500 mb-8 block hover:bg-blue-500/10 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Geri dön</a>

            <div class="">

                <div class="flex flex-col space-y-1 mt-3">
                    <span class="font-bold flex flex-row">
                        <div><span class="rounded-full bg-blue-500/10 px-3"><i class="fa-solid fa-database text-blue-800"></i></div> <span class="mx-1">Database Kontrolü <i class="fa-solid fa-info-circle text-xs ml-1 cursor-pointer text-zinc-600" data-tippy-content="Filmler API aracılığı ile çekildiği için siz film detay sayfasına gitmeden film kaydedilmez. Bu filmin durumu aşağıda mevcut"></i></span>
                    </span>
                </div>

                <div class="mt-2 container" id="php-result">
                    <?php
                    // Film ID'sini alalım
                    $movie_id = isset($_GET['id']) ? $_GET['id'] : '';

                    // Eğer film ID'si geçerliyse
                    if (!empty($movie_id)) {
                        // API key
                        $api_key = '63fd1ed0aa746bf66c0513b79c7b2b8f';

                        // API'den film bilgilerini almak için URL oluşturalım
                        $api_url = "https://api.themoviedb.org/3/movie/$movie_id?api_key=$api_key&language=tr-TR";

                        // CURL ile API isteği yapalım
                        $ch = curl_init();
                        curl_setopt($ch, CURLOPT_URL, $api_url);
                        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                        $response = curl_exec($ch);
                        curl_close($ch);

                        if ($response) {
                            $movie_data = json_decode($response, true);

                            // Film bilgilerini alalım
                            $movie_title = isset($movie_data['title']) ? $movie_data['title'] : '';
                            $movie_release_date = isset($movie_data['release_date']) ? $movie_data['release_date'] : '';
                            $movie_poster_path = isset($movie_data['poster_path']) ? $movie_data['poster_path'] : '';
                            $movie_description = isset($movie_data['overview']) ? $movie_data['overview'] : '';

                            // Kullanıcı ID'sini alalım
                            $user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;

                            // Veritabanı bağlantısını yapalım ve karakter setini ayarlayalım
                            $conn = mysqli_connect('localhost', 'fud_ebu', '@gj9r;CnbnxH', 'fud_ebu');
                            // $conn = mysqli_connect('', 'root', '', 'movie_platform');
                            mysqli_set_charset($conn, 'utf8mb4');

                            if (!$conn) {
                                echo '<div class="text-red-600 font-semibold mb-4 text-sm">Veritabanı bağlantısı başarısız: ' . mysqli_connect_error() . '</div>';
                            } else {
                                // Veritabanında film kontrolü yapalım
                                $query = "SELECT * FROM movies WHERE id = ?";
                                $stmt = mysqli_prepare($conn, $query);

                                if ($stmt) {
                                    mysqli_stmt_bind_param($stmt, 'i', $movie_id);
                                    mysqli_stmt_execute($stmt);
                                    $result = mysqli_stmt_get_result($stmt);

                                    if ($result) {
                                        if (mysqli_num_rows($result) > 0) {
                                            // Eğer film veritabanında varsa
                                            echo '<div class="text-green-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-green-500/10 px-3"><i class="fa-solid fa-wand-magic-sparkles"></i> Bu film veritabanına kayıtlı.</div>';

                                            // Kullanıcı bilgilerini ve film sayısını alalım
                                            if ($user_id) {
                                                $user_query = "SELECT users.username, users.profile_picture, COUNT(movies.id) AS total_movies 
                                FROM users 
                                LEFT JOIN movies ON users.id = movies.user_id 
                                WHERE users.id = ? 
                                GROUP BY users.id";

                                                $user_stmt = mysqli_prepare($conn, $user_query);

                                                if ($user_stmt) {
                                                    mysqli_stmt_bind_param($user_stmt, 'i', $user_id);
                                                    mysqli_stmt_execute($user_stmt);
                                                    $user_result = mysqli_stmt_get_result($user_stmt);

                                                    if ($user_result) {
                                                        if (mysqli_num_rows($user_result) > 0) {
                                                            $user_data = mysqli_fetch_assoc($user_result);
                                                            $username = isset($user_data['username']) ? $user_data['username'] : 'Bilinmiyor';
                                                            $profile_picture = isset($user_data['profile_picture']) ? $user_data['profile_picture'] : 'default-profile.png';
                                                            $total_movies = isset($user_data['total_movies']) ? $user_data['total_movies'] : 0;

                                                            echo '<div class="mt-4 flex flex-col text-sm">
                                                <span class="mb-2">Filmi kaydeden kullanıcı</span>
                                                <div class="flex flex-row space-x-1 items-center">
                                                    <a data-tippy-content="Profile git" href="profile.php?user_id=' . htmlspecialchars($user_id) . '" > <img src="' . htmlspecialchars($profile_picture) . '" alt="Profil Resmi" class="rounded-full w-8"> </a><br>
                                                    <a href="profile.php?user_id=' . htmlspecialchars($user_id) . '" class="text-gray-600 font-bold" data-tippy-content="Toplam ' . htmlspecialchars($total_movies) . ' adet film kaydetti.">' . htmlspecialchars($username) . '</a>
                                                </div>
                                            </div>';
                                                        } else {
                                                            echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> Kullanıcı bilgileri bulunamadı.</div>';
                                                        }
                                                    } else {
                                                        echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> Kullanıcı bilgileri sorgulanırken bir hata oluştu: ' . mysqli_stmt_error($user_stmt) . '</div>';
                                                    }

                                                    mysqli_stmt_close($user_stmt);
                                                } else {
                                                    echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> SQL sorgusu hazırlanırken bir hata oluştu: ' . mysqli_error($conn) . '</div>';
                                                }
                                            }
                                        } else {
                                            // Eğer film veritabanında yoksa, ekleyelim
                                            $insert_query = "INSERT INTO movies (id, title, release_date, poster_path, description, user_id) VALUES (?, ?, ?, ?, ?, ?)";
                                            $insert_stmt = mysqli_prepare($conn, $insert_query);

                                            if ($insert_stmt) {
                                                mysqli_stmt_bind_param($insert_stmt, 'issssi', $movie_id, $movie_title, $movie_release_date, $movie_poster_path, $movie_description, $user_id);
                                                if (mysqli_stmt_execute($insert_stmt)) {
                                                    echo '<div class="text-green-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-green-500/10 px-3"><i class="fa-solid fa-wand-magic-sparkles"></i> Veritabanında yoktu, sen ekledin! Tebrikler!!</div>';

                                                    // E-posta gönderim fonksiyonunu çağır
                                                    sendNewMovieEmail($movie_data);
                                                } else {
                                                    echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> Film eklenirken bir hata oluştu: ' . mysqli_stmt_error($insert_stmt) . '</div>';
                                                }

                                                mysqli_stmt_close($insert_stmt);
                                            } else {
                                                echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> SQL sorgusu hazırlanırken bir hata oluştu: ' . mysqli_error($conn) . '</div>';
                                            }
                                        }
                                    } else {
                                        echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-brands fa-searchengin"></i> Film sorgulanırken bir hata oluştu: ' . mysqli_error($conn) . '</div>';
                                    }

                                    mysqli_stmt_close($stmt);
                                } else {
                                    echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> SQL sorgusu hazırlanırken bir hata oluştu: ' . mysqli_error($conn) . '</div>';
                                }

                                mysqli_close($conn);
                            }
                        } else {
                            echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-globe"></i> API\'den film bilgileri alınamadı.</div>';
                        }
                    } else {
                        echo '<div class="text-red-500 font-semibold mb-4 text-sm"><span class="rounded-full bg-red-500/10 px-3"><i class="fa-solid fa-triangle-exclamation"></i> Film ID\'si geçersiz.</div>';
                    }
                    ?>
                </div>

            </div>

            <?php if (isset($_SESSION['like_message'])) : ?>
                <div id="like-message" class="fixed top-0 right-0 left-0 w-full bg-blue-600 text-white px-4 py-3 z-500 rounded shadow-lg opacity-0 transition-opacity duration-300">
                    <?php echo $_SESSION['like_message']; ?>
                </div>
                <script>
                    document.addEventListener("DOMContentLoaded", function() {
                        var likeMessage = document.getElementById("like-message");
                        likeMessage.classList.add('opacity-100');
                        setTimeout(function() {
                            likeMessage.remove(); // Mesajı tamamen kaldır
                        }, 4000); // 4 saniye sonra kaldır
                    });
                </script>
                <?php unset($_SESSION['like_message']); ?>
            <?php endif; ?>

            <div class="relative pt-[60px] w-full mb:pt-10 lg:pt-10 sm:pt-10">


                <div class="flex flex-col md:flex-row justify-between items-center">
                    <!-- Platform Logos -->
                    <div class="flex flex-wrap items-start mx-start gap-2 mt-4">
                        <?php
                        // API'den platform bilgilerini al
                        $platforms = getMoviePlatforms($movie['id']); // Bu fonksiyonu API çağrısı ile oluşturmalısınız
                        if (!empty($platforms)) {
                            foreach ($platforms as $platform) {
                                $providerName = htmlspecialchars($platform['provider_name'] ?? 'Bilinmiyor');
                                $logoUrl = '';

                                // Platformlara göre logo URL'leri
                                switch (strtolower($providerName)) {
                                    case 'netflix':
                                        $logoUrl = './cdn/netflix.png';
                                        break;
                                    case 'disney plus':
                                        $logoUrl = './cdn/disnep.png';
                                        break;
                                    case 'amazon prime video':
                                        $logoUrl = './cdn/prime-video.png';
                                        break;
                                    case 'apple tv':
                                        $logoUrl = './cdn/apple-tv.png';
                                        break;
                                    case 'tv+':
                                        $logoUrl = './cdn/tv-plus.png';
                                        break;
                                    case 'mubi':
                                        $logoUrl = './cdn/mubi.png';
                                        break;
                                    case 'blutv':
                                        $logoUrl = './cdn/blutv.png';
                                        break;
                                    case 'puhutv':
                                        $logoUrl = './cdn/puhutv.png';
                                        break;
                                    case 'crunchyroll':
                                        $logoUrl = './cdn/crunchyroll.png';
                                        break;
                                    case 'filmbox+':
                                        $logoUrl = './cdn/filmbox.png';
                                        break;
                                }

                                echo '<div class="flex items-center">';
                                echo '<img data-tippy-content="' . $providerName . '" src="' . $logoUrl . '" alt="' . $providerName . ' logo" class="cursor-pointer duration-150 w-8 mr-1">';
                                echo '</div>';
                            }
                        } else {
                        }
                        ?>
                    </div>

                    <!-- Diğer Bilgiler -->
                    <div class="flex gap-2 mt-4 mb-2">
                        <div class="favorite-section flex items-center">

                            <?php if (isset($_SESSION['user_id'])) : ?>
                                <form action="" method="POST" class="flex items-center">
                                    <input type="hidden" name="movie_id" value="<?php echo htmlspecialchars($movieId); ?>">
                                    <?php
                                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM user_favorites WHERE user_id = ? AND movie_id = ?");
                                    $stmt->execute([$_SESSION['user_id'], $movieId]);
                                    $isFavorite = $stmt->fetchColumn();
                                    ?>
                                    <?php if ($isFavorite > 0) : ?>
                                        <button data-tippy-content="Favorilerden kaldır" type="submit" name="remove_from_favorites" class="favorite-button py-1 text-xs md:text-sm lg:text-sm xl:text-sm sm:text-sm text-zinc-400 bg-black lg:p-2 xl:p-2 sm:p-2 md:p-2 px-4 rounded font-semibold hover:opacity-75 duration-150 cursor-pointer">
                                            <i class="fa-solid fa-star"></i> Favorilerden kaldır
                                        </button>
                                    <?php else : ?>
                                        <button data-tippy-content="Favorilere ekle" type="submit" name="add_to_favorites" class="favorite-button text-xs py-1 md:text-sm lg:text-sm xl:text-sm sm:text-sm text-zinc-400 bg-black lg:p-2 xl:p-2 sm:p-2 md:p-2 px-4 rounded font-semibold hover:opacity-75 duration-150 cursor-pointer">
                                            <i class="fa-solid fa-star"></i> Favorilere ekle
                                        </button>
                                    <?php endif; ?>
                                </form>
                            <?php endif; ?>
                        </div>

                        <div class="relative flex items-center">
                            <p class="text-sm text-zinc-400 bg-black p-2 px-4 rounded font-semibold hover:opacity-75 duration-150 cursor-pointer" data-tippy-content="Bu filmin toplam görüntülenme sayısı">
                                <i class="fa-solid fa-eye text-white mr-1"></i>
                                Bu film toplam <strong class="font-extrabold"><?php echo $total_visitors; ?></strong> kez görüntülendi
                            </p>
                        </div>

                        <div class="relative flex items-center">
                            <p class="text-sm text-zinc-400 bg-black p-2 px-4 rounded font-semibold hover:opacity-75 duration-150 cursor-pointer" onclick="openLikemodal()" data-tippy-content="Beğenenleri gör">
                                <i class="fa-solid fa-heart mr-1 text-red-500"></i>
                                <strong class="font-extrabold"><?php echo $like_count; ?></strong> kez beğenildi
                            </p>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Banner ve Poster -->
            <div class="relative flex mx-auto items-center justify-center flex-row w-full">

                <!-- Poster -->
                <div class="hidden md:block relative z-30">
                    <img src="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($movie['poster_path']); ?>" onerror="this.src='https://placehold.co/600x1080?text=IMAGE+NOT+FOUND!';" alt="<?php echo htmlspecialchars($movie['title']); ?>" class="w-[330px] h-[430px] object-cover rounded-l-lg shadow-md">
                </div>

                <!-- Banner ve içerik -->
                <div class="relative w-full md:flex md:items-center md:justify-center">
                    <!-- Banner -->
                    <div class="relative w-full">
                        <img src="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($movie['backdrop_path']); ?>" alt="<?php echo htmlspecialchars($movie['title']); ?>" onerror="this.onerror=null; this.src='https://placehold.co/200x200?font=montserrat&text=Bu%20i%C3%A7eri%C4%9Fin%20arka%20plan%C4%B1%20yok.'; this.alt='Resim bulunamadı';" class="w-full h-96 md:h-[430px] object-cover rounded-r-lg shadow-md">

                        <!-- Siyah Overlay -->
                        <div class="absolute w-full min-h-full inset-0 bg-black opacity-50 rounded-lg"></div>

                        <!-- Banner içeriği -->
                        <div class="absolute bottom-0 left-0 right-0 p-4 md:p-8 bg-opacity-80 bg-black">
                            <span class="text-blue-500/80 bg-black/10 border border-blue-500/30 px-3 rounded font-semibold text-xs sm:text-sm md:text-base"><?php echo date('Y', strtotime($movie['release_date'])); ?></span>
                            <h1 class="text-2xl sm:text-3xl md:text-4xl font-bold text-white mt-5 md:mt-0"><?php echo htmlspecialchars($movie['title']); ?></h1>

                            <!-- Açıklama -->
                            <p class="text-zinc-300 relative font-semibold shadow-md mt-2 text-xs sm:text-sm md:text-base">
                                <?php
                                $overview = $movie['overview'];
                                $overview_mobile = mb_strlen($overview) > 290 ? htmlspecialchars(mb_substr($overview, 0, 290)) . '... <a href="https://www.themoviedb.org/movie/' . $movie['id'] . '" class="text-blue-500 hover:underline" target="_blank" rel="noopener noreferrer">Daha fazla bilgi</a>' : htmlspecialchars($overview);
                                $overview_pc = mb_strlen($overview) > 590 ? htmlspecialchars(mb_substr($overview, 0, 590)) . '... <a href="https://www.themoviedb.org/movie/' . $movie['id'] . '" class="text-blue-500 hover:underline" target="_blank" rel="noopener noreferrer">Daha fazla bilgi</a>' : htmlspecialchars($overview);
                                ?>
                                <span class="block md:hidden"><?php echo $overview_mobile; ?></span>
                                <span class="hidden md:block"><?php echo $overview_pc; ?></span>
                            </p>

                            <div class="items-start mx-auto text-center flex-col space-y-2 flex justify-center mt-2">
                                <p class="text-zinc-200 mt-3 rounded text-xs sm:text-sm md:text-base"> <i class="text-yellow-500 fa-solid fa-star"></i> Ortalama Puan: <span class="text-yellow-500"><?php echo number_format($averageRating, 1); ?>/10</span></p>
                                <p class="text-zinc-200 mt-3 rounded text-xs sm:text-sm md:text-base"><i class="text-green-500 fa-solid fa-dollar-sign"></i> Bütçe: <span class="text-green-500 font-semibold"><?php echo $budget; ?></span></p>
                                <p class="text-zinc-200 mt-3 rounded text-xs sm:text-sm md:text-base"><i class="text-blue-500 fa-solid fa-clock"></i> Süre: <span class="text-blue-500 font-semibold"><?php echo $runtime; ?> dakika</span></p>
                                <?php if (!empty($producers)) : ?>
                                    <p class="text-zinc-200 mt-3 rounded text-xs sm:text-sm md:text-base"><i class="text-red-500 fa-solid fa-user"></i> Yapımcı: <span class="text-red-500 font-semibold"><?php echo htmlspecialchars(implode(', ', $producers)); ?></span></p>
                                <?php endif; ?>
                            </div>


                            <!-- Kategorileri görüntüleme -->
                            <div class="flex flex-wrap mt-4">
                                <?php foreach ($genres as $genre) : ?>
                                    <span class="bg-white text-black px-2 py-1 rounded text-xs font-bold mr-1 mb-2"><i class="fa-solid fa-hashtag"></i> <?php echo htmlspecialchars($genre['name']); ?></span>
                                <?php endforeach; ?>
                            </div>
                        </div>

                    </div>

                    <div class="flex flex-row mt-2 mb-2">

                        <div class="relative flex flex-row space-x-2 md:absolute md:right-[25%] md:bottom-8">
                            <?php if ($is_logged_in) : ?>
                                <button class="py-2 px-4 text-sm items-center hover:opacity-75 rounded md:bg-white flex flex-row space-x-1 duration-300 font-semibold" id="watch-button">
                                    <div class="flex flex-row space-x-1 items-center">
                                        <i class="fa-solid <?php echo $watched ? 'fa-eye' : 'fa-eye-slash'; ?>"></i>
                                        <span><?php echo $watched ? 'İzledim' : 'İzlemedim'; ?></span>
                                    </div>
                                </button>
                            <?php endif; ?>
                        </div>

                        <div id="watching-message" class="fixed top-0 right-0 left-0 w-full bg-blue-600 text-white px-4 py-3 z-50 rounded shadow-lg opacity-0 transition-opacity duration-300">
                            <p id="watching-message-text"></p>
                        </div>


                        <script>
                            $(document).ready(function() {
                                $('#watch-button').click(function() {
                                    var movie_id = <?php echo $movie_id; ?>;
                                    var backdrop_path = "<?php echo $backdrop_path; ?>";

                                    $.ajax({
                                        url: 'watched_button.php',
                                        type: 'POST',
                                        data: {
                                            movie_id: movie_id,
                                            backdrop_path: backdrop_path
                                        },
                                        success: function(response) {
                                            var data = JSON.parse(response);
                                            var messageText = data.watched ? 'Film izleme listesine eklendi.' : 'Film izleme listesinden çıkarıldı.';

                                            // İzleme mesajını güncelle
                                            $('#watching-message-text').text(messageText);
                                            $('#watching-message').removeClass('opacity-0').addClass('opacity-100');

                                            setTimeout(function() {
                                                $('#watching-message').removeClass('opacity-100').addClass('opacity-0');
                                            }, 3000);

                                            // Buton metnini güncelle
                                            var buttonIcon = data.watched ? 'fa-eye' : 'fa-eye-slash';
                                            var buttonText = data.watched ? 'İzledim' : 'İzlemedim';
                                            $('#watch-button').find('i').attr('class', 'fa-solid ' + buttonIcon);
                                            $('#watch-button').find('span').text(buttonText);
                                        }
                                    });
                                });
                            });
                        </script>

                        <div class="relative flex flex-row space-x-2 md:absolute md:right-[13%] md:bottom-8">
                            <?php if (isset($_SESSION['user_id'])) : ?>
                                <form method="post" action="like.php" class="">
                                    <input type="hidden" name="movie_id" value="<?php echo $movieId; ?>">
                                    <button type="submit" name="like" class="bg-blue-500 text-white px-4 text-sm py-2 rounded hover:opacity-70 transition duration-150">
                                        <i class="fas <?php echo $like ? 'fa-heart-crack' : 'fa-heart'; ?>"></i>
                                        <?php echo $like ? "Beğeniyi Kaldır" : "Beğen"; ?>
                                    </button>
                                </form>
                            <?php endif; ?>
                        </div>

                        <div class="relative flex flex-row space-x-2 md:absolute md:right-[2%] md:bottom-8">
                            <button id="addToMyListBtn" data-tippy-content="Listene eklemek için tıkla. Merak etme, eğer bir listen yoksa oluşturabilirsin. Ama unutma ki bu özellik BETA'da ve henüz geliştiriliyor. Problemler yaşaman normal. Herhangi bir problem yaşadığında bize Discord sunucumuzdan bildirerek rozetler kazanabilirsin." class="py-2 px-4 items-center hover:opacity-75 rounded md:bg-white flex flex-row space-x-2 duration-300 font-semibold <?php echo !isset($_SESSION['user_id']) ? 'md:bg-gray-300 text-gray-600 cursor-not-allowed' : ''; ?>" <?php echo isset($_SESSION['user_id']) ? 'onclick="showModal(); event.stopPropagation();"' : ''; ?>>
                                <i class="fa-solid fa-plus bg-clip-text text-sm text-transparent bg-gradient-to-r from-cyan-500 to-blue-500 font-bold"></i>
                                <span class="bg-clip-text text-sm text-transparent bg-gradient-to-r from-cyan-500 to-blue-500 font-bold">
                                    <?php echo !isset($_SESSION['user_id']) ? 'Listeye eklemek için giriş yap' : 'Listeye Ekle'; ?>
                                </span>
                            </button>
                        </div>
                    </div>

                    <!-- Modal -->
                    <div id="listModal" class="p-2 transition-opacity fixed backdrop-blur-sm transition-all duration-300 z-50 inset-0 overflow-y-auto" style="display:none;">


                        <!-- Bildirim için div (film listeye ekleme) -->
                        <div id="add-to-list-message" class="fixed top-0 right-0 left-0 w-full bg-blue-600 text-white px-4 py-3 z-1000 rounded shadow-lg opacity-0 transition-opacity duration-300">
                            <p id="add-to-list-message-text"></p>
                        </div>

                        <div class="flex items-center justify-center min-h-screen">
                            <div class="bg-white p-5 rounded-lg shadow-lg">
                                <h2 class="text-2xl"><i class="fa-solid fa-rectangle-list"></i> Listeye Ekle</h2>
                                <span class="text-xs text-zinc-500">Aşağıdan listeni seç. Eğer listen yoksa oluşturabilirsin.</span>

                                <div id="existingLists" class="mb-4 mt-4 border rounded-lg p-4">
                                    <h3 class="text-lg font-bold mb-2">Mevcut Listeleriniz</h3>
                                    <ul class="divide-y divide-gray-300">
                                        <?php foreach ($existingLists as $list) : ?>
                                            <li class="py-2 flex items-center justify-between">
                                                <a href="list.php?id=<?php echo htmlspecialchars($list['id']); ?>" class="text-blue-500 hover:underline">
                                                    <span class="font-bold"><?php echo htmlspecialchars($list['title']); ?></span>
                                                </a>
                                                <button onclick="addToList(<?php echo $list['id']; ?>)" class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-1 px-3 rounded focus:outline-none">
                                                    Ekle <i class="fas fa-plus-circle ml-1"></i>
                                                </button>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                    <?php if (empty($existingLists)) : ?>
                                        <p class="text-sm text-gray-500 mt-2">Henüz listeniz bulunmamaktadır.</p>
                                    <?php endif; ?>
                                </div>

                                <button onclick="createNewList()" class="bg-green-500 hover:bg-opacity-85 duration-150 rounded p-2 px-4 mr-2" data-tippy-content="Yeni bir liste oluştur">
                                    <span class="text-zinc-200 font-semibold "><i class="fa-solid fa-plus"></i> Yeni Liste Oluştur</span>
                                </button>
                                <button onclick="addToList()" class="bg-blue-500 hover:bg-opacity-85 duration-150 rounded p-2 px-4 mr-2" data-tippy-content="Varolan bir listeye ekle (yukarıdan listelerini görebilirsin)">
                                    <span class="text-zinc-200 font-semibold "><i class="fa-solid fa-list-check"></i> Listeye Ekle</span>
                                </button>
                                <button onclick="closeModal()" class="bg-gray-700 hover:bg-opacity-85 duration-150 rounded p-2 px-4 mr-2">
                                    <span class="text-zinc-200 font-semibold "><i class="fa-solid fa-xmark"></i> İptal</span>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div id="likeModal" class="hidden backdrop-blur-sm fixed z-10 inset-0 overflow-y-auto">
                <div class="flex items-center justify-center min-h-screen">
                    <div class="fixed inset-0 transition-opacity" aria-hidden="true">
                        <div class="absolute inset-0 opacity-75"></div>
                    </div>

                    <div class="bg-white rounded-lg overflow-hidden shadow-xl transform transition-all max-w-lg w-full p-6">
                        <div class="flex justify-between items-center mb-4">
                            <h3 class="text-lg leading-6 font-medium text-gray-900">Bu filmi beğenenler</h3>
                            <button class="text-gray-400 hover:text-gray-500" data-tippy-content="Kapat" onclick="CloseLikeModal()">
                                <span class="sr-only">Close</span>
                                <i class="fa-solid fa-times"></i>
                            </button>
                        </div>
                        <div class="space-y-4">
                            <?php foreach ($likers as $liker) : ?>
                                <a href="profile.php?user_id=<?php echo $liker['id']; ?>" class="flex bg-zinc-100 rounded p-2 hover:bg-gray-300 duration-150 items-center space-x-2 hover:text-blue-500">
                                    <img class="w-10 h-10 rounded-full" src="<?php echo htmlspecialchars($liker['profile_picture']); ?>" alt="<?php echo htmlspecialchars($liker['username']); ?>">
                                    <div class="font-bold text-zinc-600" data-tippy-content="Profile git"><?php echo htmlspecialchars($liker['username']); ?></div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="mb-6 mt-6">


            <div>
                <?php if ($userLoggedIn) : ?>
                    <?php if ($hasRated) : ?>
                        <p class="text-gray-400"><i class="fa-solid fa-star-half-stroke"></i> Zaten puan verdiniz.</p>
                    <?php else : ?>
                        <form action="add_rating.php" method="POST" class="flex items-center">
                            <input type="hidden" name="movie_id" value="<?php echo htmlspecialchars($movieId); ?>">
                            <label for="rating" class="mr-2">Bu içeriğe puan verin:</label>
                            <select name="rating" id="rating" class="py-1 px-2 border border-gray-300 rounded-md focus:outline-none focus:border-blue-500">
                                <option value="1">1 yıldız</option>
                                <option value="2">2 yıldız</option>
                                <option value="3">3 yıldız</option>
                                <option value="4">4 yıldız</option>
                                <option value="5">5 yıldız</option>
                            </select>
                            <button type="submit" class="ml-2 px-4 py-1 bg-blue-500 text-white rounded-md hover:bg-blue-600 focus:outline-none">
                                <i class="fa-solid fa-star"></i> Puan Ver
                            </button>
                        </form>
                    <?php endif; ?>
                <?php else : ?>
                    <p class="mt-4 mb-4">Filmlere puan verebilmek için <a href="login.php" class="text-blue-500">giriş yapmanız</a> gerekiyor.</p>
                <?php endif; ?>
            </div>
        </div>

        <?php
        require_once 'db.php';
        $movieId = $_GET['id'] ?? null;
        $hasParody = false;
        if ($movieId) {
            $stmt = $pdo->prepare('SELECT * FROM parodies WHERE movie_id = ?');
            $stmt->execute([$movieId]);
            $parody = $stmt->fetch();
            if ($parody) {
                $hasParody = true;
            }
        }
        if ($hasParody) : ?>
                <h2 class="text-3xl font-bold mb-4 text-center text-zinc-800"><?php echo htmlspecialchars($movie['title']); ?> - Eleştirel Parodi</h2>
                <div class="flex mb-4 items-center justify-center">
                    <iframe class="rounded-lg" width="100%" height="640" src="<?php echo $parody['video_url']; ?>" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                </div>
        <?php endif; ?>

        <!-- Fragman -->
        <?php if (!empty($videoKey)) : ?>
            <div class="mb-8">
                <div class="relative" style="padding-top: 33.25%;">
                    <iframe src="https://www.youtube.com/embed/<?php echo htmlspecialchars($videoKey); ?>?rel=0&amp;showinfo=0" frameborder="0" allowfullscreen class="absolute inset-0 w-full h-full rounded-lg"></iframe>
                </div>
            </div>
        <?php endif; ?>

        <?php if ($movie_data) : ?>
            <div class="flex flex-row space-x-2 items-center mb-8">
                <h2 class="text-3xl font-extrabold"><i class="fa-solid fa-users-line"></i> Kadro</h2>
            </div>
            <ul class="grid grid-cols-1 md:grid-cols-3 lg:grid-cols-4 gap-3">
                <?php foreach ($cast as $actor) : ?>
                    <li class="actor-card flex items-center space-x-4 p-4 bg-black shadow rounded-lg opacity-0 transform translate-y-8 transition-transform duration-700">
                        <?php if (!empty($actor['profile_path'])) : ?>
                            <img class="w-24 rounded-full" src="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($actor['profile_path']); ?>" alt="<?php echo htmlspecialchars($actor['name']); ?>">
                        <?php else : ?>
                            <div class="w-16 h-16 rounded-full bg-gray-300 flex items-center justify-center">
                                <span class="text-zinc-300">?</span>
                            </div>
                        <?php endif; ?>
                        <div>
                            <a href="actors?id=<?php echo $actor['id']; ?>" class="text-white font-medium hover:underline">
                                <h3 class="text-xl font-semibold text-zinc-300"><?php echo htmlspecialchars($actor['name']); ?></h3>
                            </a>
                            <p class="text-zinc-500 font-semibold">
                                <?php
                                $character = htmlspecialchars($actor['character']);
                                if (strpos($character, '(voice)') !== false) {
                                    $character = str_replace('(voice)', '(seslendirme)', $character);
                                }
                                echo $character;
                                ?>
                            </p>
                        </div>
                    </li>
                <?php endforeach; ?>
            </ul>
        <?php else : ?>
            <p class="text-red-500">Geçersiz film ID'si veya film bilgileri alınamadı.</p>
        <?php endif; ?>

        <div class="mt-4 mb-3 bg-black rounded mb-4 mx-auto items-center p-8">
            <h2 class="text-2xl font-bold text-center">Parodi Ekle</h2>
            <form action="add_parody.php" method="post">
                <input type="hidden" name="movie_id" value="<?php echo $movieId; ?>">
                <label class="block text-zinc-300 font-semibold" for="video_url">Parodi videosu URL'si:</label>
                <input class="block w-full p-2 mb-4 rounded bg-zinc-800 text-zinc-300" type="text" id="video_url" name="video_url">
                <button class="block w-full p-2 bg-blue-500 text-white font-semibold rounded hover:bg-blue-600" type="submit">Parodi Ekle</button>
            </form>
        </div>

        <div class="mt-4 mb-3 bg-black rounded mb-4 mx-auto items-center p-8">
            <span class="text-zinc-400 font-semibold"><i class="fa-solid fa-comment-dots text-white mr-2 fa-xl"></i> Yorum yaparak profilinizde sergileyebileceğiniz rozetler kazanabilirsiniz. Rozetler hakkında daha fazla bilgi için <a class="text-black/90 bg-white/90 px-3 hover:opacity-90 duration-150 hover:rounded hover:px-5" href="/badges"> <i class="fa-solid fa-id-badge"></i> Rozetler</a> sayfasına göz atın.</span>
        </div>

        <!-- Benzer Filmler -->
        <div class="container mx-auto mt-8">
            <h2 class="text-2xl font-bold text-center"><?php echo htmlspecialchars($movie['title']); ?> <span class="font-normal">ile benzer filmler</span></h2>
            <div id="similarMovies" class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 px-2 lg:grid-cols-5 xl:grid-cols-6 gap-4 mt-8">
                <?php if (!empty($similarMovies)) : ?>
                    <?php foreach ($similarMovies as $index => $movie) : ?>
                        <div class="group relative rounded overflow-hidden" id="movie-<?php echo $index; ?>">
                            <a href="movie?id=<?php echo $movie['id']; ?>">
                                <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $movie['poster_path']; ?>" alt="<?php echo $movie['title']; ?>">
                                <div class="overlay flex items-center justify-center">
                                    <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                        <span><?php echo $movie['title']; ?></span>
                                        <span class="font-normal text-sm"><?php echo date('Y', strtotime($movie['release_date'])); ?></span>
                                    </div>
                                </div>
                            </a>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <p class="text-center text-gray-600">Benzer filmler bulunamadı.</p>
                <?php endif; ?>
            </div>
        </div>

        <!-- Yorum Ekleme Formu -->
        <?php if ($userLoggedIn) : ?>
            <div class="items-start flex flex-col mb-4">
                <div class="border border-gray-500/30 p-4 rounded mt-3 text-sm">
                    <span class="text-zinc-500">Eğer ilk kez kayıt olduysan veya film & dizi veritabanına ilk kez kaydediliyorsa herhangi bir şey yapmadan önce sana özel SESSION oluşması için rastgele bir yorum göndermeyi dene. Seni yeni bir sayfaya atıp hata verirse geri gelip asıl yorumunu yaparak bu işlemi bitirebilirsin.</span>
                </div>

                <div class="flex mt-3 w-full border p-4 border-red-500/20 rounded mb-2 flex-row text-sm space-x-2 items-center">
                    <div class="text-sm px-4 flex flex-row space-x-1 items-center bg-red-100 text-red-400 font-bold">
                        <i class="fa-solid fa-book-bookmark"></i>
                        <span>Önemli</span>
                    </div>
                    <span class="text-red-500/70 font-semibold">Etiket oluştururken boşluk ve Türkçe karakter kullanma. Örneğin bir etiketi bu şekilde oluştur: <strong>#YuzuklerinEfendisi</strong></span>
                </div>

                <h2 class="text-xl font-bold text-center mt-8 mb-2 text-gray-600"><span class="rounded-full bg-blue-500/20 px-3"><i class="fa-solid fa-wand-magic-sparkles"></i></span> Sihirli kalemini konuştur</h2>
                <span class="text-gray-500">Diğerlerinin arasında sen de sihirli kalemin ile yorumlar yap ve ödüller kazan. </span>
            </div>
            <form action="add_comment.php" method="POST">
                <input type="hidden" name="token" value="<?php echo htmlspecialchars($_SESSION['token'] ?? ''); ?>">
                <input type="hidden" name="movie_id" value="<?php echo htmlspecialchars($movieId); ?>">
                <textarea name="content" class="w-full px-3 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500" placeholder="Yorumunuzu buraya yazın..." required></textarea>
                <button type="submit" class="mt-2 px-4 py-2 bg-blue-500 text-white rounded-lg hover:bg-blue-600 transition duration-300 focus:outline-none">Yorum Ekle</button>
            </form>

        <?php else : ?>
            <p class="mb-4 mt-4">Yorum yapmak için <a href="login" class="text-blue-500 hover:underline">Giriş yap</a> veya <a href="register" class="text-blue-500 hover:underline">Kaydol</a></p>
        <?php endif; ?>


        <!-- Yorumlar -->
        <div class="mb-8 comments-container">
            <div class="items-center flex flex-col mb-4">
                <h2 class="text-4xl font-bold text-center mt-8 mb-2 text-gray-600"><span class="rounded-full bg-blue-500/20 px-3"><i class="fa-solid fa-comments"></i></span> Yorumlar (<?php echo $totalComments; ?>)</h2>
                <span class="text-gray-500">Kullanıcıların yaptığı yorumları oku veya sende bir yorum yap.</span>
            </div>

            <!-- Yorum yoksa mesaj -->
            <?php if (empty($comments)) : ?>
                <p class="text-zinc-500 font-semibold border border-gray-500/20 p-4 rounded"><i class="fa-solid fa-comment-slash"></i> Henüz yorum yapılmamış.</p>
            <?php endif; ?>
        </div>

        <!-- Container where additional comments will be added -->
        <div id="additional-comments-container">
        </div>

        <footer class="mt-8 bg-black/90 text-white p-4 fixed bottom-0 w-full right-0 opacity-90">
            <div class="container mx-auto flex justify-between items-center">
                <div>
                    <div class="flex flex-row items-center">
                        <img src="./cdn/logo.png" alt="Foxy" class="w-12">
                        <h3 class="text-lg font-bold">Foxy</h3>
                    </div>
                    <p class="mt-2">Tüm hakları saklıdır. | <span class="font-semibold">&copy; 2024 <a class="hover:text-red-600 duration-150" href="https://9fud.com">9FUD.COM</a></span></p>
                </div>

                <a href="https://www.themoviedb.org/" target="_blank" class="hover:underline hover:text-zinc-100 duration-150 text-zinc-400" data-tippy-content="Tüm dünyaya ücretsiz ve yerel dilleri de destekleyecek bir şekilde temiz API sunduğu için The Movie Database'a (TiVo Platform Technologies LLC) teşekkürlerimizi sunarız.">Özel teşekkür - TMDB API</span>

                    <div>


                        <ul class="flex space-x-3">
                            <li>
                                <a href="https://instagram.com/FoxyPlatform" target="_blank" rel="noopener noreferrer" class="duration-150 text-gray-300 hover:text-pink-500" data-tippy-content="Bizi İnstagram'dan takip et!">
                                    <i class="fab fa-instagram fa-lg"></i>
                                </a>
                            </li>
                            <li>
                                <a href="https://twitter.com/FoxyPlatform" target="_blank" rel="noopener noreferrer" class="duration-150 text-gray-300 hover:text-blue-400" data-tippy-content="Bizi X'ten takip et!">
                                    <i class="fab fa-x-twitter fa-lg"></i>
                                </a>
                            </li>
                        </ul>
                    </div>
            </div>
        </footer>

    </div>

    <script>
        let page = 1;
        let loading = false;

        function loadMoreComments() {
            if (loading) return;
            loading = true;
            let xhr = new XMLHttpRequest();
            xhr.open('GET', `load_comments.php?id=<?= $_GET['id']; ?>&page=${page}`);
            xhr.onload = function() {
                if (xhr.status === 200) {
                    let additionalCommentsContainer = document.getElementById('additional-comments-container');
                    additionalCommentsContainer.innerHTML += xhr.responseText;

                    // tippy.js'i yeniden etkinleştir
                    tippy('[data-tippy-content]', {
                        placement: 'top',
                        animation: 'shift-away',
                        allowHTML: true,
                    });

                    page++;
                    loading = false;
                }
            };
            xhr.send();
        }

        window.addEventListener('scroll', function() {
            if (window.innerHeight + window.scrollY >= document.body.offsetHeight) {
                loadMoreComments();
            }
        });

        // İlk yüklemeyi yap
        loadMoreComments();
    </script>


    <!-- Loading bar için JavaScript -->
    <script>
        // Sayfa yükleme durumunu göstermek için
        document.addEventListener("DOMContentLoaded", function() {
            const progressBar = document.querySelector('#loading-bar .progress');
            progressBar.style.width = '100%';
            setTimeout(() => {
                progressBar.style.width = '0%';
            }, 1000);
        });
    </script>

    <!-- Bildirimleri gösteren JavaScript kodu -->
    <?php if (isset($_SESSION['favorite_message'])) : ?>
        <script>
            document.addEventListener("DOMContentLoaded", function() {
                var favoriteMessage = "<?php echo $_SESSION['favorite_message']; ?>";
                var favoriteMessageDiv = document.getElementById("favorite-message");
                var favoriteMessageText = document.getElementById("favorite-message-text");
                favoriteMessageText.innerHTML = favoriteMessage;
                favoriteMessageDiv.classList.remove("opacity-0");
                favoriteMessageDiv.classList.add("opacity-100");
                setTimeout(function() {
                    favoriteMessageDiv.classList.remove("opacity-100");
                    favoriteMessageDiv.classList.add("opacity-0");
                    favoriteMessageDiv.innerHTML = ""; // İçeriği temizle
                }, 4000); // 4 saniye sonra kaldır
            });
        </script>
        <?php unset($_SESSION['favorite_message']); ?>
    <?php endif; ?>

    <script>
        function toggleFavorite(movieId, action) {
            const xhr = new XMLHttpRequest();
            xhr.open("POST", "toggle_favorite.php", true);
            xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            xhr.onreadystatechange = function() {
                if (xhr.readyState === 4 && xhr.status === 200) {
                    const response = JSON.parse(xhr.responseText);
                    if (response.success) {
                        // Butonun durumunu güncelle
                        const button = document.querySelector(`#favoriteButton_${movieId}`);
                        if (action === "add") {
                            button.innerHTML = '<i class="fa-solid fa-star"></i> Favorilerden kaldır';
                            button.setAttribute("onclick", `toggleFavorite(${movieId}, 'remove')`);
                        } else {
                            button.innerHTML = '<i class="fa-solid fa-star"></i> Favorilere ekle';
                            button.setAttribute("onclick", `toggleFavorite(${movieId}, 'add')`);
                        }
                    } else {
                        alert("Favori işleminde bir hata oluştu.");
                    }
                }
            };
            xhr.send(`movie_id=${movieId}&action=${action}`);
        }
    </script>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const stars = document.querySelectorAll('.star');

            stars.forEach(star => {
                star.addEventListener('click', function() {
                    const value = parseInt(star.getAttribute('data-value'));
                    updateStars(value);
                });
            });

            function updateStars(value) {
                stars.forEach(star => {
                    const starValue = parseInt(star.getAttribute('data-value'));
                    if (starValue <= value) {
                        star.classList.add('active');
                    } else {
                        star.classList.remove('active');
                    }
                });
            }
        });
    </script>

    <script>
        function showModal() {
            document.getElementById('listModal').style.display = 'block';
            loadUserLists();
        }

        function closeModal() {
            document.getElementById('listModal').style.display = 'none';
        }

        function loadUserLists() {
            fetch('get_user_lists.php')
                .then(response => response.json())
                .then(data => {
                    let listsContainer = document.getElementById('existingLists');
                    listsContainer.innerHTML = '';
                    data.forEach(list => {
                        let listItem = document.createElement('div');
                        listItem.innerHTML = `
                        <label class="w-full">
                            <input type="checkbox" name="list" value="${list.id}"> <span class="checktext font-semibold hover:opacity-50 duration-150 cursor-pointer">${list.title}</span
                        </label>
                    `;
                        listsContainer.appendChild(listItem);
                    });
                });
        }

        function createNewList() {
            window.location.href = 'create_list.php';
        }

        function addToList() {
            let selectedList = document.querySelector('input[name="list"]:checked');
            if (selectedList) {
                let listId = selectedList.value;
                let movieId = <?php echo $movie_id; ?>; // Mevcut filmin ID'sini alın

                // AJAX ile film zaten listeye eklenmiş mi diye kontrol ediyoruz
                fetch('check_movie_in_list.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json'
                        },
                        body: JSON.stringify({
                            list_id: listId,
                            movie_id: movieId
                        })
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.exists) {
                            showAddToListMessage('Bu film zaten listeye eklenmiş.');
                        } else {
                            // Film listeye ekleniyor
                            fetch('add_to_list.php', {
                                    method: 'POST',
                                    headers: {
                                        'Content-Type': 'application/json'
                                    },
                                    body: JSON.stringify({
                                        list_id: listId,
                                        movie_id: movieId
                                    })
                                })
                                .then(response => response.json())
                                .then(data => {
                                    if (data.success) {
                                        showAddToListMessage('Film listeye eklendi!');
                                    } else {
                                        showAddToListMessage('Bir hata oluştu.');
                                    }
                                })
                                .catch(error => {
                                    console.error('Hata:', error);
                                    showAddToListMessage('Film listeye eklenirken bir hata oluştu.');
                                });
                        }
                    })
                    .catch(error => {
                        console.error('Hata:', error);
                        showAddToListMessage('Film listeye eklenirken bir hata oluştu.');
                    });
            } else {
                alert('Lütfen bir liste seçin.');
            }
        }

        function showAddToListMessage(message) {
            var addToListMessage = document.getElementById("add-to-list-message");
            var addToListMessageText = document.getElementById("add-to-list-message-text");
            addToListMessageText.innerText = message;
            addToListMessage.classList.remove("opacity-0");
            addToListMessage.classList.add("opacity-100");
            setTimeout(function() {
                addToListMessage.classList.remove("opacity-100");
                addToListMessage.classList.add("opacity-0");
            }, 4000); // 4 saniye sonra kaldır
        }
    </script>

    <script>
        // JavaScript ile giriş kontrolü yapılacak
        let isLoggedIn = <?php echo isset($_SESSION['user_id']) ? 'true' : 'false'; ?>;

        if (!isLoggedIn) {
            let addToMyListBtn = document.getElementById('addToMyListBtn');
            addToMyListBtn.removeAttribute('onclick'); // Buton tıklanabilirliğini kaldır
            addToMyListBtn.disabled = true; // Butonu tıklanamaz yap
        }
    </script>

    <script>
        function openLikemodal() {
            document.getElementById('likeModal').classList.remove('hidden');
        }

        function CloseLikeModal() {
            document.getElementById('likeModal').classList.add('hidden');
        }
    </script>


    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            placement: 'top',
            animation: 'shift-away'
        });
    </script>
</body>

</html>