<?php
require 'db.php'; // Veritabanı bağlantısı
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

// Kullanıcı bilgilerini çek
$userId = $_SESSION['user_id'] ?? null;
$username = $_SESSION['username'] ?? '';
$profilePicture = $_SESSION['profile_picture'] ?? ''; // Profil resmi yolunu da al

if ($userId) {
    $stmt = $pdo->prepare("SELECT username, profile_picture FROM users WHERE id = :user_id");
    $stmt->execute([':user_id' => $userId]);
    $userData = $stmt->fetch(PDO::FETCH_ASSOC);
    $username = $userData['username'] ?? $_SESSION['username'];
    $profilePicture = $userData['profile_picture'] ?? $_SESSION['profile_picture'];

    // Bildirim sayısını çek (örnek)
    $stmt = $pdo->prepare("SELECT COUNT(*) as notification_count FROM notifications WHERE user_id = :user_id AND is_read = 0");
    $stmt->execute([':user_id' => $userId]);
    $notificationData = $stmt->fetch(PDO::FETCH_ASSOC);
    $notificationCount = $notificationData['notification_count'] ?? 0;

    // Bildirimleri çek (örnek)
    $stmt = $pdo->prepare("SELECT message, created_at FROM notifications WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 5");
    $stmt->execute([':user_id' => $userId]);
    $notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);
} else {
    $username = '';
    $profilePicture = ''; // Varsayılan olarak profil resmi yoksa boş bırakabilirsiniz veya varsayılan bir resim ekleyebilirsiniz.
    $notificationCount = 0; // Kullanıcı giriş yapmamışsa bildirim yok
    $notifications = []; // Bildirim yok
}

// Bildirimlerin okunma işlemi için AJAX endpoint oluştur
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['read_notifications'])) {
    $stmt = $pdo->prepare("UPDATE notifications SET is_read = 1 WHERE user_id = :user_id AND is_read = 0");
    $stmt->execute([':user_id' => $userId]);
    echo json_encode(['success' => true]);
    exit;
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        /* Additional styles for fixed bottom menu */
        @media (max-width: 768px) {
            .fixed-bottom-menu {
                position: fixed;
                bottom: 0;
                left: 0;
                width: 100%;
                background-color: #000;
                z-index: 1000;
                /* Adjust as needed */
                display: none;
            }

            .fixed-bottom-menu.visible {
                display: block;
            }
        }

        #fixed-bottom-menu {
            white-space: nowrap;
            /* İçeriklerin tek satıra sığmasını sağlar */
            overflow-x: auto;
            /* Yatay kaydırma çubuğunu göstermek için */
            overflow-y: hidden;
            /* Dikey kaydırmayı gizle */
            padding-bottom: 1rem;
            /* Alt kısımdan biraz boşluk bırakma */
            width: 100%;
            /* Menü genişliğinin ekran genişliğine uyumlu olmasını sağlar */
        }

        #fixed-bottom-menu .flex {
            display: flex;
            /* Flexbox kullanımı */
            flex-wrap: nowrap;
            /* İçeriklerin tek satıra sığmasını sağlar */
        }

        #fixed-bottom-menu .flex a:last-child {
            padding-right: 1.5rem !important;
            /* Sağ tarafta boşluk bırakır */
        }
    </style>
</head>

<body class="bg-gray-100">
    <nav class="flex justify-between items-center py-4 bg-black text-white px-2 md:px-8">

        <!-- Hamburger Menu Button -->
        <button id="menu-button" class="md:hidden ml-4 text-white">
            <i class="fa-solid fa-bars fa-xl"></i>
        </button>

        <!-- Logo and Brand Name -->
        <div class="flex flex-row items-center space-x-2">
            <img src="./cdn/logo.png" alt="Foxy" class="w-10">
            <a href="/" class="text-2xl font-bold">Foxy</a>
        </div>

        <!-- Main Menu Items -->
        <div id="menu" class="grid grid-cols-3 hidden space-x-0 md:flex flex-col md:flex-row md:space-x-6 p-4 text-sm absolute md:relative top-16 md:top-auto left-0 w-full md:w-auto bg-black/80 md:bg-transparent">
            <a href="/users" class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-solid fa-user"></i> KULLANICILAR</a>
            <a href="/badges" class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-solid fa-id-badge"></i> ROZETLER</a>
            <a href="/categories">
                <div>
                    <span class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-solid fa-list"></i> KATEGORİLER </span>
                </div>
            </a>
            <a href="/all-list">
                <div>
                    <span class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-regular fa-rectangle-list"></i> LİSTELER </span>
                </div>
            </a>
            <a href="/top">
                <div>
                    <span class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-solid fa-list"></i> EN'LER </span>
                </div>
            </a>
            <a href="/developers">
                <div>
                    <span class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-solid fa-note-sticky"></i> GELİŞTİRİCİ NOTLARI </span>
                </div>
            </a>
            <a href="/random">
                <div>
                    <span class="text-zinc-400 font-semibold hover:text-white duration-150 md:p-0"><i class="fa-solid fa-shuffle"></i> RASTGELE</span>
                    <span class="bg-red-500 px-2 rounded text-xs font-bold mx-1">YENİ</span>
                </div>
            </a>
        </div>

        <!-- User Profile Section -->
        <div class="flex items-center relative">
            <?php if (!empty($userId)) : ?>
                <!-- Notifications Button -->
                <div class="relative">
                    <button id="notification-button" class="relative hover:opacity-75 duration-150">
                        <i class="p-3 fa-solid fa-bell text-zinc-400 text-2xl"></i>
                        <?php if ($notificationCount > 0) : ?>
                            <span class="text-xs absolute top-0 right-0 inline-flex items-center justify-center p-1 px-2 font-bold leading-none text-red-100 bg-red-600 rounded-full">
                                <?php echo htmlspecialchars($notificationCount); ?>
                            </span>
                        <?php endif; ?>
                    </button>
                    <div id="notification-menu" class="absolute right-[-80px] sm:right-0 lg:right-0 xl:right-0 md:right-0 mt-2 w-[300px] bg-black text-white border border-gray-700 rounded-lg shadow-md hidden z-10">
                        <div class="py-2">
                            <?php if (!empty($notifications)) : ?>
                                <?php foreach ($notifications as $notification) : ?>
                                    <div class="px-4 cursor-pointer py-2 hover:bg-gray-700">
                                        <span class="text-sm"><?php echo htmlspecialchars_decode($notification['message']); ?></span>
                                        <p class="text-xs text-gray-400"><?php echo htmlspecialchars(strftime('%d %B %Y - %H:%M', strtotime($notification['created_at']))); ?></p>
                                    </div>
                                <?php endforeach; ?>
                            <?php else : ?>
                                <div class="px-4 py-2">
                                    <p class="text-sm font-semibold text-zinc-400"><i class="fa-solid fa-comment-slash mr-1"></i> Yeni bildirim yok.</p>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>

                <!-- User Profile Menu -->
                <div class="relative items-start flex flex-row space-x-2">
                    <button id="user-button" class="mr-4 flex px-3 py-1 rounded hover:bg-gray-700 duration-150 focus:outline-none flex-row items-center space-x-2">
                        <img src="<?php echo htmlspecialchars($profilePicture); ?>" alt="<?php echo htmlspecialchars($username); ?>" class="w-8 h-8 rounded-full ml-2">
                        <div>
                            <span class="hidden sm:inline"><?php echo htmlspecialchars($username); ?></span>
                            <span class="sm:hidden">Profil</span>
                        </div>
                    </button>
                    <div id="user-menu" class="absolute right-0 top-12 bg-gray-800 text-white border border-gray-700 rounded-b-lg shadow-md hidden z-10 min-w-[200px]">
                        <div>
                            <a href="profile?user_id=<?php echo htmlspecialchars($userId); ?>" class="duration-150 block px-4 py-2 hover:bg-gray-700"><i class="fa-solid fa-user mr-1"></i> Profilim</a>
                            <a href="lists" class="block px-4 py-2 hover:bg-gray-700"><i class="fa-solid fa-list mr-1"></i> Listelerim</a>
                            <a href="logout" class="block bg-red-600 hover:bg-red-500 duration-150 px-4 py-2"><i class="fa-solid fa-right-from-bracket mr-1"></i> Çıkış Yap</a>
                        </div>
                    </div>
                </div>
            <?php else : ?>
                <!-- Login and Register Buttons -->
                <div class="">
                    <a href="login" class="duration-150 px-5 hover:opacity-80 py-1 rounded bg-white text-black font-semibold" data-tippy-content="Giriş Yap"><i class="fa-solid fa-right-to-bracket"></i></a>
                    <a href="register" class="duration-150 px-5 py-1 ml-1 rounded bg-blue-500 hover:opacity-85 font-semibold" data-tippy-content="Kayıt Ol"><i class="fa-solid fa-user-plus"></i></a>
                </div>
            <?php endif; ?>
        </div>

    </nav>

    <!-- Fixed Bottom Menu -->
    <div id="fixed-bottom-menu" class="fixed-bottom-menu bg-black text-white p-6 pt-8 md:hidden lg:hidden xl:hidden">
        <div class="flex items-center space-x-5">

            <div class="flex text-sm text-zinc-500 flex-row flex justify-center space-x-2 items-center">
                <span>Kaydır</span>
                <i class="fa-solid fa-arrow-right-long"></i>
            </div>

            <a href="/users" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-solid fa-user fa-xl"></i>
                    <span class="text-xs mt-3">Kullanıcılar</span>
                </div>
            </a>

            <a href="/badges" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-solid fa-id-badge fa-xl"></i>
                    <span class="text-xs mt-3">Rozetler</span>
                </div>
            </a>

            <a href="/categories" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-solid fa-list fa-xl"></i>
                    <span class="text-xs mt-3">Kategoriler</span>
                </div>
            </a>

            <a href="/all-list" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-regular fa-rectangle-list fa-xl"></i>
                    <span class="text-xs mt-3">Listeler</span>
                </div>
            </a>

            <a href="/top" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-solid fa-list fa-xl"></i>
                    <span class="text-xs mt-3">En'ler</span>
                </div>
            </a>

            <a href="/random" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-solid fa-shuffle fa-xl"></i>
                    <span class="text-xs mt-3">Rastgele</span>
                </div>
            </a>

            <a href="/developers" class="text-zinc-400 font-semibold hover:text-white duration-150">
                <div class="flex flex-col items-center">
                    <i class="fa-solid fa-note-sticky fa-xl"></i>
                    <span class="text-xs mt-3">Geliştirci Notları</span>
                </div>
            </a>
        </div>
    </div>

    <script>
        // Bildirim menüsü açma ve kapama işlemi
        const notificationButton = document.getElementById('notification-button');
        const notificationMenu = document.getElementById('notification-menu');

        notificationButton.addEventListener('click', () => {
            notificationMenu.classList.toggle('hidden');
        });

        // Kullanıcı menüsü açma ve kapama işlemi
        const userButton = document.getElementById('user-button');
        const userMenu = document.getElementById('user-menu');

        userButton.addEventListener('click', () => {
            userMenu.classList.toggle('hidden');
        });

        // Bildirimlerin okunması işlemi için AJAX
        notificationMenu.addEventListener('click', (event) => {
            if (event.target.classList.contains('notification-item')) {
                // Bildirim öğesine tıklandığında okundu olarak işaretle
                const notificationId = event.target.dataset.notificationId;
                markNotificationAsRead(notificationId);
            }
        });

        function markNotificationAsRead(notificationId) {
            // AJAX ile bildirimi okundu olarak işaretle
            fetch('index', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        read_notifications: true,
                        notification_id: notificationId
                    }),
                })
                .then(response => response.json())
                .then(data => {
                    // Başarılı işlem durumunda bildirimi arayüzden kaldır
                    if (data.success) {
                        const notificationElement = document.querySelector(`[data-notification-id="${notificationId}"]`);
                        if (notificationElement) {
                            notificationElement.remove();
                        }
                    }
                })
                .catch(error => {
                    console.error('Bildirim okunamadı:', error);
                });
        }
    </script>

    <!-- JavaScript to Handle Menu Interaction -->
    <script>
        // Hamburger Menu Interaction
        const menuButton = document.getElementById('menu-button');
        const fixedBottomMenu = document.getElementById('fixed-bottom-menu');

        menuButton.addEventListener('click', () => {
            // Üst menüyü gizle
            const isMenuHidden = menuButton.classList.toggle('open');
            const isFixedMenuVisible = fixedBottomMenu.classList.toggle('visible');

            if (isMenuHidden) {
                // Eğer üst menüyü gizlediysek, alt menüyü göster
                fixedBottomMenu.classList.add('visible');
            } else {
                // Eğer üst menüyü gösteriyorsak, alt menüyü gizle
                fixedBottomMenu.classList.remove('visible');
            }
        });

        // Dışarı tıklama ile menüyü kapatma
        document.addEventListener('click', function(event) {
            const isClickInsideMenu = menuButton.contains(event.target);
            const isClickInsideFixedBottomMenu = fixedBottomMenu.contains(event.target);

            if (!isClickInsideMenu && !isClickInsideFixedBottomMenu) {
                fixedBottomMenu.classList.remove('visible');
            }
        });
    </script>


    <!-- Tailwind CSS and Tippy.js CDN Links -->
    <script src="https://unpkg.com/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        // Initialize Tippy.js tooltips
        tippy('[data-tippy-content]', {
            animation: 'shift-away',
            duration: 200,
            arrow: false,
        });
    </script>

</body>

</html>