<?php
session_start();
include 'navbar.php';

require 'db.php'; // Database connection
require 'functions.php';

// Set locale for Turkish date format
setlocale(LC_TIME, 'tr_TR.UTF-8');

// Retrieve logged-in user information
$userId = $_SESSION['user_id'] ?? null;
$username = $_SESSION['username'] ?? '';
$profilePicture = $_SESSION['profile_picture'] ?? '';

// If user is logged in, fetch user details
if ($userId) {
    // Update last active timestamp
    $stmt = $pdo->prepare("
        INSERT INTO user_last_active (user_id) 
        VALUES (:user_id) 
        ON DUPLICATE KEY UPDATE last_active_at = CURRENT_TIMESTAMP
    ");
    $stmt->execute([':user_id' => $userId]);

    // Fetch user data
    $stmt = $pdo->prepare("SELECT username, profile_picture FROM users WHERE id = :user_id");
    $stmt->execute([':user_id' => $userId]);
    $userData = $stmt->fetch(PDO::FETCH_ASSOC);

    // Update variables with user data from database if available
    if ($userData) {
        $username = $userData['username'];
        $profilePicture = $userData['profile_picture'];
    }
}

$alertMessage = ''; // For error or informational messages

// Handle profile viewing
if (isset($_GET['user_id'])) {
    $profileUserId = $_GET['user_id'];

    // Fetch user details and comments
    $stmt = $pdo->prepare("
        SELECT 
            users.username, 
            users.profile_picture,
            users.verified,
            users.admin,
            (SELECT COUNT(*) FROM comments WHERE user_id = users.id) AS comment_count,
            (SELECT COUNT(*) FROM movies WHERE user_id = users.id) AS total_movies, 
            comments.content,
            comments.timestamp,
            comments.movie_id,
            movies.title AS movie_title
        FROM users
        LEFT JOIN comments ON users.id = comments.user_id
        LEFT JOIN movies ON comments.movie_id = movies.id
        WHERE users.id = :user_id
        GROUP BY users.id, comments.content, comments.timestamp, comments.movie_id, movies.title
        ORDER BY comments.timestamp DESC
    ");
    $stmt->execute([':user_id' => $profileUserId]);
    $userData = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (!empty($userData)) {
        $username = $userData[0]['username'];
        $total_movies = $userData[0]['total_movies'] ?? 0;
        $profilePicture = $userData[0]['profile_picture'];
        $verified = $userData[0]['verified'];
        $admin = $userData[0]['admin'];
        $commentCount = $userData[0]['comment_count'];
        $comments = array_slice($userData, 0, 5); // Get the latest 5 comments
    } else {
        http_response_code(404);
        header('Location: 404.php');
        exit;
    }
} else {
    http_response_code(404);
    header('Location: 404.php');
    exit;
}

// Handle profile picture update
$updateSuccess = false;
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['update_profile'])) {
    if ($userId == $profileUserId) {
        // Handle profile picture upload
        if ($_FILES['profile_image']['size'] > 0) {
            $target_dir = "images/";
            $target_file = $target_dir . basename($_FILES["profile_image"]["name"]);
            $uploadOk = 1;
            $imageFileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

            // Validate image file
            $check = getimagesize($_FILES["profile_image"]["tmp_name"]);
            if ($check === false) {
                $alertMessage = "Geçersiz dosya formatı.";
                $uploadOk = 0;
            }

            // Check file type
            $allowedFileTypes = ['jpg', 'jpeg', 'png', 'gif'];
            if (!in_array($imageFileType, $allowedFileTypes)) {
                $alertMessage = "Sadece JPG, JPEG, PNG ve GIF dosya formatlarına izin verilir.";
                $uploadOk = 0;
            }

            if ($uploadOk == 0) {
                $alertMessage = "Dosya yüklenemedi.";
            } else {
                if (move_uploaded_file($_FILES["profile_image"]["tmp_name"], $target_file)) {
                    // Update profile picture in the database
                    $stmt = $pdo->prepare("UPDATE users SET profile_picture = :profile_picture WHERE id = :user_id");
                    $stmt->execute([':profile_picture' => $target_file, ':user_id' => $userId]);
                    $updateSuccess = true;
                    $_SESSION['profile_picture'] = $target_file; // Update session profile picture
                    $profilePicture = $target_file; // Update profile picture
                    $alertMessage = "Profil fotoğrafı başarıyla güncellendi.";
                } else {
                    $alertMessage = "Dosya yüklenirken bir hata oluştu.";
                }
            }
        } else {
            $alertMessage = "Lütfen bir dosya seçin.";
        }
    } else {
        $alertMessage = "Bu işlem için yetkiniz yok.";
    }
}

// Get the last active time
$stmt = $pdo->prepare("SELECT last_active_at FROM user_last_active WHERE user_id = :user_id");
$stmt->execute([':user_id' => $profileUserId]);
$lastActive = $stmt->fetchColumn();

// Format the last active time
$lastActiveFormatted = strftime('%e %B %Y - %H:%M', strtotime($lastActive));



// Kullanıcının ID'sini URL'den al
$user_id = isset($_GET['user_id']) ? intval($_GET['user_id']) : $_SESSION['user_id'];

// Kullanıcının izlediği filmleri ve backdrop_path'ı al
$query = "
    SELECT 
        m.id, 
        m.title,
        um.backdrop_path, 
        um.watched_time 
    FROM 
        user_movies um
    JOIN 
        movies m ON um.movie_id = m.id 
    WHERE 
        um.user_id = :user_id AND um.watched = 1
";
$stmt = $pdo->prepare($query);
$stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
$stmt->execute();
$watched_movies = $stmt->fetchAll();

// Toplam izleme süresini hesapla
$total_duration_seconds = 0;
foreach ($watched_movies as $movie) {
    $duration = getMovieDuration($movie['id']); // getMovieDuration fonksiyonu filmin süresini döndürmelidir
    if ($duration) {
        $total_duration_seconds += $duration * 60; // dakikaları saniyeye çevir
    }
}

// Toplam süreyi saat ve dakika olarak hesapla
$total_hours = floor($total_duration_seconds / 3600);
$total_minutes = floor(($total_duration_seconds % 3600) / 60);

// Türkçe ay ve gün isimleri için diziler
$months = [
    1 => 'Ocak',
    2 => 'Şubat',
    3 => 'Mart',
    4 => 'Nisan',
    5 => 'Mayıs',
    6 => 'Haziran',
    7 => 'Temmuz',
    8 => 'Ağustos',
    9 => 'Eylül',
    10 => 'Ekim',
    11 => 'Kasım',
    12 => 'Aralık'
];
$days = [
    'Monday' => 'Pazartesi',
    'Tuesday' => 'Salı',
    'Wednesday' => 'Çarşamba',
    'Thursday' => 'Perşembe',
    'Friday' => 'Cuma',
    'Saturday' => 'Cumartesi',
    'Sunday' => 'Pazar'
];

// Filmleri döngü ile listele

// Kullanıcının izlediği toplam film sayısını hesapla
$query = "SELECT COUNT(*) as total_watched FROM user_movies WHERE user_id = :user_id AND watched = 1";
$stmt = $pdo->prepare($query);
$stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
$stmt->execute();
$result = $stmt->fetch();
$total_watched = $result['total_watched'];


//TAKİPÇİ AMINA KOYİM
// Takipçi sayısını almak için sorgu
$stmt = $pdo->prepare("SELECT COUNT(*) AS count FROM followers WHERE following_id = ?");
$stmt->execute([$user_id]);
$followers_count = $stmt->fetchColumn();

// Takip edilen sayısını almak için sorgu
$stmt = $pdo->prepare("SELECT COUNT(*) AS count FROM followers WHERE follower_id = ?");
$stmt->execute([$user_id]);
$following_count = $stmt->fetchColumn();



$stmt = $pdo->prepare("SELECT users.username, users.profile_picture, followers.created_at AS follow_date 
                        FROM followers 
                        JOIN users ON followers.follower_id = users.id 
                        WHERE followers.following_id = ?");
$stmt->execute([$user_id]);
$followers = $stmt->fetchAll();

$stmt = $pdo->prepare("SELECT users.username, users.profile_picture, followers.created_at AS follow_date 
                        FROM followers 
                        JOIN users ON followers.following_id = users.id 
                        WHERE followers.follower_id = ?");
$stmt->execute([$user_id]);
$followings = $stmt->fetchAll();

// Kullanıcı ID'sini URL'den al
$user_id = isset($_GET['user_id']) ? intval($_GET['user_id']) : 0;

// Oturumdaki kullanıcı ID'sini al
$follower_id = isset($_SESSION['user_id']) ? intval($_SESSION['user_id']) : 0;

// Profilin kendi profiliniz olup olmadığını kontrol et
$is_own_profile = ($user_id == $follower_id);

$is_following = false;

if ($user_id) {
    try {
        $checkStmt = $pdo->prepare("SELECT * FROM followers WHERE follower_id = ? AND following_id = ?");
        $checkStmt->execute([$follower_id, $user_id]);
        $is_following = $checkStmt->rowCount() > 0;
    } catch (PDOException $e) {
        echo "Hata: " . $e->getMessage();
    }
}

$message = '';
$message_type = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $action = isset($_POST['action']) ? $_POST['action'] : '';

    if ($action == 'follow') {
        if (!$is_following) {
            if ($is_own_profile) {
                $message = "Kendi profilinizi takip edemezsiniz.";
                $message_type = 'error';
            } else {
                try {
                    $stmt = $pdo->prepare("INSERT INTO followers (follower_id, following_id) VALUES (?, ?)");
                    $stmt->execute([$follower_id, $user_id]);
                    $message = "Takip etme işlemi başarılı.";
                    $message_type = 'success';
                    $is_following = true;
                } catch (PDOException $e) {
                    $message = "Takip etme sırasında hata: " . $e->getMessage();
                    $message_type = 'error';
                }
            }
        } else {
            $message = "Bu kullanıcıyı zaten takip ediyorsunuz.";
            $message_type = 'info';
        }
    } elseif ($action == 'unfollow') {
        if ($is_following) {
            try {
                $stmt = $pdo->prepare("DELETE FROM followers WHERE follower_id = ? AND following_id = ?");
                $stmt->execute([$follower_id, $user_id]);
                $message = "Takibi bırakma işlemi başarılı.";
                $message_type = 'success';
                $is_following = false;
            } catch (PDOException $e) {
                $message = "Takibi bırakma sırasında hata: " . $e->getMessage();
                $message_type = 'error';
            }
        } else {
            $message = "Bu kullanıcıyı zaten takip etmiyorsunuz.";
            $message_type = 'info';
        }
    }

    // JavaScript'e mesajı aktarma ve butonları güncelleme
    echo "<script>
        document.addEventListener('DOMContentLoaded', function () {
            showAlert('" . addslashes($message) . "', '" . addslashes($message_type) . "');
            updateFollowButtons(" . json_encode($is_following) . ");
            // İşlem başarılıysa 3 saniye sonra sayfayı yenile
            if ('" . addslashes($message_type) . "' === 'success') {
                setTimeout(function() {
                    location.reload();
                }, 3000); // 3 saniye bekleme süresi
            }
        });
    </script>";
}

$is_logged_in = isset($_SESSION['user_id']);

setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

function timeAgo($datetime)
{
    date_default_timezone_set('Europe/Istanbul'); // Türkiye'nin saat dilimini kullanın
    $now = new DateTime();
    $ago = new DateTime($datetime);
    $diff = $now->diff($ago);

    if ($diff->y > 0) {
        return $diff->y . ' yıl önce';
    } elseif ($diff->m > 0) {
        return $diff->m . ' ay önce';
    } elseif ($diff->d > 0) {
        return $diff->d . ' gün önce';
    } elseif ($diff->h > 0) {
        return $diff->h . ' saat önce';
    } elseif ($diff->i > 0) {
        return $diff->i . ' dakika önce';
    } else {
        return 'az önce';
    }
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title><?php echo htmlspecialchars($username); ?> - Foxy</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        .hidden {
            display: none;
        }
    </style>

</head>

<body class="bg-gray-100">

    <div class="container mt-8 mx-auto p-4 animate__animated ">
        <a href="/" class="hover:p-2 hover:bg-transparent text-blue-500 mb-8 block bg-blue-500/10 p-4 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Geri dön</a>

        <!-- Uyarı Mesajları -->
        <?php if (!empty($alertMessage)) : ?>
            <div class="bg-gray-100 border border-gray-400/20 font-semibold text-gray-700 px-4 py-3 rounded relative" role="alert">
                <i class="fa-solid fa-info px-4 bg-gray-500/20 rounded-full mr-1 text-gray-400"></i> <?php echo htmlspecialchars($alertMessage); ?>
            </div>
        <?php endif; ?>

        <!-- Bildirim Alanı -->
        <div id="mail-info" class="fixed top-0 right-0 p-4 w-full text-white opacity-0 transition-opacity duration-300">
            <span id="mail-info-text"></span>
        </div>

        <div id="followers-info" class="fixed top-0 right-0 p-4 w-full text-white opacity-0 transition-opacity duration-300">
            <span id="followers-info-text"></span>
        </div>

        <script>
            document.addEventListener('DOMContentLoaded', function() {
                function showAlert(message, type = 'info') {
                    const infoDiv = document.getElementById('followers-info');
                    const infoText = document.getElementById('followers-info-text');

                    // Mesajı güncelle
                    infoText.textContent = message;

                    // Renk türünü ayarla
                    switch (type) {
                        case 'success':
                            infoDiv.style.backgroundColor = '#28a745'; // Yeşil
                            break;
                        case 'error':
                            infoDiv.style.backgroundColor = '#dc3545'; // Kırmızı
                            break;
                        default:
                            infoDiv.style.backgroundColor = '#333'; // Varsayılan koyu gri
                            break;
                    }

                    // Div'i göster
                    infoDiv.classList.remove('hide');
                    infoDiv.classList.add('show');

                    // 5 saniye sonra gizle
                    setTimeout(function() {
                        infoDiv.classList.remove('show');
                        infoDiv.classList.add('hide');
                    }, 5000);
                }

                // Örnek uyarı kullanımı
                <?php if (isset($message)) : ?>
                    showAlert('<?php echo $message; ?>', '<?php echo $message_type; ?>');
                <?php endif; ?>
            });
        </script>


        <div class="container mt-8 mx-auto p-4">
            <!-- Profil Bilgileri -->
            <div class="flex items-center relative p-4 space-x-4 mb-8">
                <form method="POST" enctype="multipart/form-data" class="flex items-center space-x-4">
                    <img draggable="false" src="<?php echo htmlspecialchars($profilePicture); ?>" alt="<?php echo htmlspecialchars($username); ?>" class="w-20 h-20 rounded-full">
                    <div class="items-center">
                        <div class="flex flex-row mb-1 items-center space-x-1">
                            <h1 class="text-3xl font-bold"><?php echo htmlspecialchars($username); ?></h1>
                            <?php if ($verified == 1) : ?>
                                <img draggable="false" src="./cdn/verified.svg" alt="Doğrulanmış Kullanıcı" class="w-5 cursor-pointer" data-tippy-content="Doğrulanmış Kullanıcı">
                            <?php endif; ?>

                            <?php if ($admin == 1) : ?>
                                <img draggable="false" src="./cdn/admin.png" alt="Admin" class="w-5 cursor-pointer" data-tippy-content="Admin">
                            <?php endif; ?>
                            <?php
                            // Kullanıcı rozetlerini al
                            function getUserBadges($userId)
                            {
                                global $pdo;
                                $stmt = $pdo->prepare("SELECT * FROM badges WHERE user_id = :user_id");
                                $stmt->execute(['user_id' => $userId]);
                                return $stmt->fetchAll(PDO::FETCH_ASSOC);
                            }
                            // Check if the user has badges and display them
                            $userBadges = getUserBadges($profileUserId);
                            foreach ($userBadges as $badge) : ?>
                                <img draggable="false" src="<?= htmlspecialchars($badge['badge_icon']); ?>" alt="<?= htmlspecialchars($badge['badge_name']); ?>" data-tippy-content="<?= htmlspecialchars($badge['badge_description']); ?>" class="w-5 h-5 ml-2 cursor-pointer" data-tippy-placement="top">
                            <?php endforeach; ?>
                        </div>

                        <div class="md:absolute right-0">
                            <p class="text-gray-500 text-sm bg-gray-200 rounded px-2 inline-block"><i class="fa-solid fa-comment"></i> Toplam Yorum: <span class="font-bold"><?php echo htmlspecialchars($commentCount); ?></span></p>
                            <p class="text-gray-500 text-sm bg-gray-200 rounded px-2 inline-block hover:opacity-75 duration-150 cursor-pointer" data-tippy-content="Bu, kullanıcının Foxy'de veritabanına toplam kaydettiği film sayısı"><i class="fa-solid fa-film"></i><span class="font-bold"> <?php echo htmlspecialchars($total_movies); ?> film kaydetti</span></p>

                            <div class="mt-3 text-gray-500 text-sm bg-gray-200 rounded px-2 inline-block flex items-center space-x-1 flex-row text-xs max-w-[260px] overflow-hidden">
                                <p class="text-xs"><strong class="flex items-center flex-row space-x-2">
                                        <img src="./cdn/last-active.png" alt="Son Görülme" class="w-5">
                                        Son Görülme:</strong></p>

                                <span><?php echo htmlspecialchars($lastActiveFormatted); ?></span>
                            </div>
                        </div>


                        <!-- Profil fotoğrafı güncelleme formu -->
                        <?php if ($userId == $profileUserId) : ?>
                            <div class="mt-2 items-center">
                                <label for="profile_image" class="bg-zinc-300 text-zinc-500 font-semibold text-sm duration-150 px-2 py-1 rounded-md cursor-pointer hover:opacity-70"><i class="fa-solid fa-hand-pointer"></i> Profil Fotoğrafı Seç</label>
                                <input type="file" id="profile_image" name="profile_image" class="hidden">
                                <button type="submit" name="update_profile" class="duration-150 bg-blue-500 text-white text-sm px-3 py-1 rounded-md ml-1 hover:bg-blue-600"><i class="fa-solid fa-check"></i> Güncelle</button>
                            </div>

                            <!-- E-posta Tercihleri Butonu -->
                            <button class="mt-3 bg-gray-600 mb-4 text-white px-3 rounded duration-150 flex items-center space-x-2 hover:bg-gray-500 focus:outline-none focus:ring-2 focus:ring-gray-500" id="emailPreferencesBtn">
                                <i class="fas fa-envelope"></i>
                                <span> E-posta Tercihleri</span>
                            </button>
                        <?php endif; ?>

                        <!-- Takipçi ve Takip Edilen Sayıları -->
                        <div class="flex font-semibold flex-row space-x-6 items-center">
                            <p class="hover:opacity-70 duration-150"><strong><?php echo $followers_count; ?></strong> <a href="javascript:void(0)" id="followersBtn">Takipçi</a></p>
                            <p class="hover:opacity-70 duration-150"><strong><?php echo $following_count; ?></strong> <a href="javascript:void(0)" id="followingBtn">Takip Edilen</a></p>
                        </div>

                        <!-- Takipçi Listesi Modal -->
                        <div id="followersModal" class="modal backdrop-blur-sm hidden fixed z-10 inset-0 overflow-y-auto">
                            <div class="flex items-center justify-center min-h-screen">
                                <div class="bg-white p-6 rounded-lg shadow-lg max-w-md w-full">
                                    <div class="flex justify-between items-center mb-4">
                                        <h3 class="text-xl font-semibold"><i class="fa-solid fa-user-plus"></i> Takipçiler</h3>
                                        <button data-tippy-content="Kapat" id="closeFollowersModal" class="px-6 bg-red-500 rounded-full hover:opacity-75 text-white duration-150 text-lg">
                                            <i class="fas fa-times"></i>
                                        </button>
                                    </div>
                                    <ul id="followersList">
                                        <?php
                                        $stmt = $pdo->prepare("SELECT users.username, users.profile_picture, followers.created_at AS follow_date, users.id AS user_id 
                                        FROM followers 
                                        JOIN users ON followers.follower_id = users.id 
                                        WHERE followers.following_id = ?");
                                        $stmt->execute([$user_id]);
                                        $followers = $stmt->fetchAll();
                                        if (empty($followers)) {
                                            echo '<li>Takipçi bulunmuyor.</li>';
                                        } else {
                                            foreach ($followers as $follower) : ?>
                                                <li class="flex items-center space-x-4 mb-2">
                                                    <a href="profile.php?user_id=<?php echo htmlspecialchars($follower['user_id']); ?>">
                                                        <img src="<?php echo htmlspecialchars($follower['profile_picture']); ?>" alt="Profile Picture" class="w-10 h-10 rounded-full">
                                                    </a>
                                                    <div>
                                                        <a href="profile.php?user_id=<?php echo htmlspecialchars($follower['user_id']); ?>" class="font-semibold text-blue-600 hover:underline">
                                                            <?php echo htmlspecialchars($follower['username']); ?>
                                                        </a>
                                                        <p class="text-sm text-gray-500">
                                                            Takip Tarihi: <?php echo htmlspecialchars(timeAgo($follower['follow_date'])); ?>
                                                        </p>
                                                    </div>
                                                </li>
                                        <?php endforeach;
                                        }
                                        ?>
                                    </ul>
                                </div>
                            </div>
                        </div>

                        <!-- Takip Edilen Listesi Modal -->
                        <div id="followingModal" class="modal backdrop-blur-sm hidden fixed z-10 inset-0 overflow-y-auto">
                            <div class="flex items-center justify-center min-h-screen">
                                <div class="bg-white p-6 rounded-lg shadow-lg max-w-md w-full">
                                    <div class="flex justify-between items-center mb-4">
                                        <h3 class="text-xl font-semibold"><i class="fa-solid fa-user-group"></i> Takip Edilenler</h3>
                                        <button data-tippy-content="Kapat" id="closeFollowingModal" class="px-6 bg-red-500 rounded-full hover:opacity-75 text-white duration-150 text-lg">
                                            <i class="fas fa-times"></i>
                                        </button>
                                    </div>
                                    <ul id="followingList">
                                        <?php
                                        $stmt = $pdo->prepare("SELECT users.username, users.profile_picture, followers.created_at AS follow_date, users.id AS user_id 
                                        FROM followers 
                                        JOIN users ON followers.following_id = users.id 
                                        WHERE followers.follower_id = ?");
                                        $stmt->execute([$user_id]);
                                        $followings = $stmt->fetchAll();
                                        if (empty($followings)) {
                                            echo '<li>Takip edilen bulunmuyor.</li>';
                                        } else {
                                            foreach ($followings as $following) : ?>
                                                <li class="flex items-center space-x-4 mb-2">
                                                    <a href="profile.php?user_id=<?php echo htmlspecialchars($following['user_id']); ?>">
                                                        <img src="<?php echo htmlspecialchars($following['profile_picture']); ?>" alt="Profile Picture" class="w-10 h-10 rounded-full">
                                                    </a>
                                                    <div>
                                                        <a href="profile.php?user_id=<?php echo htmlspecialchars($following['user_id']); ?>" class="font-semibold text-blue-600 hover:underline">
                                                            <?php echo htmlspecialchars($following['username']); ?>
                                                        </a>
                                                        <p class="text-sm text-gray-500">
                                                            Takip Tarihi: <?php echo htmlspecialchars(timeAgo($following['follow_date'])); ?>
                                                        </p>
                                                    </div>
                                                </li>
                                        <?php endforeach;
                                        }
                                        ?>
                                    </ul>
                                </div>
                            </div>
                        </div>



                        <script>
                            document.getElementById('followersBtn').addEventListener('click', function(event) {
                                event.preventDefault(); // Sayfa yenilemesini engelle
                                document.getElementById('followersModal').classList.remove('hidden');
                            });

                            document.getElementById('followingBtn').addEventListener('click', function(event) {
                                event.preventDefault(); // Sayfa yenilemesini engelle
                                document.getElementById('followingModal').classList.remove('hidden');
                            });

                            document.getElementById('closeFollowersModal').addEventListener('click', function(event) {
                                event.preventDefault(); // Sayfa yenilemesini engelle
                                document.getElementById('followersModal').classList.add('hidden');
                            });

                            document.getElementById('closeFollowingModal').addEventListener('click', function(event) {
                                event.preventDefault(); // Sayfa yenilemesini engelle
                                document.getElementById('followingModal').classList.add('hidden');
                            });
                        </script>

                        <div class="flex font-semibold flex-row mt-2 justify-start items-center">
                            <!-- Takip Etme Formu -->
                            <?php if ($is_logged_in && !$is_following && !$is_own_profile) : ?>
                                <form action="profile.php?user_id=<?php echo htmlspecialchars($user_id); ?>" method="POST">
                                    <input type="hidden" name="action" value="follow">
                                    <button class="bg-blue-500 rounded px-3 mr-2 text-white" type="submit">
                                        <i class="fa-solid fa-plus"></i> Takip Et
                                    </button>
                                </form>
                            <?php endif; ?>

                            <!-- Takibi Bırakma Formu -->
                            <?php if ($is_logged_in && $is_following && !$is_own_profile) : ?>
                                <form action="profile.php?user_id=<?php echo htmlspecialchars($user_id); ?>" method="POST">
                                    <input type="hidden" name="action" value="unfollow">
                                    <button class="bg-gray-500 rounded px-3 text-zinc-300" type="submit">
                                        <i class="fa-solid fa-user-large-slash"></i> Takibi Bırak
                                    </button>
                                </form>
                            <?php endif; ?>
                        </div>

                        <script>
                            function showAlert(message, type) {
                                // Burada alert veya özel bir uyarı mesajı gösterilebilir
                                alert(type.toUpperCase() + ": " + message);
                            }

                            function updateFollowButtons(isFollowing) {
                                const followButton = document.getElementById('follow-button');
                                const unfollowButton = document.getElementById('unfollow-button');

                                if (isFollowing) {
                                    followButton.style.display = 'none';
                                    unfollowButton.style.display = 'block';
                                } else {
                                    followButton.style.display = 'block';
                                    unfollowButton.style.display = 'none';
                                }
                            }

                            // Sayfa yüklendiğinde butonları güncelle
                            document.addEventListener('DOMContentLoaded', function() {
                                // Varsayılan olarak takip durumu burada ayarlanabilir.
                                updateFollowButtons(false);
                            });
                        </script>


                        <script>
                            function showAlert(message, type = 'info') {
                                const infoDiv = document.getElementById('followers-info');
                                const infoText = document.getElementById('followers-info-text');

                                // Mesajı güncelle
                                infoText.textContent = message;

                                // Renk türünü ayarla
                                infoDiv.classList.remove('bg-green-500', 'bg-red-500', 'bg-blue-500'); // Temizle
                                switch (type) {
                                    case 'success':
                                        infoDiv.classList.add('bg-green-500');
                                        break;
                                    case 'error':
                                        infoDiv.classList.add('bg-red-500');
                                        break;
                                    default:
                                        infoDiv.classList.add('bg-blue-500');
                                        break;
                                }

                                // Görünür hale getir
                                infoDiv.classList.remove('opacity-0');
                                infoDiv.classList.add('opacity-100');

                                // 5 saniye sonra gizle
                                setTimeout(function() {
                                    infoDiv.classList.remove('opacity-100');
                                    infoDiv.classList.add('opacity-0');
                                }, 5000);
                            }
                        </script>

                        <!-- E-posta Tercihleri Modal'ı -->
                        <div id="emailPreferencesModal" class="hidden fixed inset-0 flex backdrop-blur-sm z-1000 items-center justify-center bg-gray-800 bg-opacity-50">
                            <div class="bg-white p-6 rounded-lg relative max-w-sm w-full">
                                <h2 class="text-xl font-semibold mb-4">E-posta Tercihleri</h2>

                                <!-- E-posta Bildirim Tercihi -->
                                <label class="flex items-center mb-4">
                                    <input type="checkbox" id="notifyNewMovie" class="form-checkbox h-5 w-5 text-blue-600">
                                    <span class="ml-2 text-gray-700">Yeni film eklendiğinde haber et</span>
                                </label>

                                <!-- E-posta Girişi -->
                                <div id="emailInputContainer" class="mt-2 hidden">
                                    <input type="email" id="emailInput" placeholder="E-posta adresinizi girin" class="border border-gray-300 rounded-lg p-2 w-full">
                                </div>

                                <!-- Modal Butonları -->
                                <div class="mt-4 flex justify-end space-x-2">
                                    <button id="savePreferencesBtn" class="bg-blue-500 text-white py-2 px-4 rounded-lg hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-300">Kaydet</button>
                                    <button id="closeModalBtn" class="bg-gray-500 text-white py-2 px-4 rounded-lg hover:bg-gray-600 focus:outline-none focus:ring-2 focus:ring-gray-300">Kapat</button>
                                </div>
                            </div>
                        </div>

                        <script>
                            document.addEventListener('DOMContentLoaded', function() {
                                const emailPreferencesBtn = document.getElementById('emailPreferencesBtn');
                                const emailPreferencesModal = document.getElementById('emailPreferencesModal');
                                const notifyNewMovieCheckbox = document.getElementById('notifyNewMovie');
                                const emailInputContainer = document.getElementById('emailInputContainer');
                                const emailInput = document.getElementById('emailInput');
                                const savePreferencesBtn = document.getElementById('savePreferencesBtn');
                                const closeModalBtn = document.getElementById('closeModalBtn');
                                const mailInfo = document.getElementById('mail-info');
                                const mailInfoText = document.getElementById('mail-info-text');

                                // E-posta tercihlerinin butonuna tıklama olayı
                                emailPreferencesBtn.addEventListener('click', function(event) {
                                    event.preventDefault(); // Sayfanın yenilenmesini önlemek için
                                    emailPreferencesModal.classList.remove('hidden');

                                    // Kullanıcının e-posta adresini ve tercihlerinin olup olmadığını kontrol et
                                    fetch('get_email_preferences.php') // E-posta ve tercihleri almak için bir istekte bulunun
                                        .then(response => response.json())
                                        .then(data => {
                                            if (data.error) {
                                                throw new Error(data.error);
                                            }

                                            // E-posta adresini ve bildirim tercihini göster
                                            emailInput.value = data.email || ''; // E-posta adresini göster
                                            notifyNewMovieCheckbox.checked = data.notify_new_movie === 1; // Bildirim tercihini işaretle

                                            // E-posta alanını göster/gizle
                                            emailInputContainer.classList.toggle('hidden', !notifyNewMovieCheckbox.checked);
                                        })
                                        .catch(error => {
                                            console.error('Hata:', error.message);
                                            showNotification('Bir hata oluştu. Lütfen tekrar deneyin.', false);
                                        });
                                });

                                // Modal kapama butonuna tıklama olayı
                                closeModalBtn.addEventListener('click', function() {
                                    emailPreferencesModal.classList.add('hidden');
                                });

                                // E-posta bildirim tercihini değiştirme olayı
                                notifyNewMovieCheckbox.addEventListener('change', function() {
                                    emailInputContainer.classList.toggle('hidden', !this.checked);
                                });

                                // Tercihleri kaydetme butonuna tıklama olayı
                                savePreferencesBtn.addEventListener('click', function(event) {
                                    event.preventDefault(); // Sayfanın yenilenmesini önlemek için

                                    const notifyNewMovie = notifyNewMovieCheckbox.checked ? 1 : 0;
                                    let email = emailInput.value.trim();

                                    // Eğer bildirim tercihi kapatılmışsa, e-posta adresini temizleyin
                                    if (notifyNewMovie === 0) {
                                        email = '';
                                    }

                                    // E-posta adresi girilmesi gerektiğini kontrol et
                                    if (notifyNewMovie === 1 && email === '') {
                                        showNotification('Lütfen geçerli bir e-posta adresi girin.', false);
                                        return;
                                    }

                                    fetch('save_email_preferences.php', {
                                            method: 'POST',
                                            headers: {
                                                'Content-Type': 'application/json'
                                            },
                                            body: JSON.stringify({
                                                notify_new_movie: notifyNewMovie,
                                                email: email
                                            })
                                        })
                                        .then(response => response.json())
                                        .then(data => {
                                            if (!data) {
                                                throw new Error('Veri alınamadı.');
                                            }
                                            if (data.error) {
                                                throw new Error(data.error);
                                            }

                                            showNotification(data.message, notifyNewMovie === 1);
                                            emailPreferencesModal.classList.add('hidden');
                                        })
                                        .catch(error => {
                                            console.error('Hata:', error.message);
                                            showNotification('Bir hata oluştu. Lütfen tekrar deneyin.', false);
                                        });
                                });

                                // Bildirimleri göstermek için yardımcı fonksiyon
                                function showNotification(message, isSuccess) {
                                    // Bildirimin stilini belirle
                                    const notificationClass = isSuccess ? 'bg-green-500' : 'bg-red-500';
                                    mailInfo.classList.remove('bg-green-500', 'bg-red-500');
                                    mailInfo.classList.add(notificationClass);

                                    // Mesajı ayarla
                                    mailInfoText.textContent = message;

                                    // Bildirimi görünür yap
                                    mailInfo.classList.add('opacity-100');
                                    mailInfo.classList.remove('opacity-0');

                                    // Bildirimi 3 saniye sonra gizle
                                    setTimeout(() => {
                                        mailInfo.classList.remove('opacity-100');
                                        mailInfo.classList.add('opacity-0');
                                    }, 3000); // Bildirim 3 saniye sonra kaybolur
                                }
                            });
                        </script>
                    </div>
                </form>
            </div>

            <div class="bg-zinc-200 p-5 rounded">
                <div class="bg-zinc-200 rounded">
                    <!-- Yorumlar -->
                    <div class="flex flex-row items-center mb-4 space-x-2">
                        <img src="./cdn/last_commentss.png" class="w-8">
                        <h2 class="text-xl text-zinc-500 font-semibold">
                            <span class="text-zinc-600 font-bold"><?php echo htmlspecialchars($username); ?></span> kullanıcısının son yorumları
                        </h2>
                    </div>

                    <div class="md:flex md:flex-row md:space-x-2 grid grid-cols-1 gap-2">
                        <?php if (!empty($comments) && count($comments) > 0) : ?>
                            <?php $count = 0; ?>
                            <?php foreach ($comments as $comment) : ?>
                                <?php if ($count < 6 && !empty($comment['content'])) : ?>
                                    <div class="bg-gray-100 items-center p-4 rounded-lg">
                                        <div class="flex flex-row space-x-2 items-center mb-3">
                                            <img draggable="false" src="<?php echo htmlspecialchars($profilePicture); ?>" alt="<?php echo htmlspecialchars($username); ?>" class="w-8 h-8 rounded-full">
                                            <h1 class="font-bold"><?php echo htmlspecialchars($username); ?></h1>
                                        </div>
                                        <p class="font-semibold text-sm text-zinc-400"><?php echo htmlspecialchars($comment['content']); ?></p>
                                        <p class="text-xs text-gray-500 mt-2"><?php echo strftime('%e %B %Y - %H:%M', strtotime($comment['timestamp'])); ?></p>
                                        <p class="text-xs text-gray-500 mt-1 font-semibold">
                                            <a href="movie?id=<?php echo htmlspecialchars($comment['movie_id']); ?>" class="text-blue-500 hover:underline">
                                                <?php echo htmlspecialchars($comment['movie_title'], ENT_QUOTES, 'UTF-8'); ?>
                                            </a>
                                        </p>
                                    </div>
                                <?php endif; ?>
                                <?php $count++; ?>
                            <?php endforeach; ?>
                            <?php if ($count === 0) : ?>
                                <p class="mt-4 text-zinc-500/80 font-semibold">
                                    <i class="fa-solid fa-comment-slash"></i> Bu kullanıcı henüz yorum yapmamış.
                                </p>
                            <?php endif; ?>
                        <?php else : ?>
                            <p class="mt-4 text-zinc-500/80 font-semibold">
                                <i class="fa-solid fa-comment-slash"></i> Bu kullanıcı henüz yorum yapmamış.
                            </p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <div class="container mx-auto pt-3">
                <!-- Profil Bilgisi -->
                <?php if ($total_watched > 0) : ?>
                    <div class="bg-zinc-200 shadow-lg rounded-lg p-6 mb-5">
                        <p class="text-xl flex flex-row space-x-2 items-center font-semibold text-gray-800">
                            <i class="fa-solid fa-clock"></i>
                            <span>Toplam <strong><?php echo $total_hours; ?> saat <?php echo $total_minutes; ?> dakika</strong> boyunca film izledi</span>
                        </p>
                    </div>
                <?php endif; ?>

                <!-- İzlenen Filmler -->
                <div class="bg-zinc-200 shadow-lg rounded-lg p-6">
                    <h2 class="text-2xl flex flex-row space-x-2 items-center font-bold text-gray-800 mb-6">
                        <i class="fa-solid fa-film"></i>
                        <span>İzlediği Filmler (<?php echo htmlspecialchars($total_watched); ?>)</span>
                    </h2>

                    <?php if ($total_watched > 0) : ?>
                        <div class="z-10 grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6">
                            <?php foreach ($watched_movies as $movie) : ?>
                                <?php
                                // Tarihi Türkçe formatında düzenle
                                $watched_time = strtotime($movie['watched_time']);
                                $day_name = $days[date('l', $watched_time)];
                                $month_name = $months[date('n', $watched_time)];
                                $formatted_date = sprintf(
                                    "%d %s %s - %s:%s",
                                    date('j', $watched_time),
                                    $month_name,
                                    $day_name,
                                    date('H', $watched_time),
                                    date('i', $watched_time)
                                );

                                // Backdrop path URL'yi oluştur
                                $backdrop_path = isset($movie['backdrop_path']) ? "https://image.tmdb.org/t/p/w500" . $movie['backdrop_path'] : 'https://via.placeholder.com/500x750?text=No+Image';
                                ?>
                                <div class="relative border border-gray-300 z-20 rounded-lg overflow-hidden transition duration-300">
                                    <img src="<?php echo $backdrop_path; ?>" alt="<?php echo htmlspecialchars($movie['title']); ?>" class="w-full h-40 object-cover">
                                    <div class="relative">
                                        <div class="absolute bottom-0 right-0 left-0 top-0 bg-black opacity-90"></div>
                                        <div class="relative p-4">
                                            <a href="movie.php?id=<?php echo $movie['id']; ?>" class="text-white hover:underline text-lg font-semibold">
                                                <?php echo htmlspecialchars($movie['title']); ?>
                                            </a>
                                            <p class="text-gray-300 text-sm mt-2">İzleme tarihi: <?php echo $formatted_date; ?></p>
                                        </div>
                                    </div>
                                </div>

                            <?php endforeach; ?>
                        </div>
                    <?php else : ?>
                        <p class="text-gray-600">Henüz izlediği bir film bulunmuyor.</p>
                    <?php endif; ?>
                </div>
            </div>

        </div>

        <script src="https://unpkg.com/@popperjs/core@2"></script>
        <script src="https://unpkg.com/tippy.js@6"></script>
        <script>
            tippy('[data-tippy-content]', {
                placement: 'top',
                animation: 'shift-away'
            });
        </script>
</body>

</html>