<?php
require 'db.php';

$username = $email = $password = '';
$profilePicture = 'images/default_profile.jpg'; // Varsayılan profil resmi
$defaultBannerImage = 'images/default_banner.jpg'; // Varsayılan banner resmi

$usernameError = $emailError = $passwordError = '';
$uploadError = '';
$successMessage = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $username = $_POST['username'];
    $email = $_POST['email'];
    $password = $_POST['password'];

    // Profil resmi yükleme işlemi
    if (!empty($_FILES['profile_picture']['name'])) {
        $targetDir = "images/";
        $targetFile = $targetDir . basename($_FILES["profile_picture"]["name"]);
        if (move_uploaded_file($_FILES["profile_picture"]["tmp_name"], $targetFile)) {
            $profilePicture = $targetFile;
        } else {
            $uploadError = "Profil resmi yüklenirken bir hata oluştu.";
        }
    }

    // E-posta adresinin benzersiz olup olmadığını kontrol et
    $stmt = $pdo->prepare("SELECT id FROM users WHERE email = :email");
    $stmt->execute([':email' => $email]);
    $existingUser = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($existingUser) {
        $emailError = "Bu e-posta adresi zaten kullanılıyor.";
    }

    // Şifre güçlüğünü kontrol et (örneğin, en az 8 karakter olmalıdır)
    if (strlen($password) < 8) {
        $passwordError = "Şifreniz en az 8 karakterden oluşmalıdır.";
    }

    // Kullanıcı kaydını yap
    if (empty($usernameError) && empty($emailError) && empty($passwordError) && empty($uploadError)) {
        $hashedPassword = password_hash($password, PASSWORD_BCRYPT);

        // Kullanıcıyı 'users' tablosuna ekleyin
        $stmt = $pdo->prepare("INSERT INTO users (username, email, password, profile_picture, banner_image) VALUES (:username, :email, :password, :profile_picture, :banner_image)");
        $stmt->execute([
            ':username' => $username,
            ':email' => $email,
            ':password' => $hashedPassword,
            ':profile_picture' => $profilePicture,
            ':banner_image' => $defaultBannerImage
        ]);

        // Yeni üye rozetini 'badges' tablosuna ekleyin
        $badgeName = "Yeni Üye"; // Yeni üyeler için rozet adı
        $badgeDescription = "Kullanıcı yeni üye olarak platforma katıldı.";
        $badgeIcon = "cdn/badge-user.png"; // Rozet ikon URL'si

        $stmt = $pdo->prepare("INSERT INTO badges (user_id, badge_name, badge_description, badge_icon) VALUES (:user_id, :badge_name, :badge_description, :badge_icon)");
        $stmt->execute([
            ':user_id' => $pdo->lastInsertId(), // Son eklenen kullanıcı ID'sini alın
            ':badge_name' => $badgeName,
            ':badge_description' => $badgeDescription,
            ':badge_icon' => $badgeIcon
        ]);

        $successMessage = "Kaydınız başarıyla tamamlandı. 3 saniye içinde giriş sayfasına yönlendirileceksiniz.";
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Kayıt Ol</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <script src="https://cdn.tailwindcss.com"></script>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    <style>
        body {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            overflow: hidden;
            /* Gereksiz kaydırmayı önlemek için */
            background-color: #f3f4f6;
            /* Arka plan rengi */
        }

        .register-container {
            display: flex;
            width: 80%;
            max-width: 1200px;
            background-color: #fff;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            /* İçeriği sarmalamak için */
        }

        .register-left {
            flex: 1;
            display: flex;
            justify-content: center;
            align-items: center;
            background-image: url('./cdn/marvel.jpg');
            background-size: cover;
            background-position: center;
        }

        .register-right {
            flex: 1;
            padding: 40px;
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
        }

        .register-container h1 {
            font-size: 2.5rem;
            margin-bottom: 20px;
            color: #333;
            text-align: center;
            font-weight: 600;
        }

        .register-container form {
            width: 100%;
            max-width: 300px;
            display: flex;
            flex-direction: column;
        }

        .register-container label {
            font-size: 1.1rem;
            margin-bottom: 5px;
            color: #555;
            text-align: left;
        }

        .register-container input[type="text"],
        .register-container input[type="email"],
        .register-container input[type="password"],
        .register-container input[type="file"] {
            padding: 10px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            font-size: 1rem;
            transition: border-color 0.2s ease;
            outline: none;
            /* Focus ring kaldırma */
        }

        .register-container input[type="text"]:focus,
        .register-container input[type="email"]:focus,
        .register-container input[type="password"]:focus,
        .register-container input[type="file"]:focus {
            border-color: #3490dc;
            /* Focus rengi */
        }

        .register-container input[type="text"]:hover,
        .register-container input[type="email"]:hover,
        .register-container input[type="password"]:hover,
        .register-container input[type="file"]:hover {
            border-color: #eb660e;
            /* Hover rengi */
        }

        .register-container button {
            background-color: #3490dc;
            color: white;
            padding: 10px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 1.1rem;
            transition: background-color 0.3s ease;
        }

        .register-container button:hover {
            background-color: #2779bd;
        }

        .error-message {
            color: red;
            margin-top: 10px;
            text-align: center;
        }

        .success-message {
            color: green;
            margin-top: 10px;
            text-align: center;
        }

        /* Mobil cihazlarda gizle */
        @media (max-width: 768px) {
            .register-left {
                display: none !important;
            }
        }

        /* Masaüstü ve daha büyük ekranlarda göster */
        @media (min-width: 768px) {
            .register-left {
                display: flex !important;
            }
        }

        .preview-container {
            margin-top: 10px;
            max-width: 100%;
        }

        .preview-container img {
            max-width: 100%;
            height: auto;
            border-radius: 5px;
        }
    </style>
</head>

<body>

    <div class="register-container min-h-screen min-w-full">

        <a href="/" class="flex justify-center hover:opacity-85 hover:text-white  duration-150 items-center p-8 bg-orange-700 text-zinc-200" style="background-image: url(./cdn/line.png);">
            <div class="animate__animated animate__fadeInLeft flex flex-col space-y-2 items-center">
                <i class="fa-solid fa-house-crack fa-2xl mb-8"></i>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">N</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">S</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">Y</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">F</p>
                <p class="text-2xl font-light mx-4 animate__animated animate__fadeInLeft">A</p>
            </div>
        </a>

        <div class="register-left relative animate__animated animate__fadeIn">
            <span class="animate__animated animate__fadeInLeft absolute right-4 bottom-4 text-yellow-600 font-semibold hover:text-yellow-400 duration-300"><a target="_blank" href="https://www.besthdwallpaper.com/movies/doctor-strange-in-tranquility-marvel-comic-hero-dt_en-US-123976.html">Art by <strong>Hotty</strong></a></span>
        </div>
        <div class="register-right animate__animated animate__fadeIn">
            <h1><i class="fa-solid fa-user-plus"></i> Kayıt Ol</h1>
            <?php if (!empty($successMessage)) : ?>
                <div class="success-message"><?php echo $successMessage; ?></div>
                <script>
                    setTimeout(function() {
                        window.location.href = 'login.php';
                    }, 3000);
                </script>
            <?php else : ?>
                <form action="register" method="post" enctype="multipart/form-data">
                    <label for="username" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-user"></i> Kullanıcı Adı</label>
                    <input type="text" id="username" name="username" class="w-full p-2 border rounded" value="<?php echo htmlspecialchars($username); ?>" required>
                    <?php if (!empty($usernameError)) : ?>
                        <div class="error-message"><?php echo $usernameError; ?></div>
                    <?php endif; ?>
                    <label for="email" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-envelope"></i> Email</label>
                    <input type="email" id="email" name="email" class="w-full p-2 border rounded" value="<?php echo htmlspecialchars($email); ?>" required>
                    <?php if (!empty($emailError)) : ?>
                        <div class="error-message"><?php echo $emailError; ?></div>
                    <?php endif; ?>
                    <label for="password" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-key"></i> Şifre</label>
                    <input type="password" id="password" name="password" class="w-full p-2 border rounded" required>
                    <?php if (!empty($passwordError)) : ?>
                        <div class="error-message"><?php echo $passwordError; ?></div>
                    <?php endif; ?>
                    <button type="submit" class="bg-gradient-to-r from-orange-600 to-orange-500 hover:opacity-85 duration-150 font-semibold px-4 py-2 rounded mt-4"><i class="fa-solid fa-user-plus"></i> Kayıt Ol</button>
                </form>
                <div class="flex justify-center items-center mx-auto mt-3 mb-2 text-sm font-semibold">
                    <span>Hesabın var mı? <a class="hover:px-2 font-bold text-orange-500 hover:text-orange-600 duration-300 mx-1 border border-orange-500/30 hover:bg-orange-100 px-3 bg-orange-100/50" href="/login"><i class="fa-solid fa-right-to-bracket"></i> Giriş yap</a></span>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // Profil resmi önizleme işlevselliği
        const fileInput = document.getElementById('profile_picture');
        const imagePreview = document.getElementById('imagePreview');

        fileInput.addEventListener('change', function() {
            const file = this.files[0];

            if (file) {
                const reader = new FileReader();

                reader.addEventListener('load', function() {
                    imagePreview.src = reader.result;
                    imagePreview.parentElement.classList.remove('hidden');
                });

                reader.readAsDataURL(file);
            }
        });
    </script>
</body>

</html>