<?php
require 'db.php';

if (isset($_SESSION['is_mobile']) && $_SESSION['is_mobile'] === true) {
    header("Location: index.php");
    exit;
}

$success_message = '';
$error_message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $token = $_POST['token'];
    $password = $_POST['password'];
    $confirm_password = $_POST['confirm_password'];

    if ($password === $confirm_password) {
        // Veritabanında token ile eşleşen kullanıcıyı bul
        $stmt = $pdo->prepare("SELECT * FROM users WHERE reset_token = :reset_token AND reset_token_expires_at > NOW()");
        $stmt->bindParam(':reset_token', $token);
        $stmt->execute();
        $user = $stmt->fetch();

        if ($user) {
            // Şifreyi güncelle
            $hashed_password = password_hash($password, PASSWORD_BCRYPT);
            $stmt = $pdo->prepare("UPDATE users SET password = :password, reset_token = NULL, reset_token_expires_at = NULL WHERE id = :user_id");
            $stmt->execute([
                ':password' => $hashed_password,
                ':user_id' => $user['id']
            ]);

            $success_message = 'Şifreniz başarıyla güncellendi. Yeni şifrenizle giriş yapabilirsiniz.';
        } else {
            $error_message = 'Geçersiz veya süresi dolmuş token.';
        }
    } else {
        $error_message = 'Şifreler eşleşmiyor.';
    }
} else if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $token = $_GET['token'];
}
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Şifreyi Sıfırla</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        body {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            overflow: hidden;
        }

        .reset-password-container {
            display: flex;
            width: 80%;
            max-width: 600px;
            background-color: #fff;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }

        .reset-password-left {
            flex: 1;
            display: flex;
            justify-content: center;
            align-items: center;
            background-image: url('https://cdn2.hubspot.net/hubfs/2721854/Cybersecurity%20-%2010-31-2019.jpg');
            background-size: cover;
            background-position: center;
        }

        .reset-password-right {
            flex: 1;
            padding: 40px;
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
        }

        .reset-password-container h1 {
            font-size: 2.5rem;
            margin-bottom: 20px;
            color: #333;
            text-align: center;
        }

        .reset-password-container form {
            width: 100%;
            max-width: 300px;
            display: flex;
            flex-direction: column;
        }

        .reset-password-container label {
            font-size: 1.1rem;
            margin-bottom: 5px;
            color: #555;
            text-align: left;
        }

        .reset-password-container input[type="password"] {
            padding: 10px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            font-size: 1rem;
        }

        .reset-password-container button {
            background-color: #3490dc;
            color: white;
            padding: 10px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 1.1rem;
            transition: background-color 0.3s ease;
        }

        .reset-password-container button:hover {
            background-color: #2779bd;
        }

        .error-message,
        .success-message {
            color: #333;
            margin-top: 10px;
            text-align: center;
        }

        .error-message {
            color: red;
        }

        .success-message {
            color: green;
        }
    </style>
</head>

<body>
    <div class="reset-password-container min-h-screen min-w-full relative">
        <div class="absolute"></div>
        <div class="relative reset-password-left"></div>
        <div class="reset-password-right relative">
            <h1 class="text-3xl md:text-4xl lg:text-5xl mb-6 text-center text-gray-800 font-semibold"><i class="fa-solid fa-key"></i> Şifreyi Sıfırla</h1>
            <form action="reset_password.php" method="post" class="w-full max-w-sm mx-auto">
                <?php if (!empty($error_message)) : ?>
                    <div class="error-message"><?php echo $error_message; ?></div>
                <?php endif; ?>
                <?php if (!empty($success_message)) : ?>
                    <div class="success-message">
                        <?php echo $success_message; ?>
                        <p>Giriş sayfasına yönlendiriliyorsunuz...</p>
                        <p id="countdown">3</p>
                        <script>
                            let countdown = 3;
                            const countdownElement = document.getElementById('countdown');
                            const interval = setInterval(() => {
                                countdown--;
                                countdownElement.textContent = countdown;
                                if (countdown === 0) {
                                    clearInterval(interval);
                                    window.location.href = 'login'; // Giriş sayfasının URL'sini buraya yazın
                                }
                            }, 1000);
                        </script>
                    </div>
                <?php endif; ?>
                <input type="hidden" name="token" value="<?php echo htmlspecialchars($token); ?>">
                <div class="mb-4">
                    <label for="password" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-lock"></i> Yeni Şifre</label>
                    <input type="password" id="password" name="password" class="w-full p-2 border rounded focus:outline-none focus:border-blue-500" required>
                </div>
                <div class="mb-4">
                    <label for="confirm_password" class="block text-gray-700 font-semibold mb-1"><i class="fa-solid fa-lock"></i> Şifreyi Onayla</label>
                    <input type="password" id="confirm_password" name="confirm_password" class="w-full p-2 border rounded focus:outline-none focus:border-blue-500" required>
                </div>
                <button type="submit" class="w-full py-2 px-4 bg-blue-500 text-white rounded hover:bg-blue-600 transition duration-300">Sıfırla</button>
            </form>
        </div>
    </div>

    <?php include 'footer.php'; ?>


</body>

</html>