<?php
session_start();
include 'db.php';

// JSON verisini al
$data = json_decode(file_get_contents('php://input'), true);

// JSON verisini kontrol et
if ($data === null) {
    echo json_encode(['error' => 'Geçersiz veri. Lütfen verilerinizi kontrol edin.']);
    exit();
}

if (!isset($_SESSION['user_id'])) {
    echo json_encode(['error' => 'Giriş yapmadınız. Lütfen giriş yapın.']);
    exit();
}

$user_id = $_SESSION['user_id'];
$notify_new_movie = isset($data['notify_new_movie']) ? $data['notify_new_movie'] : 0;
$email = isset($data['email']) ? $data['email'] : '';

// Veritabanı bağlantısını kontrol et
if (!isset($pdo) || $pdo === false) {
    echo json_encode(['error' => 'Veritabanı bağlantısı hatası. Lütfen veritabanı ayarlarınızı kontrol edin.']);
    exit();
}

try {
    // Kullanıcının mevcut verilerini kontrol et
    $sql = "SELECT COUNT(*) FROM email_preferences WHERE user_id = :user_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
    $stmt->execute();
    $exists = $stmt->fetchColumn();

    if ($exists) {
        // Mevcut veri varsa güncelle
        $sql = "UPDATE email_preferences 
                SET notify_new_movie = :notify_new_movie, email = :email 
                WHERE user_id = :user_id";
        $action = 'güncellendi';
    } else {
        // Mevcut veri yoksa ekle
        $sql = "INSERT INTO email_preferences (user_id, notify_new_movie, email) 
                VALUES (:user_id, :notify_new_movie, :email)";
        $action = 'eklendi';
    }

    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
    $stmt->bindParam(':notify_new_movie', $notify_new_movie, PDO::PARAM_INT);
    $stmt->bindParam(':email', $email, PDO::PARAM_STR);
    
    // Sorguyu çalıştır
    $stmt->execute();
    
    // Detaylı bilgi mesajı
    $message = $notify_new_movie 
        ? 'E-posta tercihleri ' . ($action === 'eklendi' ? 'kaydedildi. Artık bildirim alacaksın.' : 'güncellendi. Artık bildirim alacaksın.')
        : 'E-posta tercihleri ' . ($action === 'eklendi' ? 'kaydedildi. Artık bildirim almayacaksın.' : 'güncellendi. Artık film bildirimi almayacaksın.');
    
    echo json_encode(['message' => $message]);
} catch (PDOException $e) {
    echo json_encode(['error' => 'Bir hata oluştu: ' . $e->getMessage()]);
}
?>