<?php
include 'db.php';

session_start();

// Kullanıcının giriş yapmış olup olmadığını kontrol et
$userLoggedIn = isset($_SESSION['user_id']);

// Kullanıcı giriş yapmışsa, kullanıcı ID'sini al
$userId = $_SESSION['user_id'] ?? null;

include 'navbar.php'; // Başlık ve NAV

$tag = $_GET['tag'] ?? '';

if ($tag) {
    $query = "SELECT tags.tag, comments.content, users.username, users.profile_picture, users.id AS user_id, movies.id AS movie_id, movies.title 
              FROM tags 
              JOIN comments ON tags.comment_id = comments.id 
              JOIN users ON tags.user_id = users.id 
              JOIN movies ON tags.movie_id = movies.id 
              WHERE tags.tag = ?";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$tag]);
    $tagDetails = $stmt->fetchAll();
} else {
    $query = "SELECT DISTINCT tag FROM tags";
    $stmt = $pdo->query($query);
    $tags = $stmt->fetchAll();
}

// Toplam etiket sayısı
$totalTagsQuery = "SELECT COUNT(DISTINCT tag) AS total_tags FROM tags";
$totalTagsStmt = $pdo->query($totalTagsQuery);
$totalTags = $totalTagsStmt->fetchColumn();

// Son eklenen etiketler
$latestTagsQuery = "SELECT DISTINCT tag FROM tags ORDER BY id DESC LIMIT 5";
$latestTagsStmt = $pdo->query($latestTagsQuery);
$latestTagsArray = $latestTagsStmt->fetchAll(PDO::FETCH_COLUMN);

// Etiketleri virgülle ayırarak birleştir
$latestTagsString = implode(', ', $latestTagsArray);
?>
<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy - Etiketler</title>
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="title" content="Foxy'da son zamanlarda <?= htmlspecialchars($totalTags) ?> adet etiket var.">
    <meta name="description" content="Son etiketler | <?= htmlspecialchars($latestTagsString) ?>">
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.6.0/css/all.min.css" integrity="sha512-Kc323vGBEqzTmouAECnVceyQqyqdsSiqLQISBL29aUW4U/M7pSPA/gEUZQqv1cwx4OnYxTxve5UMg5GT6L4JJg==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <script src="https://cdn.tailwindcss.com"></script>
</head>

<body class="bg-gray-100">
    <a href="/tags.php" class="hover:p-2 text-blue-500 mb-8 block hover:bg-blue-500/10 p-4 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Anasayfa'ya dön</a>

    <div class="container mx-auto p-4">
        <!-- Geri Dönüş Bağlantısı -->
        <a href="/tags.php" class="hover:opacity-75 text-blue-500 mb-8 block bg-blue-100 rounded inline-flex flex-row space-x-1 items-center duration-300 font-semibold"><i class="fa-solid fa-hashtag font-extrabold"></i> <span>Tüm etiketler</span></a>

        <h1 class="text-3xl text-zinc-600 font-bold mb-4"><i class="fa-solid fa-tag"></i> Etiketler</h1>

        <?php if ($tag) : ?>
            <h2 class="text-2xl font-bold mb-4">#<?= htmlspecialchars($tag) ?></h2>
            <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                <?php if (!empty($tagDetails)) : ?>
                    <?php foreach ($tagDetails as $detail) : ?>
                        <div class="text-zinc-600 hover:shadow-xl hover:bg-gradient-to-r hover:from-cyan-50 transition-all hover:to-blue-50 duration-150 p-6 rounded-lg shadow-lg bg-white/40 mb-4">
                            <div class="flex items-start mb-4">
                                <img src="<?= htmlspecialchars($detail['profile_picture']) ?>" alt="Profil Resmi" class="w-12 h-12 rounded-full mr-4">
                                <div>
                                    <h3 class="text-xl font-bold">
                                        <a href="profile.php?user_id=<?= htmlspecialchars($detail['user_id']) ?>" class="hover:underline"><?= htmlspecialchars($detail['username']) ?></a>
                                    </h3>
                                    <p class="">
                                        Film:
                                        <a href="movie?id=<?= htmlspecialchars($detail['movie_id']) ?>" class="text-blue-500 hover:underline" data-tippy-content="<strong><?= htmlspecialchars($detail['title']) ?></strong> filminin sayfasına git">
                                            <?= htmlspecialchars($detail['title']) ?>
                                        </a>
                                    </p>
                                </div>
                            </div>
                            <p><?= htmlspecialchars($detail['content']) ?></p>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <div class="text-zinc-500 font-semibold">Henüz bu isme sahip bir etiket yok. Sen oluşturmak ister misin? Etiketini oluşturmak istediğin film sayfasında yorum eklerken #<?= htmlspecialchars($tag) ?> kullanabilirsin.</div>
                <?php endif; ?>
            </div>
        <?php else : ?>
            <div class="grid grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-4">
                <?php foreach ($tags as $tag) : ?>
                    <div class="bg-white/30 p-4 rounded shadow hover:shadow-lg transition-shadow duration-300">
                        <a href="tags.php?tag=<?= htmlspecialchars($tag['tag']) ?>" class="text-blue-500 hover:underline text-lg">#<?= htmlspecialchars($tag['tag']) ?></a>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>

    </div>


    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            placement: 'top',
            animation: 'shift-away',
            allowHTML: true,
        });
    </script>
</body>

</html>