<?php
session_start(); // Session başlat
require 'db.php'; // Veritabanı bağlantısı
include 'navbar.php';

// TMDb API ayarları
$tmdbApiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f'; // TMDb API anahtarı
$baseImageUrl = 'https://image.tmdb.org/t/p/w500'; // Poster resimlerinin temel URL'si

// Fonksiyon: TMDb API'ye istek gönderme
function tmdbApiRequest($url)
{
    $ch = curl_init();
    curl_setopt_array($ch, [
        CURLOPT_URL => $url,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_SSL_VERIFYHOST => false,
        CURLOPT_SSL_VERIFYPEER => false,
    ]);
    $response = curl_exec($ch);
    curl_close($ch);
    return json_decode($response, true);
}

// Fonksiyon: Filmin poster URL'sini al
function getMoviePosterUrl($posterPath)
{
    global $baseImageUrl;
    return $baseImageUrl . $posterPath;
}

// Veritabanı bağlantısı ve diğer ayarlamalar


// En fazla yorum yapılan filmi bulma sorgusu
$stmtComments = $pdo->prepare("
    SELECT 
        movies.id,
        movies.title,
        movies.poster_path,
        COUNT(comments.id) AS comment_count
    FROM movies
    LEFT JOIN comments ON movies.id = comments.movie_id
    GROUP BY movies.id
    ORDER BY comment_count DESC
    LIMIT 1
");
$stmtComments->execute();
$mostCommentedMovie = $stmtComments->fetch(PDO::FETCH_ASSOC);

// En yüksek puan alan filmi bulma sorgusu
$stmtRatings = $pdo->prepare("
    SELECT 
        movies.id,
        movies.title,
        movies.poster_path,
        AVG(ratings.rating) AS avg_rating
    FROM movies
    LEFT JOIN ratings ON movies.id = ratings.movie_id
    GROUP BY movies.id
    ORDER BY avg_rating DESC
    LIMIT 1
");
$stmtRatings->execute();
$highestRatedMovie = $stmtRatings->fetch(PDO::FETCH_ASSOC);

// En fazla beğenilen filmi bulma sorgusu
$stmtLikes = $pdo->prepare("
    SELECT 
        movies.id,
        movies.title,
        movies.poster_path,
        COUNT(likes.id) AS like_count
    FROM movies
    LEFT JOIN likes ON movies.id = likes.movie_id
    GROUP BY movies.id
    ORDER BY like_count DESC
    LIMIT 1
");
$stmtLikes->execute();
$mostLikedMovie = $stmtLikes->fetch(PDO::FETCH_ASSOC);

// En fazla yorum yapan kullanıcıyı bulma sorgusu
$stmtTopCommenter = $pdo->prepare("
    SELECT 
        users.id,
        users.username,
        users.profile_picture,
        COUNT(comments.id) AS comment_count
    FROM comments
    LEFT JOIN users ON comments.user_id = users.id
    GROUP BY users.id
    ORDER BY comment_count DESC
    LIMIT 1
");
$stmtTopCommenter->execute();
$topCommenter = $stmtTopCommenter->fetch(PDO::FETCH_ASSOC);


// En fazla görüntülenen filmi bulma sorgusu
$stmtViews = $pdo->prepare("
    SELECT 
        movies.id,
        movies.title,
        movies.poster_path,
        COUNT(page_visitors.id) AS view_count
    FROM movies
    LEFT JOIN page_visitors ON movies.id = page_visitors.page_id
    GROUP BY movies.id
    ORDER BY view_count DESC
    LIMIT 1
");
$stmtViews->execute();
$mostViewedMovie = $stmtViews->fetch(PDO::FETCH_ASSOC);


// HTML başlangıcı
?>
<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy - En'ler</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta property="title" content="Foxy - EN'LER" />
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <meta property="description" content="Foxy'in en'lerine göz at! | En fazla yorum alan filmler - En fazla oy alan filmler - En fazla beğenilen filmler - En fazla görüntülenen filmler ve En fazla yorum yapan kullanıcı" />
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
</head>

<body class="bg-gray-100">
    <?php include 'duyuru.php'; ?>

    <div class="container mx-auto p-4">


        <!-- Geri Dönüş Bağlantısı -->
        <a href="/" class="hover:p-2 text-start text-blue-500 mb-8 block hover:bg-blue-500/10 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Geri dön</a>

        <div class="mt-6 grid grid-cols-1 md:grid-cols-2 gap-6">

            <div>
                <!-- En Fazla Yorum Yapılan Film -->
                <h1 class="text-xl text-start text-zinc-600 font-bold mb-4"><i class="fa-solid fa-comments"></i> En fazla yorum alan</h1>
                <div class="bg-white shadow-md rounded-lg flex items-center">
                    <?php if ($mostCommentedMovie) : ?>
                        <?php
                        // TMDb API'den film detaylarını al
                        $tmdbMovieUrl = "https://api.themoviedb.org/3/movie/{$mostCommentedMovie['id']}?api_key={$tmdbApiKey}&language=tr-TR";
                        $movieDetails = tmdbApiRequest($tmdbMovieUrl);
                        ?>
                        <div class="flex-shrink-0">
                            <?php if ($movieDetails && isset($movieDetails['poster_path'])) : ?>
                                <img src="<?php echo getMoviePosterUrl($movieDetails['poster_path']); ?>" alt="<?php echo htmlspecialchars($mostCommentedMovie['title']); ?>" class="w-[130px] md:w-36 object-cover rounded-md">
                            <?php else : ?>
                                <img src="./cdn/default-movie-poster.png" alt="<?php echo htmlspecialchars($mostCommentedMovie['title']); ?>" class="w-24 h-36 object-cover rounded-md">
                            <?php endif; ?>
                        </div>
                        <div class="ml-4">
                            <h2 class="text-lg md:text-2xl mb-2 text-start font-semibold"><?php echo htmlspecialchars($mostCommentedMovie['title'], ENT_QUOTES | ENT_HTML5, 'UTF-8'); ?></h2>
                            <p class="text-gray-600 text-start"><i class="fa-solid fa-clapperboard"></i> Bu zamana kadar <strong><?php echo htmlspecialchars($mostCommentedMovie['comment_count'], ENT_QUOTES | ENT_HTML5, 'UTF-8'); ?></strong> yorum aldı.</p>

                        </div>
                    <?php else : ?>
                        <p class="text-gray-500 p-4 rounded">Veri bulunamadı LAAAAAANN</p>
                    <?php endif; ?>
                </div>
            </div>

            <div>
                <!-- En Yüksek Puan Alan Film -->
                <h1 class="text-xl text-start text-zinc-600 font-bold mb-4"><i class="fa-solid fa-ranking-star"></i> En fazla oy alan</h1>
                <div class="bg-white shadow-md rounded-lg flex items-center">
                    <?php if ($highestRatedMovie) : ?>
                        <?php
                        // TMDb API'den film detaylarını al
                        $tmdbMovieUrl = "https://api.themoviedb.org/3/movie/{$highestRatedMovie['id']}?api_key={$tmdbApiKey}&language=tr-TR";
                        $movieDetails = tmdbApiRequest($tmdbMovieUrl);
                        ?>
                        <div class="flex-shrink-0">
                            <?php if ($movieDetails && isset($movieDetails['poster_path'])) : ?>
                                <img src="<?php echo getMoviePosterUrl($movieDetails['poster_path']); ?>" alt="<?php echo htmlspecialchars($highestRatedMovie['title']); ?>" class="w-[130px] md:w-36 object-cover rounded-md">
                            <?php else : ?>
                                <img src="./cdn/default-movie-poster.png" alt="<?php echo htmlspecialchars($highestRatedMovie['title']); ?>" class="w-24 h-36 object-cover rounded-md">
                            <?php endif; ?>
                        </div>
                        <div class="ml-4">
                            <h2 class="text-lg md:text-2xl mb-2 text-start font-semibold"><?php echo htmlspecialchars($highestRatedMovie['title']); ?></h2>
                            <p class="text-gray-600 text-start"><i class="fa-solid fa-star"></i> <strong><?php echo number_format($highestRatedMovie['avg_rating'], 1); ?></strong> ortalama ile platformun en fazla oylanan filmi.</p>
                        </div>
                    <?php else : ?>
                        <p class="text-gray-500 p-4 rounded">Veri bulunamadı LAAAAAANN</p>
                    <?php endif; ?>
                </div>
            </div>

            <div>
                <!-- En Fazla Beğenilen Film -->
                <h1 class="text-xl text-start text-zinc-600 font-bold mb-4"><i class="fa-brands fa-gratipay"></i> En fazla beğenilen</h1>
                <div class="bg-white shadow-md rounded-lg flex items-center">
                    <?php if ($mostLikedMovie) : ?>
                        <?php
                        // TMDb API'den film detaylarını al
                        $tmdbMovieUrl = "https://api.themoviedb.org/3/movie/{$mostLikedMovie['id']}?api_key={$tmdbApiKey}&language=tr-TR";
                        $movieDetails = tmdbApiRequest($tmdbMovieUrl);
                        ?>
                        <div class="flex-shrink-0">
                            <?php if ($movieDetails && isset($movieDetails['poster_path'])) : ?>
                                <img src="<?php echo getMoviePosterUrl($movieDetails['poster_path']); ?>" alt="<?php echo htmlspecialchars($mostLikedMovie['title']); ?>" class="w-[130px] md:w-36 object-cover rounded-md">
                            <?php else : ?>
                                <img src="./cdn/default-movie-poster.png" alt="<?php echo htmlspecialchars($mostLikedMovie['title']); ?>" class="w-24 h-36 object-cover rounded-md">
                            <?php endif; ?>
                        </div>
                        <div class="ml-4">
                            <h2 class="text-lg md:text-2xl mb-2 text-start font-semibold"><?php echo htmlspecialchars($mostLikedMovie['title']); ?></h2>
                            <p class="text-gray-600 text-start"><i class="fa-solid fa-heart"></i> Toplam <strong><?php echo htmlspecialchars($mostLikedMovie['like_count']); ?></strong> beğeni aldı. Vay be!</p>
                        </div>
                    <?php else : ?>
                        <p class="text-gray-500 p-4 rounded">Veri bulunamadı LAAAAAANN</p>
                    <?php endif; ?>
                </div>
            </div>

            <div>
                <h1 class="text-xl text-start text-zinc-600 font-bold mb-4"><i class="fa-solid fa-eye"></i> En fazla görüntülenen</h1>
                <div class="bg-white shadow-md rounded-lg flex items-center">
                    <?php if ($mostViewedMovie) : ?>
                        <?php
                        // TMDb API'den film detaylarını al
                        $tmdbMovieUrl = "https://api.themoviedb.org/3/movie/{$mostViewedMovie['id']}?api_key={$tmdbApiKey}&language=tr-TR";
                        $movieDetails = tmdbApiRequest($tmdbMovieUrl);
                        ?>
                        <div class="flex-shrink-0">
                            <?php if ($movieDetails && isset($movieDetails['poster_path'])) : ?>
                                <img src="<?php echo getMoviePosterUrl($movieDetails['poster_path']); ?>" alt="<?php echo htmlspecialchars($mostViewedMovie['title']); ?>" class="w-[130px] md:w-36 object-cover rounded-md">
                            <?php else : ?>
                                <img src="./cdn/default-movie-poster.png" alt="<?php echo htmlspecialchars($mostViewedMovie['title']); ?>" class="w-24 h-36 object-cover rounded-md">
                            <?php endif; ?>
                        </div>
                        <div class="ml-4">
                            <h2 class="text-lg md:text-2xl mb-2 text-start font-semibold"><?php echo htmlspecialchars($mostViewedMovie['title'], ENT_QUOTES | ENT_HTML5, 'UTF-8'); ?></h2>
                            <p class="text-gray-600 text-start"><i class="fa-solid fa-eye"></i> Bu film <strong><?php echo htmlspecialchars($mostViewedMovie['view_count'], ENT_QUOTES | ENT_HTML5, 'UTF-8'); ?></strong> kez görüntülendi.</p>
                        </div>
                    <?php else : ?>
                        <p class="text-gray-500 p-4 rounded">Veri bulunamadı LAAAAAANN</p>
                    <?php endif; ?>
                </div>
            </div>


            <div>

                <!-- En Fazla Yorum Yapan Kullanıcı -->
                <h1 class="text-xl text-start text-zinc-600 font-bold mb-4"><i class="fa-solid fa-users"></i> En fazla yorum yapan kullanıcı</h1>
                <div class="bg-white p-4 shadow-md rounded-lg flex items-center">
                    <?php if ($topCommenter && isset($topCommenter['profile_picture'])) : ?>
                        <div class="flex-shrink-0">
                            <img src="<?php echo htmlspecialchars($topCommenter['profile_picture']); ?>" alt="Profil Resmi" class="w-20 h-20 md:w-24 md:h-24 object-cover rounded-full">
                        </div>
                    <?php else : ?>
                        <div class="flex-shrink-0">
                            <img src="./cdn/default-profile-picture.png" alt="Varsayılan Profil Resmi" class="w-20 h-20 md:w-24 md:h-24 object-cover rounded-full">
                        </div>
                    <?php endif; ?>
                    <div class="ml-4">
                        <?php if ($topCommenter) : ?>
                            <a href="profile.php?user_id=<?php echo htmlspecialchars($topCommenter['id']); ?>" class="text-gray-900 hover:underline">
                                <h2 class="text-lg md:text-2xl mb-2 text-start font-bold"><?php echo htmlspecialchars($topCommenter['username']); ?></h2>
                            </a>
                            <p class="text-gray-600 text-start"><i class="fa-solid fa-comment-dots"></i> Toplam <strong><?php echo htmlspecialchars($topCommenter['comment_count']); ?></strong> yorum yaptı. Kendisini tebrik ediyoruz!</p>
                            <?php if (!empty($topCommenter['badges'])) : ?>
                                <p class="text-gray-600">Rozetler: <?php echo htmlspecialchars($topCommenter['badges']); ?></p>
                            <?php endif; ?>
                        <?php else : ?>
                            <p class="text-gray-500 p-4 rounded">Veri bulunamadı LAAAAAANN</p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

        </div>

    </div>

</body>

</html>