<?php
session_start();

// Database connection and other necessary files
require 'db.php'; // Database connection
require 'tmdb.php'; // TMDb API functions

if (isset($_SESSION['is_mobile']) && $_SESSION['is_mobile'] === true) {
    header("Location: index.php");
    exit;
}

// Türkçe ayarları yap
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

$userLoggedIn = isset($_SESSION['user_id']);

// Define $userId if user is logged in
$userId = null;
if ($userLoggedIn) {
    $userId = $_SESSION['user_id'];
}


// Function: Fetch TV show videos from TMDb
function fetchTVShowVideos($tvId)
{
    $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f'; // TMDb API key
    $url = "https://api.themoviedb.org/3/tv/$tvId/videos?api_key=$apiKey&language=tr-TR";

    // Send GET request to the API
    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    curl_close($ch);

    // Decode response JSON
    $videos = json_decode($response, true);

    // Check if $videos is not null and if 'results' key exists
    if (!empty($videos) && isset($videos['results']) && is_array($videos['results'])) {
        // Filter only trailers
        $trailers = array_filter($videos['results'], function ($video) {
            return $video['type'] === 'Trailer';
        });
        return $trailers;
    } else {
        // Log the error message for debugging
        error_log("Invalid API response: " . print_r($videos, true));
        return []; // Return empty array if no valid videos found
    }
}

// Function: Add notification for a user
function addNotification($userId, $message)
{
    global $pdo;
    $stmt = $pdo->prepare("
        INSERT INTO notifications (user_id, message)
        VALUES (:user_id, :message)
    ");
    $stmt->execute(['user_id' => $userId, 'message' => $message]);
}

// Function: Get badges of a user
function getUserBadges($userId)
{
    global $pdo;
    $stmt = $pdo->prepare("SELECT * FROM badges WHERE user_id = :user_id");
    $stmt->execute(['user_id' => $userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Function: Add badge to a user
function addUserBadge($userId, $badgeName, $badgeDescription, $badgeIcon, $commentCount)
{
    global $pdo;
    $stmt = $pdo->prepare("
        INSERT INTO badges (user_id, badge_name, badge_description, badge_icon, comment_count)
        VALUES (:user_id, :badge_name, :badge_description, :badge_icon, :comment_count)
    ");
    $stmt->execute([
        'user_id' => $userId,
        'badge_name' => $badgeName,
        'badge_description' => $badgeDescription,
        'badge_icon' => $badgeIcon,
        'comment_count' => $commentCount
    ]);

    // Send notification
    $badgeName = htmlspecialchars($badgeName, ENT_QUOTES, 'UTF-8'); // XSS protection
    $message = "Tebrikler! <strong>$badgeName</strong> rozetini kazandınız.";
    addNotification($userId, $message);
}

// Check if user is logged in
$userLoggedIn = isset($_SESSION['user_id']);

// Check if TV show ID is provided
if (isset($_GET['id'])) {
    $tvId = $_GET['id'];
    $tvShow = getTVShowDetails($tvId); // Function to get TV show details

    // Get comments and total comment count per user
    $stmt = $pdo->prepare("
        SELECT 
            comments.id, 
            users.id AS user_id, 
            users.username, 
            users.profile_picture, 
            users.verified,
            users.admin,            
            comments.content, 
            comments.timestamp,
            comments.edited,
            (SELECT COUNT(*) FROM comments WHERE user_id = users.id) AS comment_count 
        FROM comments
        JOIN users ON comments.user_id = users.id
        WHERE comments.tv_id = :tv_id
        ORDER BY comments.timestamp DESC
        LIMIT 20
    ");

    $stmt->execute(['tv_id' => $tvId]);
    $comments = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Calculate total comment count
    $stmt = $pdo->prepare("SELECT COUNT(*) as total_comments FROM comments WHERE tv_id = :tv_id");
    $stmt->execute(['tv_id' => $tvId]);
    $totalComments = $stmt->fetch(PDO::FETCH_ASSOC)['total_comments'];



    // Fetch TV show videos
    $videos = fetchTVShowVideos($tvId);
    $videoKey = !empty($videos) ? $videos[0]['key'] : null; // Get key of the first trailer if available

} else {
    echo "TV show ID is not specified.";
    exit();
}

// Delete Comment Action
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['comment_id'])) {
    $commentId = $_GET['comment_id'];
    // Additional checks can be added to verify if the comment belongs to the user.
    $stmt = $pdo->prepare("DELETE FROM comments WHERE id = :comment_id");
    $stmt->execute(['comment_id' => $commentId]);

    // Refresh page after deleting comment
    header("Location: tv?id=$tvId");
    exit();
}

// Check if user has reached a certain comment count and give badge
if ($userLoggedIn) {
    $userId = $_SESSION['user_id'];
    $stmt = $pdo->prepare("SELECT COUNT(*) as comment_count FROM comments WHERE user_id = :user_id");
    $stmt->execute(['user_id' => $userId]);
    $commentCount = $stmt->fetch(PDO::FETCH_ASSOC)['comment_count'];

    // Badge check and award based on comment count
    if ($commentCount >= 10) {
        // Check if user already has the badge
        $existingBadge = getUserBadges($userId);

        // 10 Yorum Rozeti
        $badgeName10 = '10 Yorum';
        $badgeDescription10 = '10. yorumuna ulaştı';
        $badgeIcon10 = 'cdn/badge-10.png'; // Rozet ikonu URL'si

        // 50 Yorum Rozeti
        $badgeName50 = '50 Yorum';
        $badgeDescription50 = 'Vay be! 50 yorum yaptı.';
        $badgeIcon50 = 'cdn/badge-50.png'; // Rozet ikonu URL'si

        // 150 Yorum Rozeti
        $badgeName150 = '150 Yorum';
        $badgeDescription150 = 'Efsanevi! 150 yorum yaptı.';
        $badgeIcon150 = 'cdn/badge-150.png'; // Rozet ikonu URL'si

        // 500 Yorum Rozeti
        $badgeName500 = '500 Yorum';
        $badgeDescription500 = 'İnanılmaz! 500 yorum yapmayı başardı.';
        $badgeIcon500 = 'cdn/badge-500.png'; // Rozet ikonu URL'si

        // 1000 Yorum Rozeti
        $badgeName1000 = '1000 Yorum';
        $badgeDescription1000 = 'DURDURULAMAZ! 1.000 yorumunu ekledi!';
        $badgeIcon1000 = 'cdn/badge-1000.png'; // Rozet ikonu URL'si

        // 2000 Yorum Rozeti
        $badgeName2000 = '2000 Yorum';
        $badgeDescription2000 = 'BU ADAM BİR YAŞAYAN EFSANE! 2.000 YORUMU VAAR!!';
        $badgeIcon2000 = 'cdn/badge-2000.png'; // Rozet ikonu URL'si

        // Check if user already has each badge
        $hasBadge10 = false;
        $hasBadge50 = false;
        $hasBadge150 = false;
        $hasBadge500 = false;
        $hasBadge1000 = false;
        $hasBadge2000 = false;

        foreach ($existingBadge as $badge) {
            if ($badge['badge_name'] === $badgeName10) {
                $hasBadge10 = true;
            }
            if ($badge['badge_name'] === $badgeName50) {
                $hasBadge50 = true;
            }
            if ($badge['badge_name'] === $badgeName150) {
                $hasBadge150 = true;
            }
            if ($badge['badge_name'] === $badgeName500) {
                $hasBadge500 = true;
            }
            if ($badge['badge_name'] === $badgeName1000) {
                $hasBadge1000 = true;
            }
            if ($badge['badge_name'] === $badgeName2000) {
                $hasBadge2000 = true;
            }
        }

        // Add 10 Comments Badge if user doesn't already have it
        if (!$hasBadge10) {
            addUserBadge($userId, $badgeName10, $badgeDescription10, $badgeIcon10, $commentCount);
        }

        // Add 50 Comments Badge if user doesn't already have it and comment count is 50 or more
        if (!$hasBadge50 && $commentCount >= 50) {
            addUserBadge($userId, $badgeName50, $badgeDescription50, $badgeIcon50, $commentCount);
        }

        // Add 150 Comments Badge if user doesn't already have it and comment count is 150 or more
        if (!$hasBadge150 && $commentCount >= 150) {
            addUserBadge($userId, $badgeName150, $badgeDescription150, $badgeIcon150, $commentCount);
        }

        // Add 500 Comments Badge if user doesn't already have it and comment count is 500 or more
        if (!$hasBadge500 && $commentCount >= 500) {
            addUserBadge($userId, $badgeName500, $badgeDescription500, $badgeIcon500, $commentCount);
        }

        // Add 1000 Comments Badge if user doesn't already have it and comment count is 1000 or more
        if (!$hasBadge1000 && $commentCount >= 1000) {
            addUserBadge($userId, $badgeName1000, $badgeDescription1000, $badgeIcon1000, $commentCount);
        }

        // Add 2000 Comments Badge if user doesn't already have it and comment count is 2000 or more
        if (!$hasBadge2000 && $commentCount >= 2000) {
            addUserBadge($userId, $badgeName2000, $badgeDescription2000, $badgeIcon2000, $commentCount);
        }
    }
}

// Add Comment Action
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['comment'])) {
    $content = htmlspecialchars($_POST['comment'], ENT_QUOTES, 'UTF-8'); // XSS protection
    $userId = $_SESSION['user_id'];

    if (!empty($content)) {
        $stmt = $pdo->prepare("
            INSERT INTO comments (tv_id, user_id, content, timestamp)
            VALUES (:tv_id, :user_id, :content, NOW())
        ");
        $stmt->execute([
            'tv_id' => $tvId,
            'user_id' => $userId,
            'content' => $content
        ]);

        // Redirect to prevent form resubmission on refresh
        header("Location: tv.php?id=$tvId");
        exit();
    }
}

// Function: Get TV show average rating from TMDb API
function getTVShowAverageRating($tvId)
{
    global $pdo;
    $apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f'; // TMDb API key
    $url = "https://api.themoviedb.org/3/tv/$tvId?api_key=$apiKey&language=tr-TR";

    // Initialize curl session
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute API request
    $response = curl_exec($ch);

    // Check for curl errors
    if (curl_errno($ch)) {
        echo 'Curl error: ' . curl_error($ch);
        exit();
    }

    // Close curl session
    curl_close($ch);

    // Decode JSON response
    $tvShow = json_decode($response, true);

    // Check if response is valid
    if ($tvShow && isset($tvShow['vote_average'])) {
        return $tvShow['vote_average'];
    } else {
        // Log the error message for debugging
        error_log("Invalid TV show details response: " . print_r($tvShow, true));
        return 0; // Return 0 if no valid TV show details found or no vote average available
    }
}

// Usage example to get average rating
$averageRating = getTVShowAverageRating($tvId);
$userBadges = getUserBadges($userId); // Function to get user badges


$apiKey = '63fd1ed0aa746bf66c0513b79c7b2b8f';
$tvShowId = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($tvShowId > 0) {
    $apiUrl = "https://api.themoviedb.org/3/tv/$tvShowId?api_key=$apiKey&language=tr-TR&append_to_response=seasons";
    $response = file_get_contents($apiUrl);
    $tvShow = json_decode($response, true);

    // Sezonları kontrol et ve bölümleri ekle
    if (isset($tvShow['seasons']) && is_array($tvShow['seasons'])) {
        $seasons = [];
        foreach ($tvShow['seasons'] as $season) {
            $seasonNumber = $season['season_number'];
            $seasonUrl = "https://api.themoviedb.org/3/tv/$tvShowId/season/$seasonNumber?api_key=$apiKey&language=tr-TR";
            $seasonResponse = file_get_contents($seasonUrl);
            $seasonDetails = json_decode($seasonResponse, true);

            // `episodes` anahtarını kontrol et ve sezon bilgisine ekle
            if (isset($seasonDetails['episodes']) && is_array($seasonDetails['episodes'])) {
                $season['episodes'] = $seasonDetails['episodes'];
            } else {
                $season['episodes'] = []; // Varsayılan boş dizi
            }

            // Sezonu listeye ekle
            $seasons[] = $season;
        }
    } else {
        $seasons = [];
    }
} else {
    echo "Geçersiz TV Show ID";
    exit;
}

function formatTurkishDate($date)
{
    if (empty($date)) {
        return 'Tarih mevcut değil';
    }

    $months = array(
        1 => 'Ocak',
        2 => 'Şubat',
        3 => 'Mart',
        4 => 'Nisan',
        5 => 'Mayıs',
        6 => 'Haziran',
        7 => 'Temmuz',
        8 => 'Ağustos',
        9 => 'Eylül',
        10 => 'Ekim',
        11 => 'Kasım',
        12 => 'Aralık'
    );

    try {
        $dateObj = new DateTime($date);
        $day = $dateObj->format('d');
        $month = $months[intval($dateObj->format('m'))];
        $year = $dateObj->format('Y');
        return "$day $month $year";
    } catch (Exception $e) {
        return 'Geçersiz tarih';
    }
}

// API yanıtını işleme ve ilk yayın tarihini kontrol etme
$firstAirDate = isset($tvShow['first_air_date']) ? $tvShow['first_air_date'] : '';

// Son bölümü kontrol etme
$lastEpisodeAirDate = isset($tvShow['last_episode_to_air']['air_date']) ? $tvShow['last_episode_to_air']['air_date'] : '';


// Dil kodlarına karşılık gelen ülke adları dizisi
$languageTranslations = [
    'af' => 'Afrikaans',
    'sq' => 'Arnavutça',
    'ar' => 'Arapça',
    'hy' => 'Ermenice',
    'az' => 'Azerice',
    'eu' => 'Baskça',
    'be' => 'Belarusça',
    'bn' => 'Bengalce',
    'bs' => 'Boşnakça',
    'ca' => 'Katalanca',
    'hr' => 'Hırvatça',
    'cs' => 'Çekçe',
    'da' => 'Danca',
    'nl' => 'Flemenkçe',
    'en' => 'İngilizce',
    'eo' => 'Esperanto',
    'et' => 'Estonca',
    'fi' => 'Fince',
    'fr' => 'Fransızca',
    'fy' => 'Frizce',
    'gd' => 'İskoçca',
    'gl' => 'Galce',
    'ka' => 'Gürcüce',
    'de' => 'Almanca',
    'el' => 'Yunanca',
    'gn' => 'Guarani',
    'gu' => 'Gujaratça',
    'ht' => 'Haitice',
    'ha' => 'Hausa',
    'he' => 'İbranice',
    'hi' => 'Hintçe',
    'hmn' => 'Hmong',
    'hu' => 'Macarca',
    'is' => 'İzlandaca',
    'ig' => 'Igbo',
    'id' => 'Endonezce',
    'ia' => 'Interlingua',
    'ie' => 'Interlingue',
    'iu' => 'Inuktitut',
    'it' => 'İtalyanca',
    'ja' => 'Japonca',
    'jw' => 'Javanese',
    'kn' => 'Kannada',
    'km' => 'Kmerce',
    'ko' => 'Korece',
    'la' => 'Latince',
    'lv' => 'Letonca',
    'lt' => 'Litvanca',
    'lu' => 'Luba-Katanga',
    'lb' => 'Lüksemburgce',
    'mk' => 'Makedonca',
    'ml' => 'Malayalam',
    'mi' => 'Maori',
    'mr' => 'Marathi',
    'my' => 'Burma',
    'mn' => 'Moğolca',
    'myv' => 'Erzya',
    'ne' => 'Nepalce',
    'no' => 'Norveçce',
    'or' => 'Odia',
    'pa' => 'Pencapça',
    'pl' => 'Lehçe',
    'ps' => 'Peştu',
    'pt' => 'Portekizce',
    'qu' => 'Quechua',
    'ro' => 'Romence',
    'ru' => 'Rusça',
    'sa' => 'Sanskritçe',
    'sd' => 'Sindhi',
    'si' => 'Singalaca',
    'sk' => 'Slovakça',
    'sl' => 'Slovence',
    'sm' => 'Samoan',
    'sn' => 'Shona',
    'so' => 'Somalice',
    'sq' => 'Arnavutça',
    'sr' => 'Sırpça',
    'ss' => 'Swati',
    'st' => 'Sotho',
    'su' => 'Sunda',
    'sv' => 'İsveçce',
    'sw' => 'Swahili',
    'ta' => 'Tamilce',
    'te' => 'Telugu',
    'tg' => 'Tacikce',
    'th' => 'Tayca',
    'ti' => 'Tigrinya',
    'tk' => 'Türkmence',
    'tl' => 'Tagalog',
    'tn' => 'Tswana',
    'to' => 'Tonga',
    'tr' => 'Türkçe',
    'ts' => 'Tsonga',
    'tt' => 'Tatarca',
    'tw' => 'Twi',
    'uk' => 'Ukraynaca',
    'ur' => 'Urduca',
    'uz' => 'Özbekçe',
    'vi' => 'Vietnamca',
    'vo' => 'Volapük',
    'cy' => 'Galce',
    'xh' => 'Xhosa',
    'yi' => 'Yidiş',
    'yo' => 'Yoruba',
    'zu' => 'Zulu',
];

// Dil kodunu ülke adına çeviren fonksiyon
function getCountryName($languageCode, $translations)
{
    return isset($translations[$languageCode]) ? $translations[$languageCode] : $languageCode;
}

$tvShowBackdrop = "https://image.tmdb.org/t/p/original" . $tvShow['backdrop_path']; // Arka plan görseli

$tvShowId = $_GET['id']; // veya başka bir yolla TV şovu ID'sini alın

// API isteğini yapın
$response = @file_get_contents("https://api.themoviedb.org/3/tv/{$tvShowId}/recommendations?api_key=63fd1ed0aa746bf66c0513b79c7b2b8f");

// Hata kontrolü
if ($response === FALSE) {
    die('API isteği başarısız oldu. Lütfen bağlantınızı kontrol edin.');
}

// Yanıtı JSON olarak çözümleyin
$data = json_decode($response, true);

// JSON çözümleme hatası kontrolü
if (json_last_error() !== JSON_ERROR_NONE) {
    die('JSON çözümleme hatası: ' . json_last_error_msg());
}

// Yanıtı kontrol edin ve $similarTVShows değişkenini doldurun
if (isset($data['results']) && is_array($data['results'])) {
    // İlk 6 öğeyi seçin
    $similarTVShows = array_slice($data['results'], 0, 6);
} else {
    $similarTVShows = [];
}

// Bölüm süresini saat ve dakika formatında gösteren fonksiyon
function formatRuntime($runtimeInMinutes)
{
    if ($runtimeInMinutes < 60) {
        return $runtimeInMinutes . 'dk';
    } else {
        $hours = intdiv($runtimeInMinutes, 60);
        $minutes = $runtimeInMinutes % 60;
        return $hours . 'sa ' . $minutes . 'dk';
    }
}

// TV dizisinin durumu
$status = $tvShow['status'];

switch ($status) {
    case 'Returning Series':
        $statusTurkish = 'Devam Ediyor';
        $badgeColor = 'bg-green-600/30 border-green-500/60 text-green-400';
        $dataTippyContent = 'Bu dizi yeni bölümleriyle devam ediyor.';
        $icon = '<i class="fas fa-sync-alt"></i>';
        break;
    case 'Ended':
        $statusTurkish = 'Bitti';
        $badgeColor = 'bg-red-500/30 border-red-500/60 text-red-400';
        $dataTippyContent = 'Bu dizi sona erdi.';
        $icon = '<i class="fas fa-times"></i>';
        break;
    case 'Canceled':
        $statusTurkish = 'İptal Edildi';
        $badgeColor = 'bg-yellow-500/30 border-yellow-500/60 text-yellow-400';
        $dataTippyContent = 'Dizi iptal edildi';
        $icon = '<i class="fas fa-ban"></i>';
        break;
    case 'Pilot':
        $statusTurkish = 'Pilot Bölüm';
        $badgeColor = 'bg-blue-500/30 border-blue-500/60 text-blue-400';
        $dataTippyContent = 'Bu bir pilot bölümdür.';
        $icon = '<i class="fas fa-paper-plane"></i>';
        break;
    case 'In Production':
        $statusTurkish = 'Yapım Aşamasında';
        $badgeColor = 'bg-purple-500/30 border-purple-500/60 text-purple-400';
        $dataTippyContent = 'Bu dizi şu anda yapım aşamasındadır.';
        $icon = '<i class="fas fa-film"></i>';
        break;
    case 'Planned':
        $statusTurkish = 'Planlandı';
        $badgeColor = 'bg-indigo-500/30 border-indigo-500/60 text-indigo-400';
        $dataTippyContent = 'Bu dizi planlanmıştır.';
        $icon = '<i class="fas fa-calendar-alt"></i>';
        break;
    default:
        $statusTurkish = 'Bilinmiyor';
        $badgeColor = 'bg-gray-500/30 border-gray-500/60 text-gray-400';
        $dataTippyContent = 'Bu dizinin durumu bilinmiyor.';
        $icon = '<i class="fas fa-question-circle"></i>';
        break;
}


// HTML STARTS HERE
?>
<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Foxy - <?php echo htmlspecialchars($tvShow['name']); ?></title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <meta name="description" content="<?php echo htmlspecialchars($tvShow['overview']); ?>">
    <meta name="keywords" content="film, <?php echo htmlspecialchars($tvShow['name']); ?>">
    <meta property="og:image" content="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($tvShow['poster_path']); ?>">
    <meta name="author" content="Foxy | 9FUD.COM">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        #loading-bar {
            width: 100%;
            height: 3px;
            background-color: #1a202c;
            position: fixed;
            top: 0;
            left: 0;
            z-index: 9999;
        }

        #loading-bar .progress {
            height: 100%;
            width: 0;
            background-color: #4caf50;
            transition: width 0.3s ease;
        }

        /* Animasyon sınıfı */
        @keyframes slideDown {
            from {
                max-height: 0;
                opacity: 0;
            }

            to {
                max-height: 500px;
                /* Maksimum yükseklik, içeriğin uzunluğuna göre ayarlanabilir */
                opacity: 1;
            }
        }

        @keyframes slideUp {
            from {
                max-height: 500px;
                /* Maksimum yükseklik, içeriğin uzunluğuna göre ayarlanabilir */
                opacity: 1;
            }

            to {
                max-height: 0;
                opacity: 0;
            }
        }

        .hidden {
            display: none;
        }

        .show {
            animation: slideDown 0.5s ease-out;
            overflow: hidden;
            /* İçeriğin taşmasını önlemek için */
        }

        .hide {
            animation: slideUp 0.5s ease-in;
            overflow: hidden;
            /* İçeriğin taşmasını önlemek için */
        }

        .backdrop {
            background-image: url('<?php echo $tvShowBackdrop; ?>');
            background-size: cover;
            background-position: center;
            background-repeat: no-repeat;
            background-attachment: fixed;
        }
    </style>
</head>

<body class="bg-gray-100">

    <!-- Navbar -->
    <?php include 'navbar.php'; ?>

    <!-- Loading bar -->
    <div id="loading-bar">
        <div class="progress"></div>
    </div>

    <div class="container mx-auto p-4 mb-14 mt-4">

        <div class="bg-black rounded mb-4 mx-auto items-center p-4">
            <span class="text-zinc-300 font-semibold"><span><i class="fa-solid fa-cable-car text-white ml-1 text-xl"></i></span> <span class="mx-1">Dizi sayfaları genel olarak bakımdadır.</span></span>
        </div>

        <!-- Geri Dönüş Bağlantısı -->
        <a href="/" class="hover:p-2 hover:bg-transparent text-blue-500 mb-8 block bg-blue-500/10 p-4 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Geri dön</a>

        <div class="container mx-auto pb-3">
            <div class="flex flex-col md:flex-row relative rounded-lg overflow-hidden mb-8 w-full backdrop" style="background-image: url('<?php echo $tvShowBackdrop; ?>');">
                <div class=" flex-shrink-0">
                    <img src="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($tvShow['poster_path']); ?>" alt="<?php echo htmlspecialchars($tvShow['name']); ?>" class="md:w-[300px] object-cover rounded-lg">
                </div>
                <div class="p-4 bg-black/40 backdrop-blur-md text-zinc-300 flex flex-col items-start justify-start">

                    <div class="inline-block mb-3 cursor-pointer hover:opacity-75 duration-150 px-3 md:absolute right-4 border py-1 rounded-lg text-sm font-semibold flex items-center space-x-2 <?php echo $badgeColor; ?>" data-tippy-content="<?php echo htmlspecialchars($dataTippyContent); ?>">
                        <?php echo $icon; ?>
                        <span><?php echo htmlspecialchars($statusTurkish); ?></span>
                    </div>

                    <div class="flex flex-row text-zinc-300 space-x-2 items-center">
                        <h1 class="text-2xl text-zinc-300 md:text-3xl font-bold text-gray-900"><?php echo htmlspecialchars($tvShow['name']); ?> |</h1>
                        <span class="font-semibold text-zinc-300"><?php echo htmlspecialchars($tvShow['number_of_seasons']); ?> Sezon <?php echo htmlspecialchars($tvShow['number_of_episodes']); ?> Bölüm</span>
                    </div>

                    <p class="text-zinc-100 mt-2"><?php echo htmlspecialchars($tvShow['overview']); ?></p>

                    <div class="w-full mt-2 rounded text-zinc-300">
                        <ul class="">
                            <li><strong><i class="fa-solid fa-language"></i> Orijinal Dil:</strong> <?php echo htmlspecialchars(getCountryName($tvShow['original_language'], $languageTranslations)); ?></li>
                            <li><strong><i class="fa-solid fa-calendar-week"></i> İlk Yayın Tarihi:</strong> <?php echo formatTurkishDate(isset($tvShow['first_air_date']) ? $tvShow['first_air_date'] : ''); ?></li>
                        </ul>
                        <div class="flex flex-row space-x-1 items-center mb-3">
                            <i class="fa-solid fa-star"></i>
                            <p><strong>Ortalama Puan:</strong> <?php echo number_format($tvShow['vote_average'], 1); ?>/10</p>
                        </div>
                        <div class="flex flex-wrap gap-1">
                            <?php foreach ($tvShow['genres'] as $genre) : ?>
                                <span class="bg-white font-semibold text-black px-3 py-1 rounded-md text-sm"><i class="fa-solid fa-hashtag"></i><?php echo htmlspecialchars($genre['name']); ?></span>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>

            <div class="mt-8">
                <h2 class="text-xl md:text-2xl font-bold text-gray-900 mb-4 duration-150"><i class="fa-solid fa-layer-group"></i> Sezonlar</h2>
                <div class="space-y-4">
                    <?php foreach ($seasons as $season) : ?>
                        <div>
                            <button class="w-full border duration-300 text-left p-4 bg-gray-200 hover:border-blue-500/80 hover:bg-gray-100 rounded-lg shadow-md flex justify-between items-center" onclick="toggleSeason(<?php echo $season['season_number']; ?>)">
                                <span><span class="font-semibold mr-3 text-xl text-blue-600"><?php echo $season['season_number']; ?></span> <?php echo htmlspecialchars($season['name']); ?></span>
                                <i class="fa-solid fa-chevron-down"></i>
                            </button>
                            <div id="season-<?php echo $season['season_number']; ?>" class="hidden mt-2 p-4 bg-white rounded-lg shadow-lg">
                                <?php if ($season['episode_count'] == 0) : ?>
                                    <span class="cursor-pointer hover:opacity-80 duration-150 text-sm border border-blue-500/20 px-3 rounded bg-blue-100 text-blue-500/80"><i class="fa-solid fa-person-running"></i> YAKINDA</span></h2>
                                    <div class="flex flex-row space-x-2 mt-2 items-center">
                                        <a target="_blank" href="https://www.deviantart.com/tuxedoneko/art/Cute-Blue-Fox-941796866"><img class="hover:opacity-75 duration-150 w-14 bg-blue-500/20 p-1 rounded-full" src="https://i.hizliresim.com/emxun8e.png" data-tippy-content="Art by <span class='font-semibold'>TuxedoNeko</span>" /></a>
                                        <p class="text-gray-500 text-sm mt-2">Bu sezon hakkında şu anlık bir bölüm eklenmemiş. Yakında yeni bilgiler geldiğinde <span data-tippy-content="❤️" class="font-semibold hover:bg-blue-400 hover:px-3 hover:rounded cursor-pointer duration-150 hover:text-white">Foxy</span> senin için burayı güncelleyecek!</p>
                                    </div>
                                <?php else : ?>
                                    <p class="text-xl font-bold text-zinc-600">
                                        <i class="fa-solid fa-clapperboard"></i>
                                        <?php echo htmlspecialchars($season['episode_count']); ?> Bölüm
                                    </p>
                                    <p class="font-semibold"><?php echo htmlspecialchars($season['overview']); ?></p>
                                    <span class="text-sm mt-1 text-zinc-500">
                                        <i class="fa-solid fa-calendar-week"></i>
                                        <?php echo formatTurkishDate(isset($season['air_date']) ? $season['air_date'] : ''); ?> tarihinde yayınlandı
                                    </span>

                                    <div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-2 mt-4">
                                        <?php foreach ($season['episodes'] as $episode) : ?>
                                            <div class="grid-item rounded hover:border-gray-500/30 border p-4 rounded-lg hover:shadow-xl transition duration-300 ease-in-out">
                                                <div class="relative">
                                                    <img src="https://image.tmdb.org/t/p/original<?php echo htmlspecialchars($episode['still_path']); ?>" alt="<?php echo htmlspecialchars($episode['name']); ?>" data-tippy-content="Sezon <?php echo htmlspecialchars($season['season_number']); ?> | Bölüm <?php echo htmlspecialchars($episode['episode_number']); ?> | <?php echo htmlspecialchars($episode['name']); ?>" class="hover:opacity-75 duration-150 relative cursor-pointer w-full h-48 object-cover rounded-lg mb-2" onerror="this.onerror=null; this.src='https://placehold.co/720x400?text=G%C3%B6rsel+bulunamad%C4%B1';">
                                                    <?php if (isset($episode['runtime']) && !empty($episode['runtime'])) : ?>
                                                        <div class="absolute hover:bg-black cursor-pointer duration-300 bottom-0 right-0 text-sm bg-black/20 backdrop-blur-sm rounded-l-full px-4 p-2">
                                                            <div class="space-x-1 text-zinc-300/90 flex flex-row items-center">
                                                                <i class="fa-regular fa-clock text-sm"></i>
                                                                <span><?php echo formatRuntime($episode['runtime']); ?></span>
                                                            </div>
                                                        </div>
                                                    <?php endif; ?>
                                                </div>

                                                <div class="flex flex-row space-x-2 items-center">
                                                    <h3 class="text-lg text-zinc-800 font-bold"><?php echo htmlspecialchars($episode['name']); ?></h3>
                                                </div>
                                                <div>
                                                    <p class="text-gray-600 font-semibold text-sm mt-1 mb-3"><?php echo htmlspecialchars($episode['overview']); ?></p>

                                                    <div class="text-gray-500 text-sm flex justify-between items-center">
                                                        <span>
                                                            <i class="fa-solid fa-calendar-week mr-1"></i> <?php echo formatTurkishDate(isset($episode['air_date']) ? $episode['air_date'] : ''); ?> |
                                                            <a href="https://www.themoviedb.org/tv/<?php echo $episode['show_id']; ?>/season/<?php echo $season['season_number']; ?>/episode/<?php echo $episode['episode_number']; ?>" target="_blank" class="text-blue-500 hover:underline ml-1">
                                                                <i class="fa-regular fa-map"></i> Bölümü TMDB'de görüntüle
                                                            </a>
                                                        </span>
                                                        <div class="text-sm text-yellow-600/90">
                                                            <i class="fa-solid fa-star mr-1"></i>
                                                            <?php echo number_format($episode['vote_average'], 1); ?> / 10
                                                        </div>
                                                    </div>

                                                    <?php
                                                    $trailerUrl = '';
                                                    if (isset($episode['videos']) && isset($episode['videos']['results']) && is_array($episode['videos']['results'])) {
                                                        foreach ($episode['videos']['results'] as $video) {
                                                            if ($video['type'] === 'Trailer' && $video['site'] === 'YouTube') {
                                                                $trailerUrl = 'https://www.youtube.com/watch?v=' . $video['key'];
                                                                break;
                                                            }
                                                        }
                                                    }
                                                    ?>

                                                    <?php if (!empty($trailerUrl)) : ?>
                                                        <div class="mt-2">
                                                            <a href="<?php echo $trailerUrl; ?>" target="_blank" class="text-red-500 hover:underline flex items-center">
                                                                <i class="fa-solid fa-play mr-1"></i>
                                                                Fragmanı İzle
                                                            </a>
                                                        </div>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>


                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

        </div>

        <script>
            function toggleSeason(seasonNumber) {
                const seasonDiv = document.getElementById(`season-${seasonNumber}`);
                const chevron = seasonDiv.previousElementSibling.querySelector('i');
                if (seasonDiv.classList.contains('hidden') || seasonDiv.classList.contains('hide')) {
                    // İçeriği göster
                    seasonDiv.classList.remove('hidden', 'hide');
                    seasonDiv.classList.add('show');
                    chevron.classList.replace('fa-chevron-down', 'fa-chevron-up');
                } else {
                    // İçeriği gizle
                    seasonDiv.classList.remove('show');
                    seasonDiv.classList.add('hide');
                    chevron.classList.replace('fa-chevron-up', 'fa-chevron-down');

                    // Animasyon tamamlandığında içeriği tamamen gizle
                    seasonDiv.addEventListener('animationend', function() {
                        seasonDiv.classList.add('hidden');
                        seasonDiv.classList.remove('hide');
                    }, {
                        once: true
                    });
                }
            }
        </script>

        <!-- Fragman -->
        <?php if (!empty($videoKey)) : ?>
            <div class="mb-8">
                <div class="relative" style="padding-top: 33.25%;">
                    <iframe src="https://www.youtube.com/embed/<?php echo htmlspecialchars($videoKey); ?>?rel=0&amp;showinfo=0" frameborder="0" allowfullscreen class="absolute inset-0 w-full h-full rounded-lg"></iframe>
                </div>
            </div>
        <?php endif; ?>

        <!-- Benzer Diziler -->
        <div class="container mx-auto mt-8">
            <h2 class="text-2xl font-bold text-center"><?php echo htmlspecialchars($tvShow['name']); ?> <span class="font-normal">ile benzer diziler</span></h2>
            <div id="similarTVShows" class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 px-2 lg:grid-cols-5 xl:grid-cols-6 gap-4 mt-8">
                <?php if (!empty($similarTVShows)) : ?>
                    <?php foreach ($similarTVShows as $index => $tvShow) : ?>
                        <div class="group relative rounded overflow-hidden" id="tv-show-<?php echo $index; ?>">
                            <a href="tv?id=<?php echo $tvShow['id']; ?>">
                                <img class="w-full h-full group-hover:scale-105 transition duration-300" src="https://image.tmdb.org/t/p/w500<?php echo $tvShow['poster_path']; ?>" alt="<?php echo $tvShow['name']; ?>">
                                <div class="overlay flex items-center justify-center">
                                    <div class="text-zinc-300 flex flex-col text-lg font-bold text-center">
                                        <span><?php echo $tvShow['name']; ?></span>
                                        <span class="font-normal text-sm"><?php echo date('Y', strtotime($tvShow['first_air_date'])); ?></span>
                                    </div>
                                </div>
                            </a>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <p class="text-center text-gray-600">Benzer diziler bulunamadı.</p>
                <?php endif; ?>
            </div>
        </div>


        <!-- Yorum Ekleme Formu -->
        <?php if ($userLoggedIn) : ?>
            <div class="items-start flex flex-col mb-4">
                <h2 class="text-xl font-bold text-center mt-8 mb-2 text-gray-600"><span class="rounded-full bg-blue-500/20 px-3"><i class="fa-solid fa-wand-magic-sparkles"></i></span> Sihirli kalemini konuştur <span class="cursor-pointer hover:opacity-80 duration-150 text-sm border border-red-500/20 px-3 rounded text-red-500/80"><i class="fa-solid fa-hammer mr-1"></i> BAKIMDA</span></h2>
                <span class="text-gray-500">Diğerlerinin arasında sen de sihirli kalemin ile yorumlar yap ve ödüller kazan. </span>
            </div>
            <form action="add_comments_tv.php" method="POST">
                <input type="hidden" name="token" value="<?php echo htmlspecialchars($_SESSION['token'] ?? ''); ?>">
                <input type="hidden" name="tv_id" value="<?php echo htmlspecialchars($tvId); ?>">
            </form>
            <div data-tippy-content="Dizi sayfasında yorum yapmak geçici olarak kapatıldı.">
                <textarea class="w-full px-3 py-2 cursor-not-allowed border rounded-lg focus:outline-none" placeholder="Yorumunuzu buraya yazın..." required readonly></textarea>
                <button class="mt-1 px-4 py-2 bg-gray-300 px-4 rounded-md opacity-50 cursor-not-allowed rounded-lg transition duration-300 focus:outline-none">Yorum Ekle</button>
            </div>

        <?php else : ?>
            <p class="mb-4">Yorum yapmak için <a href="login" class="text-blue-500 hover:underline">Giriş yapın</a> veya <a href="register" class="text-blue-500 hover:underline">Kayıt olun</a>.</p>
        <?php endif; ?>
        <!-- Yorumlar -->
        <div>
            <h2 class="text-2xl mt-4 font-semibold mb-4 text-gray-600">Yorumlar (<?php echo htmlspecialchars($totalComments); ?>)</h2>
            <?php if (empty($comments)) : ?>
                <p>Henüz yorum yapılmamış. İlk yorum yapan siz olun!</p>
            <?php else : ?>
                <?php foreach ($comments as $comment) : ?>
                    <div class="border rounded-lg p-4 mb-4 bg-white shadow-md">
                        <div class="flex items-center mb-2">
                            <img src="<?= htmlspecialchars($comment['profile_picture']); ?>" alt="<?= htmlspecialchars($comment['username']); ?>" class="w-10 h-10 rounded-full mr-2">
                            <h3 class="font-semibold"><?php echo htmlspecialchars($comment['username']); ?></h3>
                            <?php if (!empty($comment['badge_name'])) : ?>
                                <span class="ml-2 px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-gray-200 text-gray-800">
                                    <?php echo htmlspecialchars($comment['badge_name']); ?>
                                </span>
                            <?php endif; ?>
                        </div>

                        <p><?php echo htmlspecialchars($comment['content']); ?></p>

                        <p class="text-gray-500 text-sm" id="comment-timestamp">
                            <?= strftime('%e %B %Y - %H:%M', strtotime($comment['timestamp'])); ?>
                        </p>
                    </div>
                <?php endforeach; ?>

            <?php endif; ?>
        </div>


    </div>

    <!-- Tippy.js Script -->
    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            animation: 'shift-away',
            theme: 'material',
            duration: [300, 250],
            allowHTML: 'true'
        });
    </script>
</body>

</html>