<?php
session_start(); // Session başlat

require 'db.php'; // Veritabanı bağlantısı

// Türkçe ayarları yap
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');

// Kullanıcı rozetlerini al
function getUserBadges($userId)
{
    global $pdo;
    $stmt = $pdo->prepare("SELECT * FROM badges WHERE user_id = :user_id");
    $stmt->execute(['user_id' => $userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Tüm kullanıcıları çek
$stmt = $pdo->query("
    SELECT 
        users.id AS user_id,
        users.username,
        users.profile_picture,
        users.created_at,
        users.verified,
        users.admin,
        COUNT(comments.id) AS comment_count
    FROM users
    LEFT JOIN comments ON users.id = comments.user_id
    GROUP BY users.id
");
$users = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="tr">

<head>
    <meta charset="UTF-8">
    <title>Tüm Kullanıcılar</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css">
    <link rel="stylesheet" href="https://unpkg.com/tippy.js@6/animations/shift-away.css" />
    <link rel="icon" type="image/x-icon" href="/cdn/logo.png">
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-JW4L56PTPX"></script>
    <script>
        window.dataLayer = window.dataLayer || [];

        function gtag() {
            dataLayer.push(arguments);
        }
        gtag('js', new Date());

        gtag('config', 'G-JW4L56PTPX');
    </script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.2/css/all.min.css" integrity="sha512-SnH5WK+bZxgPHs44uWIX+LLJAJ9/2PkPKZ5QiAj6Ta86w+fsb2TkcmfRyVX3pBnMFcV7oQPJkl9QevSCWr3W6A==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        /* Custom CSS for responsiveness */
        @media (min-width: 640px) {
            .grid-cols-2 {
                grid-template-columns: repeat(2, minmax(0, 1fr)) !important;
            }
        }

        @media (min-width: 768px) {
            .grid-cols-2 {
                grid-template-columns: repeat(2, minmax(0, 1fr)) !important;
            }

            .grid-cols-3 {
                grid-template-columns: repeat(3, minmax(0, 1fr)) !important;
            }
        }

        @media (min-width: 1024px) {
            .grid-cols-3 {
                grid-template-columns: repeat(3, minmax(0, 1fr)) !important;
            }

            .grid-cols-4 {
                grid-template-columns: repeat(4, minmax(0, 1fr)) !important;
            }
        }

        /* Custom style for the checkmark SVG */
        .checkmark-svg {
            fill: #3490dc;
            width: 1em;
            height: 1em;
            vertical-align: middle;
        }
    </style>
</head>

<body class="bg-gray-100">

    <div class="w-full absolute top-0 z-20 text-center">
        <div class="mx-auto items-center rounded-b-lg hover:opacity-95 duration-150 bg-gradient-to-r from-indigo-600 to-indigo-700 text-zinc-300">
            <a href="https://discord.gg/Chh7gM5kY7" class="block p-3">
                <i class="fa-brands fa-discord fa-lg"></i> <strong>Discord</strong> sunucumuz açıldı! Buraya tıklayarak hemen sen de katıl.
            </a>
        </div>
    </div>

    <div class="container mx-auto pb-32 p-4 mt-20 md:mt-16 lg:mt-16 xl:mt-16 animate__animated">
        <a href="/" class="hover:p-2 text-blue-500 mb-8 block hover:bg-blue-500/10 rounded duration-300 font-semibold"><i class="fa-solid fa-arrow-left-long"></i> Geri dön</a>

        <div class="">
            <h1 class="text-3xl font-bold mb-4 p-4 text-zinc-600"><i class="fa-solid fa-circle-user"></i> Tüm Kullanıcılar</h1>

            <div class="grid gap-4 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4">
                <?php foreach ($users as $user) : ?>
                    <div class="p-4 rounded-lg shadow-md flex flex-col">
                        <div class="flex items-center mb-2">
                            <img src="<?= htmlspecialchars($user['profile_picture']); ?>" alt="<?= htmlspecialchars($user['username']); ?>" class="w-12 h-12 rounded-full">
                            <div class="ml-4 flex flex-col">
                                <div class="flex flex-row items-center">
                                    <a href="profile.php?user_id=<?= htmlspecialchars($user['user_id']); ?>" class="text-blue-500/80 font-bold hover:underline text-lg"><?= htmlspecialchars($user['username']); ?></a>

                                    <div class="ml-1 flex flex-row space-x-2">
                                        <?php if ($user['verified'] == 1) : ?>
                                            <img draggable="false" src="./cdn/verified.svg" alt="Doğrulanmış Kullanıcı" class="w-5 cursor-pointer" data-tippy-content="Doğrulanmış Kullanıcı">
                                        <?php endif; ?>
                                        <?php if ($user['admin'] == 1) : ?>
                                            <img draggable="false" src="./cdn/admin.png" alt="Admin" class="w-5 cursor-pointer" data-tippy-content=" Admin">
                                        <?php endif; ?>
                                    </div>
                                </div>

                                <div class="text-sm text-gray-500 mb-2"><?= htmlspecialchars(strftime('%e %B %Y - %H:%M', strtotime($user['created_at']))); ?></div>
                            </div>
                        </div>
                        <div class="text-sm mb-2">
                            <span class="font-semibold px-2 rounded bg-blue-100 border border-gray-500/20 text-blue-400"><i class="fa-solid fa-comments"> </i> <?= htmlspecialchars($user['comment_count']); ?> yorum</span>
                        </div>
                        <div class="mt-5">
                            <span class="text-xl">Rozetler</span>
                            <div class="mt-2 flex flex-wrap">
                                <?php
                                $userBadges = getUserBadges($user['user_id']);
                                if (count($userBadges) > 0) {
                                    foreach ($userBadges as $badge) : ?>
                                        <img draggable="false" src="<?= htmlspecialchars($badge['badge_icon']); ?>" alt="<?= htmlspecialchars($badge['badge_name']); ?>" data-tippy-content="<?= htmlspecialchars($badge['badge_description']); ?>" class="w-6 h-6 ml-2 mb-2 cursor-pointer" data-tippy-placement="top">
                                <?php endforeach;
                                } else {
                                    echo '<span class="text-xs text-red-500">Rozeti yok</span>';
                                }
                                ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>
    <footer class="mt-8 bg-black/90 text-white p-4 fixed bottom-0 w-full right-0 opacity-90">
        <div class="container mx-auto flex justify-between items-center">
            <div>
                <div class="flex flex-row items-center">
                    <img src="./cdn/logo.png" alt="Foxy" class="w-12">
                    <h3 class="text-lg font-bold">Foxy</h3>
                </div>
                <p class="mt-2">Tüm hakları saklıdır. | <span class="font-semibold">&copy; 2024 <a class="hover:text-red-600 duration-150" href="https://9fud.com">9FUD.COM</a></span></p>
            </div>

            <a href="https://www.themoviedb.org/" target="_blank" class="hover:underline hover:text-zinc-100 duration-150 text-zinc-400" data-tippy-content="Tüm dünyaya ücretsiz ve yerel dilleri de destekleyecek bir şekilde temiz API sunduğu için The Movie Database'a (TiVo Platform Technologies LLC) teşekkürlerimizi sunarız.">Özel teşekkür - TMDB API</span>

                <div>


                    <ul class="flex space-x-3">
                        <li>
                            <a href="https://instagram.com/FoxyPlatform" target="_blank" rel="noopener noreferrer" class="duration-150 text-gray-300 hover:text-pink-500" data-tippy-content="Bizi İnstagram'dan takip et!">
                                <i class="fab fa-instagram fa-lg"></i>
                            </a>
                        </li>
                        <li>
                            <a href="https://twitter.com/FoxyPlatform" target="_blank" rel="noopener noreferrer" class="duration-150 text-gray-300 hover:text-blue-400" data-tippy-content="Bizi X'ten takip et!">
                                <i class="fab fa-x-twitter fa-lg"></i>
                            </a>
                        </li>
                    </ul>
                </div>
        </div>
    </footer>

    <script src="https://unpkg.com/@popperjs/core@2"></script>
    <script src="https://unpkg.com/tippy.js@6"></script>
    <script>
        tippy('[data-tippy-content]', {
            animation: 'shift-away',
            theme: 'light',
        });
    </script>
</body>

</html>